local addonName, bepgp = ...
local moduleName = addonName.."_prices_cata"
local bepgp_prices_cata = bepgp:NewModule(moduleName, "AceEvent-3.0")
local ST = LibStub("ScrollingTable")
local name_version = "BastionEPGP_CC-1.0"
local prices = {}
local GetItemInventoryTypeByID = C_Item and C_Item.GetItemInventoryTypeByID or _G.GetItemInventoryTypeByID

local EQUIPSLOT_MULTIPLIER_1 = {
  INVTYPE_HEAD = 1,
  INVTYPE_NECK = 0.5,
  INVTYPE_SHOULDER = 0.75,
  INVTYPE_CHEST = 1,
  INVTYPE_ROBE = 1,
  INVTYPE_WAIST = 0.75,
  INVTYPE_LEGS = 1,
  INVTYPE_FEET = 0.75,
  INVTYPE_WRIST = 0.5,
  INVTYPE_HAND = 0.75,
  INVTYPE_FINGER = 0.5,
  INVTYPE_TRINKET = 0.75,
  INVTYPE_CLOAK = 0.5,
  INVTYPE_WEAPON = 1.5,
  INVTYPE_SHIELD = 1.5,
  INVTYPE_2HWEAPON = 2,
  INVTYPE_WEAPONMAINHAND = 1.5,
  INVTYPE_WEAPONOFFHAND = 0.5,
  INVTYPE_HOLDABLE = 0.5,
  INVTYPE_RANGED = 1.5,
  INVTYPE_RANGEDRIGHT = 1.5,
  INVTYPE_THROWN = 0.5,
  INVTYPE_RELIC = 0.5,
  -- Hack for Tier 9 25M heroic tokens.
  INVTYPE_CUSTOM_MULTISLOT_TIER = 0.9,
}

-- This is the low price equipslot multiplier (off hand weapons, non
-- tanking shields).
local EQUIPSLOT_MULTIPLIER_2 = {
  INVTYPE_WEAPON = 0.5,     -- One-handed subtype for melee Off-hand weapon or Tank Main-hand
  INVTYPE_SHIELD = 0.5,     -- for Non-tank Shield
  INVTYPE_2HWEAPON = 1,     -- Hunter or Titan Grip Off-hand
  INVTYPE_RANGED = 0.5,     -- Non-hunter Ranged Weapon
  INVTYPE_RANGEDRIGHT = 0.5,-- Non-hunter Ranged Weapon or Wands
}


--Used to display GP values directly on tier tokens
local CUSTOM_ITEM_DATA = {
  -- T11.359 (normal)
  [63682] = { 4, 359, "INVTYPE_HEAD" }, -- Helm of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [63683] = { 4, 359, "INVTYPE_HEAD" }, -- Helm of the Forlorn Conqueror (paladin/priest/warlock)
  [63684] = { 4, 359, "INVTYPE_HEAD" }, -- Helm of the Forlorn Protector (hunter/shaman/warrior)
  [64314] = { 4, 359, "INVTYPE_SHOULDER" }, -- Mantle of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [64315] = { 4, 359, "INVTYPE_SHOULDER" }, -- Mantle of the Forlorn Conqueror (paladin/priest/warlock)
  [64316] = { 4, 359, "INVTYPE_SHOULDER" }, -- Mantle of the Forlorn Protector (hunter/shaman/warrior)
  -- T11.372 (heroic)
  [65000] = { 4, 372, "INVTYPE_HEAD" }, -- Crown of the Forlorn Protector (hunter/shaman/warrior)
  [65001] = { 4, 372, "INVTYPE_HEAD" }, -- Crown of the Forlorn Conqueror (paladin/priest/warlock)
  [65002] = { 4, 372, "INVTYPE_HEAD" }, -- Crown of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [65087] = { 4, 372, "INVTYPE_SHOULDER" }, -- Shoulders of the Forlorn Protector (hunter/shaman/warrior)
  [65088] = { 4, 372, "INVTYPE_SHOULDER" }, -- Shoulders of the Forlorn Conqueror (paladin/priest/warlock)
  [65089] = { 4, 372, "INVTYPE_SHOULDER" }, -- Shoulders of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [67423] = { 4, 372, "INVTYPE_CHEST" }, -- Chest of the Forlorn Conqueror (paladin/priest/warlock)
  [67424] = { 4, 372, "INVTYPE_CHEST" }, -- Chest of the Forlorn Protector (hunter/shaman/warrior)
  [67425] = { 4, 372, "INVTYPE_CHEST" }, -- Chest of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [67429] = { 4, 372, "INVTYPE_HAND" }, -- Gauntlets of the Forlorn Conqueror (paladin/priest/warlock)
  [67430] = { 4, 372, "INVTYPE_HAND" }, -- Gauntlets of the Forlorn Protector (hunter/shaman/warrior)
  [67431] = { 4, 372, "INVTYPE_HAND" }, -- Gauntlets of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [67426] = { 4, 372, "INVTYPE_LEGS" }, -- Leggings of the Forlorn Vanquisher (dk/druid/mage/rogue)
  [67427] = { 4, 372, "INVTYPE_LEGS" }, -- Leggings of the Forlorn Protector (hunter/shaman/warrior)
  [67428] = { 4, 372, "INVTYPE_LEGS" }, -- Leggings of the Forlorn Conqueror (paladin/priest/warlock)
  [66998] = { 4, 372, "INVTYPE_CUSTOM_MULTISLOT_TIER"}, -- Essence of the Forlorn
  -- T12.378 (normal)
  [71668] = { 4, 378, "INVTYPE_HEAD" }, -- Helm of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71675] = { 4, 378, "INVTYPE_HEAD" }, -- Helm of the Fiery Conqueror (paladin/priest/warlock)
  [71682] = { 4, 378, "INVTYPE_HEAD" }, -- Helm of the Fiery Protector (hunter/shaman/warrior)
  [71674] = { 4, 378, "INVTYPE_SHOULDER" }, -- Mantle of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71681] = { 4, 378, "INVTYPE_SHOULDER" }, -- Mantle of the Fiery Conqueror (paladin/priest/warlock)
  [71688] = { 4, 378, "INVTYPE_SHOULDER" }, -- Mantle of the Fiery Protector (hunter/shaman/warrior)
  -- T12.391 (heroic)
  [71670] = { 4, 391, "INVTYPE_HEAD" }, -- Crown of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71677] = { 4, 391, "INVTYPE_HEAD" }, -- Crown of the Fiery Conqueror (paladin/priest/warlock)
  [71684] = { 4, 391, "INVTYPE_HEAD" }, -- Crown of the Fiery Protector (hunter/shaman/warrior)
  [71673] = { 4, 391, "INVTYPE_SHOULDER" }, -- Shoulders of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71680] = { 4, 391, "INVTYPE_SHOULDER" }, -- Shoulders of the Fiery Conqueror (paladin/priest/warlock)
  [71687] = { 4, 391, "INVTYPE_SHOULDER" }, -- Shoulders of the Fiery Protector (hunter/shaman/warrior)
  [71672] = { 4, 391, "INVTYPE_CHEST" }, -- Chest of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71679] = { 4, 391, "INVTYPE_CHEST" }, -- Chest of the Fiery Conqueror (paladin/priest/warlock)
  [71686] = { 4, 391, "INVTYPE_CHEST" }, -- Chest of the Fiery Protector (hunter/shaman/warrior)
  [71669] = { 4, 391, "INVTYPE_HAND" }, -- Gauntlets of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71676] = { 4, 391, "INVTYPE_HAND" }, -- Gauntlets of the Fiery Conqueror (paladin/priest/warlock)
  [71683] = { 4, 391, "INVTYPE_HAND" }, -- Gauntlets of the Fiery Protector (hunter/shaman/warrior)
  [71671] = { 4, 391, "INVTYPE_LEGS" }, -- Leggings of the Fiery Vanquisher (dk/druid/mage/rogue)
  [71678] = { 4, 391, "INVTYPE_LEGS" }, -- Leggings of the Fiery Conqueror (paladin/priest/warlock)
  [71685] = { 4, 391, "INVTYPE_LEGS" }, -- Leggings of the Fiery Protector (hunter/shaman/warrior)
  -- T13.397 (normal)
  [78172] = { 4, 397, "INVTYPE_HEAD" }, -- Crown of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78177] = { 4, 397, "INVTYPE_HEAD" }, -- Crown of the Corrupted Protector (hunter/shaman/warrior)
  [78182] = { 4, 397, "INVTYPE_HEAD" }, -- Crown of the Corrupted Conqueror (paladin/priest/warlock)
  [78170] = { 4, 397, "INVTYPE_SHOULDER" }, -- Shoulders of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78175] = { 4, 397, "INVTYPE_SHOULDER" }, -- Shoulders of the Corrupted Protector (hunter/shaman/warrior)
  [78180] = { 4, 397, "INVTYPE_SHOULDER" }, -- Shoulders of the Corrupted Conqueror (paladin/priest/warlock)
  [78174] = { 4, 397, "INVTYPE_CHEST" }, -- Chest of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78179] = { 4, 397, "INVTYPE_CHEST" }, -- Chest of the Corrupted Protector (hunter/shaman/warrior)
  [78184] = { 4, 397, "INVTYPE_CHEST" }, -- Chest of the Corrupted Conqueror (paladin/priest/warlock)
  [78173] = { 4, 397, "INVTYPE_HAND" }, -- Gauntlets of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78178] = { 4, 397, "INVTYPE_HAND" }, -- Gauntlets of the Corrupted Protector (hunter/shaman/warrior)
  [78183] = { 4, 397, "INVTYPE_HAND" }, -- Gauntlets of the Corrupted Conqueror (paladin/priest/warlock)
  [78171] = { 4, 397, "INVTYPE_LEGS" }, -- Leggings of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78176] = { 4, 397, "INVTYPE_LEGS" }, -- Leggings of the Corrupted Protector (hunter/shaman/warrior)
  [78181] = { 4, 397, "INVTYPE_LEGS" }, -- Leggings of the Corrupted Conqueror (paladin/priest/warlock)
  -- T13.410 (heroic)
  [78850] = { 4, 410, "INVTYPE_HEAD" }, -- Crown of the Corrupted Conqueror (paladin/priest/warlock)
  [78851] = { 4, 410, "INVTYPE_HEAD" }, -- Crown of the Corrupted Protector (hunter/shaman/warrior)
  [78852] = { 4, 410, "INVTYPE_HEAD" }, -- Crown of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78859] = { 4, 410, "INVTYPE_SHOULDER" }, -- Shoulders of the Corrupted Conqueror (paladin/priest/warlock)
  [78860] = { 4, 410, "INVTYPE_SHOULDER" }, -- Shoulders of the Corrupted Protector (hunter/shaman/warrior)
  [78861] = { 4, 410, "INVTYPE_SHOULDER" }, -- Shoulders of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78847] = { 4, 410, "INVTYPE_CHEST" }, -- Chest of the Corrupted Conqueror (paladin/priest/warlock)
  [78848] = { 4, 410, "INVTYPE_CHEST" }, -- Chest of the Corrupted Protector (hunter/shaman/warrior)
  [78849] = { 4, 410, "INVTYPE_CHEST" }, -- Chest of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78853] = { 4, 410, "INVTYPE_HAND" }, -- Gauntlets of the Corrupted Conqueror (paladin/priest/warlock)
  [78854] = { 4, 410, "INVTYPE_HAND" }, -- Gauntlets of the Corrupted Protector (hunter/shaman/warrior)
  [78855] = { 4, 410, "INVTYPE_HAND" }, -- Gauntlets of the Corrupted Vanquisher (dk/druid/mage/rogue)
  [78856] = { 4, 410, "INVTYPE_LEGS" }, -- Leggings of the Corrupted Conqueror (paladin/priest/warlock)
  [78857] = { 4, 410, "INVTYPE_LEGS" }, -- Leggings of the Corrupted Protector (hunter/shaman/warrior)
  [78858] = { 4, 410, "INVTYPE_LEGS" }, -- Leggings of the Corrupted Vanquisher (dk/druid/mage/rogue)
}
local CACHED_ITEM_DATA = {
  [54503] = {4,359,"INVTYPE_WAIST"}, -- "Dreamless Belt"
  [54504] = {4,359,"INVTYPE_WAIST"}, -- "Belt of the Depths"
  [54505] = {4,359,"INVTYPE_LEGS"}, -- "Breeches of Mended Nightmares"
  [54506] = {4,359,"INVTYPE_LEGS"}, -- "Flame-Ascended Pantaloons"
  [55058] = {4,359,"INVTYPE_CHEST"}, -- "Hardened Elementium Hauberk"
  [55059] = {4,359,"INVTYPE_WAIST"}, -- "Hardened Elementium Girdle"
  [55060] = {4,359,"INVTYPE_CHEST"}, -- "Elementium Deathplate"
  [55061] = {4,359,"INVTYPE_WAIST"}, -- "Elementium Girdle of Pain"
  [55062] = {4,359,"INVTYPE_CHEST"}, -- "Light Elementium Chestguard"
  [55063] = {4,359,"INVTYPE_WAIST"}, -- "Light Elementium Belt"
  [55069] = {4,359,"INVTYPE_SHIELD"}, -- "Elementium Earthguard"
  [55070] = {4,359,"INVTYPE_SHIELD"}, -- "Elementium Stormshield"
  [56536] = {4,359,"INVTYPE_WAIST"}, -- "Lightning Lash"
  [56537] = {4,359,"INVTYPE_WAIST"}, -- "Belt of Nefarious Whispers"
  [56538] = {4,359,"INVTYPE_WAIST"}, -- "Stormleather Sash"
  [56539] = {4,359,"INVTYPE_WAIST"}, -- "Corded Viper Belt"
  [56561] = {4,359,"INVTYPE_CHEST"}, -- "Chestguard of Nature's Fury"
  [56562] = {4,359,"INVTYPE_CHEST"}, -- "Assassin's Chestplate"
  [56563] = {4,359,"INVTYPE_CHEST"}, -- "Twilight Scale Chestguard"
  [56564] = {4,359,"INVTYPE_CHEST"}, -- "Dragonkiller Tunic"
  [58180] = {4,359,"INVTYPE_TRINKET"}, -- "License to Slay"
  [58181] = {4,359,"INVTYPE_TRINKET"}, -- "Fluid Death"
  [58182] = {4,359,"INVTYPE_TRINKET"}, -- "Bedrock Talisman"
  [58183] = {4,359,"INVTYPE_TRINKET"}, -- "Soul Casket"
  [58184] = {4,359,"INVTYPE_TRINKET"}, -- "Core of Ripeness"
  [58185] = {4,359,"INVTYPE_FINGER"}, -- "Band of Bees"
  [58187] = {4,359,"INVTYPE_FINGER"}, -- "Ring of the Battle Anthem"
  [58188] = {4,359,"INVTYPE_FINGER"}, -- "Band of Secret Names"
  [58189] = {4,359,"INVTYPE_FINGER"}, -- "Twined Band of Flowers"
  [58190] = {4,359,"INVTYPE_CLOAK"}, -- "Floating Web"
  [58191] = {4,359,"INVTYPE_CLOAK"}, -- "Viewless Wings"
  [58192] = {4,359,"INVTYPE_CLOAK"}, -- "Gray Hair Cloak"
  [58193] = {4,359,"INVTYPE_CLOAK"}, -- "Haunt of Flies"
  [58194] = {4,359,"INVTYPE_CLOAK"}, -- "Heavenly Breeze"
  [58195] = {4,359,"INVTYPE_FEET"}, -- "Woe Breeder's Boots"
  [58197] = {4,359,"INVTYPE_FEET"}, -- "Rock Furrow Boots"
  [58198] = {4,359,"INVTYPE_FEET"}, -- "Eternal Pathfinders"
  [58199] = {4,359,"INVTYPE_FEET"}, -- "Moccasins of Verdurous Glooms"
  [58481] = {4,359,"INVTYPE_FEET"}, -- "Boots of the Perilous Seas"
  [58482] = {4,359,"INVTYPE_FEET"}, -- "Treads of Fleeting Joy"
  [58483] = {4,359,"INVTYPE_TRINKET"}, -- "Lifebound Alchemist Stone"
  [58484] = {4,359,"INVTYPE_FEET"}, -- "Fading Violet Sandals"
  [58485] = {4,359,"INVTYPE_FEET"}, -- "Melodious Slippers"
  [58486] = {4,359,"INVTYPE_FEET"}, -- "Slippers of Moving Waters"
  [59117] = {4,359,"INVTYPE_WAIST"}, -- "Jumbotron Power Belt"
  [59118] = {4,359,"INVTYPE_WRIST"}, -- "Electron Inductor Coils"
  [59119] = {4,359,"INVTYPE_CHEST"}, -- "Voltage Source Chestguard"
  [59120] = {4,359,"INVTYPE_SHOULDER"}, -- "Poison Protocol Pauldrons"
  [59121] = {4,359,"INVTYPE_FINGER"}, -- "Lightning Conductor Band"
  [59122] = {4,359,"INVTYPE_WEAPON"}, -- "Organic Lifeform Inverter"
  [59216] = {4,359,"INVTYPE_FEET"}, -- "Life Force Chargers"
  [59217] = {4,359,"INVTYPE_WAIST"}, -- "X-Tron Duct Tape"
  [59218] = {4,359,"INVTYPE_SHOULDER"}, -- "Passive Resistor Spaulders"
  [59219] = {4,359,"INVTYPE_HEAD"}, -- "Power Generator Hood"
  [59220] = {4,359,"INVTYPE_FINGER"}, -- "Security Measure Alpha"
  [59221] = {4,359,"INVTYPE_FEET"}, -- "Massacre Treads"
  [59222] = {4,359,"INVTYPE_SHOULDER"}, -- "Spaulders of the Scarred Lady"
  [59223] = {4,359,"INVTYPE_HAND"}, -- "Double Attack Handguards"
  [59224] = {4,359,"INVTYPE_TRINKET"}, -- "Heart of Rage"
  [59225] = {4,359,"INVTYPE_HAND"}, -- "Plated Fists of Provocation"
  [59233] = {4,359,"INVTYPE_FINGER"}, -- "Bile-O-Tron Nut"
  [59234] = {4,359,"INVTYPE_FEET"}, -- "Einhorn's Galoshes"
  [59310] = {4,359,"INVTYPE_WRIST"}, -- "Chaos Beast Bracers"
  [59311] = {4,359,"INVTYPE_SHOULDER"}, -- "Burden of Mortality"
  [59312] = {4,359,"INVTYPE_HEAD"}, -- "Helm of the Blind Seer"
  [59313] = {4,359,"INVTYPE_HAND"}, -- "Brackish Gloves"
  [59314] = {4,359,"INVTYPE_RANGEDRIGHT"}, -- "Finkle's Mixer Upper"
  [59315] = {4,359,"INVTYPE_FEET"}, -- "Boots of Vertigo"
  [59316] = {4,359,"INVTYPE_CHEST"}, -- "Battleplate of Ancient Kings"
  [59317] = {4,359,"INVTYPE_LEGS"}, -- "Legguards of the Unseeing"
  [59318] = {4,359,"INVTYPE_CHEST"}, -- "Sark of the Unwatched"
  [59319] = {4,359,"INVTYPE_NECK"}, -- "Ironstar Amulet"
  [59320] = {4,359,"INVTYPE_RANGED"}, -- "Themios the Darkbringer"
  [59321] = {4,359,"INVTYPE_WAIST"}, -- "Belt of the Nightmare"
  [59322] = {4,359,"INVTYPE_WRIST"}, -- "Bracers of the Burningeye"
  [59324] = {4,359,"INVTYPE_HAND"}, -- "Gloves of Cacophony"
  [59325] = {4,359,"INVTYPE_SHOULDER"}, -- "Mantle of Roaring Flames"
  [59326] = {4,359,"INVTYPE_TRINKET"}, -- "Bell of Enraging Resonance"
  [59327] = {4,359,"INVTYPE_SHIELD"}, -- "Kingdom's Heart"
  [59328] = {4,359,"INVTYPE_FEET"}, -- "Molten Tantrum Boots"
  [59329] = {4,359,"INVTYPE_WRIST"}, -- "Parasitic Bands"
  [59330] = {4,359,"INVTYPE_2HWEAPON"}, -- "Shalug'doom, the Axe of Unmaking"
  [59331] = {4,359,"INVTYPE_LEGS"}, -- "Leggings of Lethal Force"
  [59332] = {4,359,"INVTYPE_TRINKET"}, -- "Symbiotic Worm"
  [59333] = {4,359,"INVTYPE_WEAPON"}, -- "Lava Spine"
  [59334] = {4,359,"INVTYPE_WAIST"}, -- "Lifecycle Waistguard"
  [59335] = {4,359,"INVTYPE_ROBE"}, -- "Scorched Wormling Vest"
  [59336] = {4,359,"INVTYPE_LEGS"}, -- "Flame Pillar Leggings"
  [59337] = {4,359,"INVTYPE_SHOULDER"}, -- "Mantle of Nefarius"
  [59340] = {4,359,"INVTYPE_CHEST"}, -- "Breastplate of Avenging Flame"
  [59341] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Incineratus"
  [59342] = {4,359,"INVTYPE_WAIST"}, -- "Belt of Absolute Zero"
  [59343] = {4,359,"INVTYPE_LEGS"}, -- "Aberration's Leggings"
  [59344] = {4,359,"INVTYPE_HEAD"}, -- "Dragon Bone Warhelm"
  [59346] = {4,359,"INVTYPE_CHEST"}, -- "Tunic of Failed Experiments"
  [59347] = {4,359,"INVTYPE_WEAPON"}, -- "Mace of Acrid Death"
  [59348] = {4,359,"INVTYPE_CLOAK"}, -- "Cloak of Biting Chill"
  [59349] = {4,359,"INVTYPE_WAIST"}, -- "Belt of Arcane Storms"
  [59350] = {4,359,"INVTYPE_FEET"}, -- "Treads of Flawless Creation"
  [59351] = {4,359,"INVTYPE_LEGS"}, -- "Legwraps of the Greatest Son"
  [59352] = {4,359,"INVTYPE_HAND"}, -- "Flash Freeze Gauntlets"
  [59353] = {4,359,"INVTYPE_LEGS"}, -- "Leggings of Consuming Flames"
  [59354] = {4,359,"INVTYPE_TRINKET"}, -- "Jar of Ancient Remedies"
  [59355] = {4,359,"INVTYPE_WRIST"}, -- "Chimaeron Armguards"
  [59356] = {4,359,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Apocalypse"
  [59359] = {4,359,"INVTYPE_HEAD"}, -- "Reinforced Bio-Optic Killshades"
  [59441] = {4,359,"INVTYPE_TRINKET"}, -- "Prestor's Talisman of Machination"
  [59442] = {4,359,"INVTYPE_NECK"}, -- "Rage of Ages"
  [59443] = {4,359,"INVTYPE_WEAPON"}, -- "Crul'korak, the Lightning's Arc"
  [59444] = {4,359,"INVTYPE_SHIELD"}, -- "Akmin-Kurai, Dominion's Shield"
  [59448] = {4,359,"INVTYPE_HEAD"}, -- "Specialized Bio-Optic Killshades"
  [59449] = {4,359,"INVTYPE_HEAD"}, -- "Lightweight Bio-Optic Killshades"
  [59450] = {4,359,"INVTYPE_WAIST"}, -- "Belt of the Blackhand"
  [59451] = {4,359,"INVTYPE_WRIST"}, -- "Manacles of the Sleeping Beast"
  [59452] = {4,359,"INVTYPE_HEAD"}, -- "Crown of Burning Waters"
  [59453] = {4,359,"INVTYPE_HEAD"}, -- "Camouflage Bio-Optic Killshades"
  [59454] = {4,359,"INVTYPE_ROBE"}, -- "Shadowblaze Robes"
  [59455] = {4,359,"INVTYPE_HEAD"}, -- "Agile Bio-Optic Killshades"
  [59456] = {4,359,"INVTYPE_HEAD"}, -- "Deadly Bio-Optic Killshades"
  [59457] = {4,359,"INVTYPE_CLOAK"}, -- "Shadow of Dread"
  [59458] = {4,359,"INVTYPE_HEAD"}, -- "Energized Bio-Optic Killshades"
  [59459] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Andoros, Fist of the Dragon King"
  [59460] = {4,359,"INVTYPE_RANGEDRIGHT"}, -- "Theresa's Booklight"
  [59461] = {4,359,"INVTYPE_TRINKET"}, -- "Fury of Angerforge"
  [59462] = {4,359,"INVTYPE_WEAPONOFFHAND"}, -- "Maimgor's Bite"
  [59463] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Maldo's Sword Cane"
  [59464] = {4,359,"INVTYPE_FEET"}, -- "Treads of Savage Beatings"
  [59465] = {4,359,"INVTYPE_WAIST"}, -- "Corehammer's Riveted Girdle"
  [59466] = {4,359,"INVTYPE_CLOAK"}, -- "Ironstar's Impenetrable Cover"
  [59467] = {4,359,"INVTYPE_SHOULDER"}, -- "Hide of Chromaggus"
  [59468] = {4,359,"INVTYPE_ROBE"}, -- "Shadowforge's Lightbound Smock"
  [59469] = {4,359,"INVTYPE_FEET"}, -- "Storm Rider's Boots"
  [59470] = {4,359,"INVTYPE_WRIST"}, -- "Bracers of Impossible Strength"
  [59471] = {4,359,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Great Ettin"
  [59472] = {4,359,"INVTYPE_HAND"}, -- "Proto-Handler's Gauntlets"
  [59473] = {4,359,"INVTYPE_TRINKET"}, -- "Essence of the Cyclone"
  [59474] = {4,359,"INVTYPE_2HWEAPON"}, -- "Malevolence"
  [59475] = {4,359,"INVTYPE_WRIST"}, -- "Bracers of the Bronze Flight"
  [59476] = {4,359,"INVTYPE_LEGS"}, -- "Legguards of the Emerald Brood"
  [59481] = {4,359,"INVTYPE_HEAD"}, -- "Helm of the Nether Scion"
  [59482] = {4,359,"INVTYPE_ROBE"}, -- "Robes of the Burning Acolyte"
  [59483] = {4,359,"INVTYPE_NECK"}, -- "Wyrmbreaker's Amulet"
  [59484] = {4,359,"INVTYPE_HOLDABLE"}, -- "Book of Binding Will"
  [59485] = {4,359,"INVTYPE_WAIST"}, -- "Coil of Ten-Thousand Screams"
  [59486] = {4,359,"INVTYPE_CHEST"}, -- "Battleplate of the Apocalypse"
  [59487] = {4,359,"INVTYPE_HEAD"}, -- "Helm of Maddening Whispers"
  [59490] = {4,359,"INVTYPE_HEAD"}, -- "Membrane of C'Thun"
  [59492] = {4,359,"INVTYPE_2HWEAPON"}, -- "Akirus the Worm-Breaker"
  [59494] = {4,359,"INVTYPE_WEAPON"}, -- "Uhn'agh Fash, the Darkest Betrayal"
  [59495] = {4,359,"INVTYPE_FEET"}, -- "Treads of Hideous Transformation"
  [59497] = {4,359,"INVTYPE_WRIST"}, -- "Shackles of the End of Days"
  [59498] = {4,359,"INVTYPE_HAND"}, -- "Hands of the Twilight Council"
  [59499] = {4,359,"INVTYPE_LEGS"}, -- "Kilt of the Forgotten Battle"
  [59500] = {4,359,"INVTYPE_TRINKET"}, -- "Fall of Mortality"
  [59501] = {4,359,"INVTYPE_FINGER"}, -- "Signet of the Fifth Circle"
  [59502] = {4,359,"INVTYPE_WAIST"}, -- "Dispersing Belt"
  [59503] = {4,359,"INVTYPE_LEGS"}, -- "Terrastra's Legguards"
  [59504] = {4,359,"INVTYPE_HEAD"}, -- "Arion's Crown"
  [59505] = {4,359,"INVTYPE_HAND"}, -- "Gravitational Pull"
  [59506] = {4,359,"INVTYPE_TRINKET"}, -- "Crushing Weight"
  [59507] = {4,359,"INVTYPE_CLOAK"}, -- "Glittering Epidermis"
  [59508] = {4,359,"INVTYPE_FEET"}, -- "Treads of Liquid Ice"
  [59509] = {4,359,"INVTYPE_HEAD"}, -- "Glaciated Helm"
  [59510] = {4,359,"INVTYPE_SHOULDER"}, -- "Feludius' Mantle"
  [59511] = {4,359,"INVTYPE_HAND"}, -- "Hydrolance Gloves"
  [59512] = {4,359,"INVTYPE_NECK"}, -- "Valiona's Medallion"
  [59513] = {4,359,"INVTYPE_HOLDABLE"}, -- "Scepter of Ice"
  [59514] = {4,359,"INVTYPE_TRINKET"}, -- "Heart of Ignacious"
  [59515] = {4,359,"INVTYPE_TRINKET"}, -- "Vial of Stolen Memories"
  [59516] = {4,359,"INVTYPE_CLOAK"}, -- "Drape of the Twins"
  [59517] = {4,359,"INVTYPE_NECK"}, -- "Necklace of Strife"
  [59518] = {4,359,"INVTYPE_FINGER"}, -- "Ring of Rivalry"
  [59519] = {4,359,"INVTYPE_TRINKET"}, -- "Theralion's Mirror"
  [59520] = {4,359,"INVTYPE_TRINKET"}, -- "Unheeded Warning"
  [59521] = {4,359,"INVTYPE_WEAPON"}, -- "Soul Blade"
  [59525] = {4,359,"INVTYPE_2HWEAPON"}, -- "Chelley's Staff of Dark Mending"
  [59901] = {4,359,"INVTYPE_SHOULDER"}, -- "Heaving Plates of Protection"
  [60201] = {4,359,"INVTYPE_LEGS"}, -- "Phase-Twister Leggings"
  [60202] = {4,359,"INVTYPE_HEAD"}, -- "Tsanga's Helm"
  [60210] = {4,359,"INVTYPE_RANGEDRIGHT"}, -- "Crossfire Carbine"
  [60211] = {4,359,"INVTYPE_WRIST"}, -- "Bracers of the Dark Pool"
  [60226] = {4,379,"INVTYPE_FINGER"}, -- "Dargonax's Signet"
  [60227] = {4,379,"INVTYPE_NECK"}, -- "Caelestrasz's Will"
  [60228] = {4,379,"INVTYPE_WRIST"}, -- "Bracers of the Mat'redor"
  [60229] = {4,379,"INVTYPE_FEET"}, -- "War-Torn Crushers"
  [60230] = {4,379,"INVTYPE_LEGS"}, -- "Twilight Scale Leggings"
  [60231] = {4,379,"INVTYPE_WAIST"}, -- "Belt of the Fallen Brood"
  [60232] = {4,379,"INVTYPE_CLOAK"}, -- "Shroud of Endless Grief"
  [60233] = {4,379,"INVTYPE_TRINKET"}, -- "Shard of Woe"
  [60234] = {4,379,"INVTYPE_WRIST"}, -- "Bindings of Bleak Betrayal"
  [60235] = {4,379,"INVTYPE_FEET"}, -- "Boots of Az'galada"
  [60236] = {4,379,"INVTYPE_FEET"}, -- "Nightmare Rider's Boots"
  [60237] = {4,379,"INVTYPE_HEAD"}, -- "Crown of the Twilight Queen"
  [60238] = {4,379,"INVTYPE_WRIST"}, -- "Bracers of the Dark Mother"
  [60243] = {4,359,"INVTYPE_HEAD"}, -- "Firelord's Hood"
  [60244] = {4,359,"INVTYPE_ROBE"}, -- "Firelord's Robes"
  [60245] = {4,359,"INVTYPE_LEGS"}, -- "Firelord's Leggings"
  [60246] = {4,359,"INVTYPE_SHOULDER"}, -- "Firelord's Mantle"
  [60247] = {4,359,"INVTYPE_HAND"}, -- "Firelord's Gloves"
  [60248] = {4,359,"INVTYPE_HAND"}, -- "Shadowflame Handwraps"
  [60249] = {4,359,"INVTYPE_HEAD"}, -- "Shadowflame Hood"
  [60250] = {4,359,"INVTYPE_LEGS"}, -- "Shadowflame Leggings"
  [60251] = {4,359,"INVTYPE_ROBE"}, -- "Shadowflame Robes"
  [60252] = {4,359,"INVTYPE_SHOULDER"}, -- "Shadowflame Mantle"
  [60253] = {4,359,"INVTYPE_SHOULDER"}, -- "Mercurial Shoulderwraps"
  [60254] = {4,359,"INVTYPE_ROBE"}, -- "Mercurial Vestment"
  [60255] = {4,359,"INVTYPE_LEGS"}, -- "Mercurial Leggings"
  [60256] = {4,359,"INVTYPE_HEAD"}, -- "Mercurial Hood"
  [60257] = {4,359,"INVTYPE_HAND"}, -- "Mercurial Gloves"
  [60258] = {4,359,"INVTYPE_HEAD"}, -- "Mercurial Cowl"
  [60259] = {4,359,"INVTYPE_ROBE"}, -- "Mercurial Robes"
  [60261] = {4,359,"INVTYPE_LEGS"}, -- "Mercurial Legwraps"
  [60262] = {4,359,"INVTYPE_SHOULDER"}, -- "Mercurial Mantle"
  [60275] = {4,359,"INVTYPE_HAND"}, -- "Mercurial Handwraps"
  [60276] = {4,359,"INVTYPE_ROBE"}, -- "Stormrider's Robes"
  [60277] = {4,359,"INVTYPE_HEAD"}, -- "Stormrider's Helm"
  [60278] = {4,359,"INVTYPE_LEGS"}, -- "Stormrider's Legwraps"
  [60279] = {4,359,"INVTYPE_SHOULDER"}, -- "Stormrider's Mantle"
  [60280] = {4,359,"INVTYPE_HAND"}, -- "Stormrider's Handwraps"
  [60281] = {4,359,"INVTYPE_ROBE"}, -- "Stormrider's Vestment"
  [60282] = {4,359,"INVTYPE_HEAD"}, -- "Stormrider's Cover"
  [60283] = {4,359,"INVTYPE_LEGS"}, -- "Stormrider's Leggings"
  [60284] = {4,359,"INVTYPE_SHOULDER"}, -- "Stormrider's Shoulderwraps"
  [60285] = {4,359,"INVTYPE_HAND"}, -- "Stormrider's Gloves"
  [60286] = {4,359,"INVTYPE_HEAD"}, -- "Stormrider's Headpiece"
  [60287] = {4,359,"INVTYPE_ROBE"}, -- "Stormrider's Raiment"
  [60288] = {4,359,"INVTYPE_LEGS"}, -- "Stormrider's Legguards"
  [60289] = {4,359,"INVTYPE_SHOULDER"}, -- "Stormrider's Spaulders"
  [60290] = {4,359,"INVTYPE_HAND"}, -- "Stormrider's Grips"
  [60298] = {4,359,"INVTYPE_HAND"}, -- "Wind Dancer's Gloves"
  [60299] = {4,359,"INVTYPE_HEAD"}, -- "Wind Dancer's Helmet"
  [60300] = {4,359,"INVTYPE_LEGS"}, -- "Wind Dancer's Legguards"
  [60301] = {4,359,"INVTYPE_CHEST"}, -- "Wind Dancer's Tunic"
  [60302] = {4,359,"INVTYPE_SHOULDER"}, -- "Wind Dancer's Spaulders"
  [60303] = {4,359,"INVTYPE_HEAD"}, -- "Lightning-Charged Headguard"
  [60304] = {4,359,"INVTYPE_CHEST"}, -- "Lightning-Charged Tunic"
  [60305] = {4,359,"INVTYPE_LEGS"}, -- "Lightning-Charged Legguards"
  [60306] = {4,359,"INVTYPE_SHOULDER"}, -- "Lightning-Charged Spaulders"
  [60307] = {4,359,"INVTYPE_HAND"}, -- "Lightning-Charged Gloves"
  [60308] = {4,359,"INVTYPE_HEAD"}, -- "Faceguard of the Raging Elements"
  [60309] = {4,359,"INVTYPE_CHEST"}, -- "Tunic of the Raging Elements"
  [60310] = {4,359,"INVTYPE_LEGS"}, -- "Legwraps of the Raging Elements"
  [60311] = {4,359,"INVTYPE_SHOULDER"}, -- "Mantle of the Raging Elements"
  [60312] = {4,359,"INVTYPE_HAND"}, -- "Handwraps of the Raging Elements"
  [60313] = {4,359,"INVTYPE_CHEST"}, -- "Hauberk of the Raging Elements"
  [60314] = {4,359,"INVTYPE_HAND"}, -- "Gloves of the Raging Elements"
  [60315] = {4,359,"INVTYPE_HEAD"}, -- "Headpiece of the Raging Elements"
  [60316] = {4,359,"INVTYPE_LEGS"}, -- "Kilt of the Raging Elements"
  [60317] = {4,359,"INVTYPE_SHOULDER"}, -- "Shoulderwraps of the Raging Elements"
  [60318] = {4,359,"INVTYPE_CHEST"}, -- "Cuirass of the Raging Elements"
  [60319] = {4,359,"INVTYPE_HAND"}, -- "Grips of the Raging Elements"
  [60320] = {4,359,"INVTYPE_HEAD"}, -- "Helmet of the Raging Elements"
  [60321] = {4,359,"INVTYPE_LEGS"}, -- "Legguards of the Raging Elements"
  [60322] = {4,359,"INVTYPE_SHOULDER"}, -- "Spaulders of the Raging Elements"
  [60323] = {4,359,"INVTYPE_CHEST"}, -- "Earthen Battleplate"
  [60324] = {4,359,"INVTYPE_LEGS"}, -- "Earthen Legplates"
  [60325] = {4,359,"INVTYPE_HEAD"}, -- "Earthen Helmet"
  [60326] = {4,359,"INVTYPE_HAND"}, -- "Earthen Gauntlets"
  [60327] = {4,359,"INVTYPE_SHOULDER"}, -- "Earthen Pauldrons"
  [60328] = {4,359,"INVTYPE_HEAD"}, -- "Earthen Faceguard"
  [60329] = {4,359,"INVTYPE_CHEST"}, -- "Earthen Chestguard"
  [60330] = {4,359,"INVTYPE_LEGS"}, -- "Earthen Legguards"
  [60331] = {4,359,"INVTYPE_SHOULDER"}, -- "Earthen Shoulderguards"
  [60332] = {4,359,"INVTYPE_HAND"}, -- "Earthen Handguards"
  [60339] = {4,359,"INVTYPE_CHEST"}, -- "Magma Plated Battleplate"
  [60340] = {4,359,"INVTYPE_HAND"}, -- "Magma Plated Gauntlets"
  [60341] = {4,359,"INVTYPE_HEAD"}, -- "Magma Plated Helmet"
  [60342] = {4,359,"INVTYPE_LEGS"}, -- "Magma Plated Legplates"
  [60343] = {4,359,"INVTYPE_SHOULDER"}, -- "Magma Plated Pauldrons"
  [60344] = {4,359,"INVTYPE_CHEST"}, -- "Reinforced Sapphirium Battleplate"
  [60345] = {4,359,"INVTYPE_HAND"}, -- "Reinforced Sapphirium Gauntlets"
  [60346] = {4,359,"INVTYPE_HEAD"}, -- "Reinforced Sapphirium Helmet"
  [60347] = {4,359,"INVTYPE_LEGS"}, -- "Reinforced Sapphirium Legplates"
  [60348] = {4,359,"INVTYPE_SHOULDER"}, -- "Reinforced Sapphirium Pauldrons"
  [60349] = {4,359,"INVTYPE_CHEST"}, -- "Magma Plated Chestguard"
  [60350] = {4,359,"INVTYPE_HAND"}, -- "Magma Plated Handguards"
  [60351] = {4,359,"INVTYPE_HEAD"}, -- "Magma Plated Faceguard"
  [60352] = {4,359,"INVTYPE_LEGS"}, -- "Magma Plated Legguards"
  [60353] = {4,359,"INVTYPE_SHOULDER"}, -- "Magma Plated Shoulderguards"
  [60354] = {4,359,"INVTYPE_CHEST"}, -- "Reinforced Sapphirium Chestguard"
  [60355] = {4,359,"INVTYPE_HAND"}, -- "Reinforced Sapphirium Handguards"
  [60356] = {4,359,"INVTYPE_HEAD"}, -- "Reinforced Sapphirium Faceguard"
  [60357] = {4,359,"INVTYPE_LEGS"}, -- "Reinforced Sapphirium Legguards"
  [60358] = {4,359,"INVTYPE_SHOULDER"}, -- "Reinforced Sapphirium Shoulderguards"
  [60359] = {4,359,"INVTYPE_HEAD"}, -- "Reinforced Sapphirium Headguard"
  [60360] = {4,359,"INVTYPE_CHEST"}, -- "Reinforced Sapphirium Breastplate"
  [60361] = {4,359,"INVTYPE_LEGS"}, -- "Reinforced Sapphirium Greaves"
  [60362] = {4,359,"INVTYPE_SHOULDER"}, -- "Reinforced Sapphirium Mantle"
  [60363] = {4,359,"INVTYPE_HAND"}, -- "Reinforced Sapphirium Gloves"
  [60524] = {4,365,"INVTYPE_WRIST"}, -- "Vicious Gladiator's Bracers of Triumph"
  [60794] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Cruelty"
  [60795] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Accuracy"
  [60796] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Alacrity"
  [60797] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Prowess"
  [60798] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Command"
  [60799] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Meditation"
  [60801] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Cruelty"
  [60802] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Accuracy"
  [60803] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Alacrity"
  [60804] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Prowess"
  [60805] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Command"
  [60806] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Meditation"
  [61026] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Cruelty"
  [61027] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Accuracy"
  [61028] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Alacrity"
  [61029] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Prowess"
  [61030] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Proficiency"
  [61031] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Meditation"
  [62047] = {4,359,"INVTYPE_TRINKET"}, -- "Darkmoon Card: Volcano"
  [62048] = {4,359,"INVTYPE_TRINKET"}, -- "Darkmoon Card: Earthquake"
  [62049] = {4,359,"INVTYPE_TRINKET"}, -- "Darkmoon Card: Hurricane"
  [62050] = {4,359,"INVTYPE_TRINKET"}, -- "Darkmoon Card: Tsunami"
  [62051] = {4,359,"INVTYPE_TRINKET"}, -- "Darkmoon Card: Hurricane"
  [62362] = {4,359,"INVTYPE_FINGER"}, -- "Signet of the Elder Council"
  [62363] = {4,359,"INVTYPE_FEET"}, -- "Earthmender's Boots"
  [62364] = {4,359,"INVTYPE_HAND"}, -- "Flamebloom Gloves"
  [62365] = {4,359,"INVTYPE_HAND"}, -- "World Keeper's Gauntlets"
  [62383] = {4,359,"INVTYPE_CLOAK"}, -- "Wrap of the Great Turtle"
  [62384] = {4,359,"INVTYPE_WAIST"}, -- "Belt of the Ferocious Wolf"
  [62385] = {4,359,"INVTYPE_FEET"}, -- "Treads of Malorne"
  [62386] = {4,359,"INVTYPE_WAIST"}, -- "Cord of the Raven Queen"
  [62416] = {4,359,"INVTYPE_NECK"}, -- "Yellow Smoke Pendant"
  [62417] = {4,359,"INVTYPE_HAND"}, -- "Liar's Handwraps"
  [62418] = {4,359,"INVTYPE_FEET"}, -- "Boots of Sullen Rock"
  [62420] = {4,359,"INVTYPE_WAIST"}, -- "Withered Dream Belt"
  [62431] = {4,359,"INVTYPE_WAIST"}, -- "Belt of the Untamed"
  [62432] = {4,359,"INVTYPE_FEET"}, -- "Gryphon Rider's Boots"
  [62433] = {4,359,"INVTYPE_HAND"}, -- "Stormbolt Gloves"
  [62434] = {4,359,"INVTYPE_NECK"}, -- "Lightning Flash Pendant"
  [62447] = {4,359,"INVTYPE_NECK"}, -- "Gift of Nadun"
  [62448] = {4,359,"INVTYPE_WAIST"}, -- "Sun King's Girdle"
  [62449] = {4,359,"INVTYPE_WRIST"}, -- "Sandguard Bracers"
  [62450] = {4,359,"INVTYPE_FEET"}, -- "Desert Walker Sandals"
  [62463] = {4,359,"INVTYPE_TRINKET"}, -- "Unsolvable Riddle"
  [62464] = {4,359,"INVTYPE_TRINKET"}, -- "Impatience of Youth"
  [62465] = {4,359,"INVTYPE_TRINKET"}, -- "Stump of Time"
  [62466] = {4,359,"INVTYPE_TRINKET"}, -- "Mirror of Broken Images"
  [62467] = {4,359,"INVTYPE_TRINKET"}, -- "Mandala of Stirring Patterns"
  [62468] = {4,359,"INVTYPE_TRINKET"}, -- "Unsolvable Riddle"
  [62469] = {4,359,"INVTYPE_TRINKET"}, -- "Impatience of Youth"
  [62470] = {4,359,"INVTYPE_TRINKET"}, -- "Stump of Time"
  [62471] = {4,359,"INVTYPE_TRINKET"}, -- "Mirror of Broken Images"
  [62472] = {4,359,"INVTYPE_TRINKET"}, -- "Mandala of Stirring Patterns"
  [63093] = {4,359,"INVTYPE_SHOULDER"}, -- "Twilight's Hammer Shoulders"
  [63488] = {4,359,"INVTYPE_FINGER"}, -- "Mistral Circle"
  [63489] = {4,359,"INVTYPE_FINGER"}, -- "Permafrost Signet"
  [63490] = {4,359,"INVTYPE_WAIST"}, -- "Sky Strider Belt"
  [63491] = {4,359,"INVTYPE_WAIST"}, -- "Thunder Wall Belt"
  [63492] = {4,359,"INVTYPE_WAIST"}, -- "Star Chaser Belt"
  [63493] = {4,359,"INVTYPE_WAIST"}, -- "Wind Stalker Belt"
  [63494] = {4,359,"INVTYPE_FINGER"}, -- "Planetary Band"
  [63495] = {4,359,"INVTYPE_WAIST"}, -- "Tempest Keeper Belt"
  [63496] = {4,359,"INVTYPE_WAIST"}, -- "Lightning Well Belt"
  [63497] = {4,359,"INVTYPE_WAIST"}, -- "Gale Rouser Belt"
  [63498] = {4,359,"INVTYPE_WAIST"}, -- "Soul Breath Belt"
  [63499] = {4,359,"INVTYPE_FINGER"}, -- "Cloudburst Ring"
  [63500] = {4,359,"INVTYPE_LEGS"}, -- "Sky Strider Greaves"
  [63501] = {4,359,"INVTYPE_LEGS"}, -- "Thunder Wall Greaves"
  [63502] = {4,359,"INVTYPE_LEGS"}, -- "Star Chaser Legguards"
  [63503] = {4,359,"INVTYPE_LEGS"}, -- "Wind Stalker Leggings"
  [63504] = {4,359,"INVTYPE_LEGS"}, -- "Tempest Keeper Leggings"
  [63505] = {4,359,"INVTYPE_LEGS"}, -- "Lightning Well Legguards"
  [63506] = {4,359,"INVTYPE_LEGS"}, -- "Gale Rouser Leggings"
  [63507] = {4,359,"INVTYPE_LEGS"}, -- "Soul Breath Leggings"
  [63531] = {4,359,"INVTYPE_HEAD"}, -- "Daybreaker Helm"
  [63532] = {4,359,"INVTYPE_RANGEDRIGHT"}, -- "Dragonheart Piercer"
  [63533] = {4,359,"INVTYPE_WEAPON"}, -- "Fang of Twilight"
  [63534] = {4,359,"INVTYPE_HEAD"}, -- "Helm of Eldritch Authority"
  [63535] = {4,359,"INVTYPE_WAIST"}, -- "Waistguard of Hatred"
  [63536] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Blade of the Witching Hour"
  [63537] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Claws of Torment"
  [63538] = {4,359,"INVTYPE_WEAPONOFFHAND"}, -- "Claws of Agony"
  [63540] = {4,359,"INVTYPE_CHEST"}, -- "Circuit Design Breastplate"
  [63679] = {4,359,"INVTYPE_2HWEAPON"}, -- "Reclaimed Ashkandi, Greatsword of the Brotherhood"
  [63680] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Twilight's Hammer"
  [64377] = {4,359,"INVTYPE_2HWEAPON"}, -- "Zin'rokh, Destroyer of Worlds"
  [64489] = {4,359,"INVTYPE_2HWEAPON"}, -- "Staff of Sorcerer-Thane Thaurissan"
  [64645] = {4,359,"INVTYPE_TRINKET"}, -- "Tyrande's Favorite Doll"
  [64671] = {4,359,"INVTYPE_RELIC"}, -- "Relic of Golganneth"
  [64672] = {4,359,"INVTYPE_RELIC"}, -- "Relic of Norgannon"
  [64673] = {4,359,"INVTYPE_RELIC"}, -- "Relic of Eonar"
  [64674] = {4,359,"INVTYPE_RELIC"}, -- "Relic of Aggramar"
  [64676] = {4,359,"INVTYPE_RELIC"}, -- "Relic of Khaz'goroth"
  [64880] = {4,359,"INVTYPE_2HWEAPON"}, -- "Staff of Ammunae"
  [64885] = {4,359,"INVTYPE_WEAPON"}, -- "Scimitar of the Sirocco"
  [64904] = {4,359,"INVTYPE_FINGER"}, -- "Ring of the Boy Emperor"
  [65003] = {4,372,"INVTYPE_2HWEAPON"}, -- "Reclaimed Ashkandi, Greatsword of the Brotherhood"
  [65004] = {4,372,"INVTYPE_CHEST"}, -- "Circuit Design Breastplate"
  [65005] = {4,372,"INVTYPE_WEAPONOFFHAND"}, -- "Claws of Agony"
  [65006] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Claws of Torment"
  [65007] = {4,372,"INVTYPE_2HWEAPON"}, -- "Akirus the Worm-Breaker"
  [65008] = {4,372,"INVTYPE_ROBE"}, -- "Shadowforge's Lightbound Smock"
  [65009] = {4,372,"INVTYPE_SHOULDER"}, -- "Hide of Chromaggus"
  [65010] = {4,372,"INVTYPE_CLOAK"}, -- "Ironstar's Impenetrable Cover"
  [65011] = {4,372,"INVTYPE_WAIST"}, -- "Corehammer's Riveted Girdle"
  [65012] = {4,372,"INVTYPE_FEET"}, -- "Treads of Savage Beatings"
  [65013] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Maldo's Sword Cane"
  [65014] = {4,372,"INVTYPE_WEAPONOFFHAND"}, -- "Maimgor's Bite"
  [65016] = {4,372,"INVTYPE_RANGEDRIGHT"}, -- "Theresa's Booklight"
  [65017] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Andoros, Fist of the Dragon King"
  [65018] = {4,372,"INVTYPE_CLOAK"}, -- "Shadow of Dread"
  [65019] = {4,372,"INVTYPE_ROBE"}, -- "Shadowblaze Robes"
  [65020] = {4,372,"INVTYPE_HEAD"}, -- "Crown of Burning Waters"
  [65021] = {4,372,"INVTYPE_WRIST"}, -- "Manacles of the Sleeping Beast"
  [65022] = {4,372,"INVTYPE_WAIST"}, -- "Belt of the Blackhand"
  [65023] = {4,372,"INVTYPE_SHIELD"}, -- "Akmin-Kurai, Dominion's Shield"
  [65024] = {4,372,"INVTYPE_WEAPON"}, -- "Crul'korak, the Lightning's Arc"
  [65025] = {4,372,"INVTYPE_NECK"}, -- "Rage of Ages"
  [65026] = {4,372,"INVTYPE_TRINKET"}, -- "Prestor's Talisman of Machination"
  [65027] = {4,372,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Apocalypse"
  [65028] = {4,372,"INVTYPE_WRIST"}, -- "Chimaeron Armguards"
  [65029] = {4,372,"INVTYPE_TRINKET"}, -- "Jar of Ancient Remedies"
  [65030] = {4,372,"INVTYPE_LEGS"}, -- "Leggings of Consuming Flames"
  [65031] = {4,372,"INVTYPE_HAND"}, -- "Flash Freeze Gauntlets"
  [65032] = {4,372,"INVTYPE_LEGS"}, -- "Legwraps of the Greatest Son"
  [65033] = {4,372,"INVTYPE_FEET"}, -- "Treads of Flawless Creation"
  [65034] = {4,372,"INVTYPE_WAIST"}, -- "Belt of Arcane Storms"
  [65035] = {4,372,"INVTYPE_CLOAK"}, -- "Cloak of Biting Chill"
  [65036] = {4,372,"INVTYPE_WEAPON"}, -- "Mace of Acrid Death"
  [65037] = {4,372,"INVTYPE_CHEST"}, -- "Tunic of Failed Experiments"
  [65038] = {4,372,"INVTYPE_HEAD"}, -- "Dragon Bone Warhelm"
  [65039] = {4,372,"INVTYPE_LEGS"}, -- "Aberration's Leggings"
  [65040] = {4,372,"INVTYPE_WAIST"}, -- "Belt of Absolute Zero"
  [65041] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Incineratus"
  [65042] = {4,372,"INVTYPE_CHEST"}, -- "Breastplate of Avenging Flame"
  [65043] = {4,372,"INVTYPE_SHOULDER"}, -- "Mantle of Nefarius"
  [65044] = {4,372,"INVTYPE_LEGS"}, -- "Flame Pillar Leggings"
  [65045] = {4,372,"INVTYPE_ROBE"}, -- "Scorched Wormling Vest"
  [65046] = {4,372,"INVTYPE_WAIST"}, -- "Lifecycle Waistguard"
  [65047] = {4,372,"INVTYPE_WEAPON"}, -- "Lava Spine"
  [65048] = {4,372,"INVTYPE_TRINKET"}, -- "Symbiotic Worm"
  [65049] = {4,372,"INVTYPE_LEGS"}, -- "Leggings of Lethal Force"
  [65050] = {4,372,"INVTYPE_WRIST"}, -- "Parasitic Bands"
  [65051] = {4,372,"INVTYPE_FEET"}, -- "Molten Tantrum Boots"
  [65052] = {4,372,"INVTYPE_SHIELD"}, -- "Kingdom's Heart"
  [65053] = {4,372,"INVTYPE_TRINKET"}, -- "Bell of Enraging Resonance"
  [65054] = {4,372,"INVTYPE_SHOULDER"}, -- "Mantle of Roaring Flames"
  [65055] = {4,372,"INVTYPE_HAND"}, -- "Gloves of Cacophony"
  [65056] = {4,372,"INVTYPE_WRIST"}, -- "Bracers of the Burningeye"
  [65057] = {4,372,"INVTYPE_WAIST"}, -- "Belt of the Nightmare"
  [65058] = {4,372,"INVTYPE_RANGED"}, -- "Themios the Darkbringer"
  [65059] = {4,372,"INVTYPE_NECK"}, -- "Ironstar Amulet"
  [65060] = {4,372,"INVTYPE_CHEST"}, -- "Sark of the Unwatched"
  [65061] = {4,372,"INVTYPE_LEGS"}, -- "Legguards of the Unseeing"
  [65062] = {4,372,"INVTYPE_CHEST"}, -- "Battleplate of Ancient Kings"
  [65063] = {4,372,"INVTYPE_FEET"}, -- "Boots of Vertigo"
  [65064] = {4,372,"INVTYPE_RANGEDRIGHT"}, -- "Finkle's Mixer Upper"
  [65065] = {4,372,"INVTYPE_HAND"}, -- "Brackish Gloves"
  [65066] = {4,372,"INVTYPE_HEAD"}, -- "Helm of the Blind Seer"
  [65067] = {4,372,"INVTYPE_SHOULDER"}, -- "Burden of Mortality"
  [65068] = {4,372,"INVTYPE_WRIST"}, -- "Chaos Beast Bracers"
  [65069] = {4,372,"INVTYPE_FEET"}, -- "Einhorn's Galoshes"
  [65070] = {4,372,"INVTYPE_FINGER"}, -- "Bile-O-Tron Nut"
  [65071] = {4,372,"INVTYPE_HAND"}, -- "Plated Fists of Provocation"
  [65072] = {4,372,"INVTYPE_TRINKET"}, -- "Heart of Rage"
  [65073] = {4,372,"INVTYPE_HAND"}, -- "Double Attack Handguards"
  [65074] = {4,372,"INVTYPE_SHOULDER"}, -- "Spaulders of the Scarred Lady"
  [65075] = {4,372,"INVTYPE_FEET"}, -- "Massacre Treads"
  [65076] = {4,372,"INVTYPE_FINGER"}, -- "Security Measure Alpha"
  [65077] = {4,372,"INVTYPE_HEAD"}, -- "Power Generator Hood"
  [65078] = {4,372,"INVTYPE_SHOULDER"}, -- "Passive Resistor Spaulders"
  [65079] = {4,372,"INVTYPE_WAIST"}, -- "X-Tron Duct Tape"
  [65080] = {4,372,"INVTYPE_FEET"}, -- "Life Force Chargers"
  [65081] = {4,372,"INVTYPE_WEAPON"}, -- "Organic Lifeform Inverter"
  [65082] = {4,372,"INVTYPE_FINGER"}, -- "Lightning Conductor Band"
  [65083] = {4,372,"INVTYPE_SHOULDER"}, -- "Poison Protocol Pauldrons"
  [65084] = {4,372,"INVTYPE_CHEST"}, -- "Voltage Source Chestguard"
  [65085] = {4,372,"INVTYPE_WRIST"}, -- "Electron Inductor Coils"
  [65086] = {4,372,"INVTYPE_WAIST"}, -- "Jumbotron Power Belt"
  [65090] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Twilight's Hammer"
  [65091] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Blade of the Witching Hour"
  [65092] = {4,372,"INVTYPE_WAIST"}, -- "Waistguard of Hatred"
  [65093] = {4,372,"INVTYPE_HEAD"}, -- "Helm of Eldritch Authority"
  [65094] = {4,372,"INVTYPE_WEAPON"}, -- "Fang of Twilight"
  [65095] = {4,372,"INVTYPE_RANGEDRIGHT"}, -- "Dragonheart Piercer"
  [65096] = {4,372,"INVTYPE_HEAD"}, -- "Daybreaker Helm"
  [65097] = {4,372,"INVTYPE_WRIST"}, -- "Bracers of the Dark Pool"
  [65098] = {4,372,"INVTYPE_RANGEDRIGHT"}, -- "Crossfire Carbine"
  [65099] = {4,372,"INVTYPE_HEAD"}, -- "Tsanga's Helm"
  [65100] = {4,372,"INVTYPE_LEGS"}, -- "Phase-Twister Leggings"
  [65101] = {4,372,"INVTYPE_SHOULDER"}, -- "Heaving Plates of Protection"
  [65102] = {4,372,"INVTYPE_2HWEAPON"}, -- "Chelley's Staff of Dark Mending"
  [65103] = {4,372,"INVTYPE_WEAPON"}, -- "Soul Blade"
  [65105] = {4,372,"INVTYPE_TRINKET"}, -- "Theralion's Mirror"
  [65106] = {4,372,"INVTYPE_FINGER"}, -- "Ring of Rivalry"
  [65107] = {4,372,"INVTYPE_NECK"}, -- "Necklace of Strife"
  [65108] = {4,372,"INVTYPE_CLOAK"}, -- "Drape of the Twins"
  [65109] = {4,372,"INVTYPE_TRINKET"}, -- "Vial of Stolen Memories"
  [65110] = {4,372,"INVTYPE_TRINKET"}, -- "Heart of Ignacious"
  [65111] = {4,372,"INVTYPE_HOLDABLE"}, -- "Scepter of Ice"
  [65112] = {4,372,"INVTYPE_NECK"}, -- "Valiona's Medallion"
  [65113] = {4,372,"INVTYPE_HAND"}, -- "Hydrolance Gloves"
  [65114] = {4,372,"INVTYPE_SHOULDER"}, -- "Feludius' Mantle"
  [65115] = {4,372,"INVTYPE_HEAD"}, -- "Glaciated Helm"
  [65116] = {4,372,"INVTYPE_FEET"}, -- "Treads of Liquid Ice"
  [65117] = {4,372,"INVTYPE_CLOAK"}, -- "Glittering Epidermis"
  [65118] = {4,372,"INVTYPE_TRINKET"}, -- "Crushing Weight"
  [65119] = {4,372,"INVTYPE_HAND"}, -- "Gravitational Pull"
  [65120] = {4,372,"INVTYPE_HEAD"}, -- "Arion's Crown"
  [65121] = {4,372,"INVTYPE_LEGS"}, -- "Terrastra's Legguards"
  [65122] = {4,372,"INVTYPE_WAIST"}, -- "Dispersing Belt"
  [65123] = {4,372,"INVTYPE_FINGER"}, -- "Signet of the Fifth Circle"
  [65124] = {4,372,"INVTYPE_TRINKET"}, -- "Fall of Mortality"
  [65125] = {4,372,"INVTYPE_LEGS"}, -- "Kilt of the Forgotten Battle"
  [65126] = {4,372,"INVTYPE_HAND"}, -- "Hands of the Twilight Council"
  [65127] = {4,372,"INVTYPE_WRIST"}, -- "Shackles of the End of Days"
  [65128] = {4,372,"INVTYPE_FEET"}, -- "Treads of Hideous Transformation"
  [65129] = {4,372,"INVTYPE_HEAD"}, -- "Membrane of C'Thun"
  [65130] = {4,372,"INVTYPE_HEAD"}, -- "Helm of Maddening Whispers"
  [65131] = {4,372,"INVTYPE_CHEST"}, -- "Battleplate of the Apocalypse"
  [65132] = {4,372,"INVTYPE_WAIST"}, -- "Coil of Ten-Thousand Screams"
  [65133] = {4,372,"INVTYPE_HOLDABLE"}, -- "Book of Binding Will"
  [65134] = {4,372,"INVTYPE_NECK"}, -- "Wyrmbreaker's Amulet"
  [65135] = {4,372,"INVTYPE_ROBE"}, -- "Robes of the Burning Acolyte"
  [65136] = {4,372,"INVTYPE_HEAD"}, -- "Helm of the Nether Scion"
  [65137] = {4,372,"INVTYPE_LEGS"}, -- "Legguards of the Emerald Brood"
  [65138] = {4,372,"INVTYPE_WRIST"}, -- "Bracers of the Bronze Flight"
  [65139] = {4,372,"INVTYPE_2HWEAPON"}, -- "Malevolence"
  [65140] = {4,372,"INVTYPE_TRINKET"}, -- "Essence of the Cyclone"
  [65141] = {4,372,"INVTYPE_HAND"}, -- "Proto-Handler's Gauntlets"
  [65142] = {4,372,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Great Ettin"
  [65143] = {4,372,"INVTYPE_WRIST"}, -- "Bracers of Impossible Strength"
  [65144] = {4,372,"INVTYPE_FEET"}, -- "Storm Rider's Boots"
  [65145] = {4,372,"INVTYPE_2HWEAPON"}, -- "Shalug'doom, the Axe of Unmaking"
  [65179] = {4,372,"INVTYPE_CHEST"}, -- "Magma Plated Battleplate"
  [65180] = {4,372,"INVTYPE_HAND"}, -- "Magma Plated Gauntlets"
  [65181] = {4,372,"INVTYPE_HEAD"}, -- "Magma Plated Helmet"
  [65182] = {4,372,"INVTYPE_LEGS"}, -- "Magma Plated Legplates"
  [65183] = {4,372,"INVTYPE_SHOULDER"}, -- "Magma Plated Pauldrons"
  [65184] = {4,372,"INVTYPE_CHEST"}, -- "Magma Plated Chestguard"
  [65185] = {4,372,"INVTYPE_HAND"}, -- "Magma Plated Handguards"
  [65186] = {4,372,"INVTYPE_HEAD"}, -- "Magma Plated Faceguard"
  [65187] = {4,372,"INVTYPE_LEGS"}, -- "Magma Plated Legguards"
  [65188] = {4,372,"INVTYPE_SHOULDER"}, -- "Magma Plated Shoulderguards"
  [65189] = {4,372,"INVTYPE_HAND"}, -- "Stormrider's Grips"
  [65190] = {4,372,"INVTYPE_HEAD"}, -- "Stormrider's Headpiece"
  [65191] = {4,372,"INVTYPE_LEGS"}, -- "Stormrider's Legguards"
  [65192] = {4,372,"INVTYPE_ROBE"}, -- "Stormrider's Raiment"
  [65193] = {4,372,"INVTYPE_SHOULDER"}, -- "Stormrider's Spaulders"
  [65194] = {4,372,"INVTYPE_HAND"}, -- "Stormrider's Handwraps"
  [65195] = {4,372,"INVTYPE_HEAD"}, -- "Stormrider's Helm"
  [65196] = {4,372,"INVTYPE_LEGS"}, -- "Stormrider's Legwraps"
  [65197] = {4,372,"INVTYPE_ROBE"}, -- "Stormrider's Robes"
  [65198] = {4,372,"INVTYPE_SHOULDER"}, -- "Stormrider's Mantle"
  [65199] = {4,372,"INVTYPE_HAND"}, -- "Stormrider's Gloves"
  [65200] = {4,372,"INVTYPE_HEAD"}, -- "Stormrider's Cover"
  [65201] = {4,372,"INVTYPE_LEGS"}, -- "Stormrider's Leggings"
  [65202] = {4,372,"INVTYPE_ROBE"}, -- "Stormrider's Vestment"
  [65203] = {4,372,"INVTYPE_SHOULDER"}, -- "Stormrider's Shoulderwraps"
  [65204] = {4,372,"INVTYPE_CHEST"}, -- "Lightning-Charged Tunic"
  [65205] = {4,372,"INVTYPE_HAND"}, -- "Lightning-Charged Gloves"
  [65206] = {4,372,"INVTYPE_HEAD"}, -- "Lightning-Charged Headguard"
  [65207] = {4,372,"INVTYPE_LEGS"}, -- "Lightning-Charged Legguards"
  [65208] = {4,372,"INVTYPE_SHOULDER"}, -- "Lightning-Charged Spaulders"
  [65209] = {4,372,"INVTYPE_HAND"}, -- "Firelord's Gloves"
  [65210] = {4,372,"INVTYPE_HEAD"}, -- "Firelord's Hood"
  [65211] = {4,372,"INVTYPE_LEGS"}, -- "Firelord's Leggings"
  [65212] = {4,372,"INVTYPE_ROBE"}, -- "Firelord's Robes"
  [65213] = {4,372,"INVTYPE_SHOULDER"}, -- "Firelord's Mantle"
  [65214] = {4,372,"INVTYPE_CHEST"}, -- "Reinforced Sapphirium Battleplate"
  [65215] = {4,372,"INVTYPE_HAND"}, -- "Reinforced Sapphirium Gauntlets"
  [65216] = {4,372,"INVTYPE_HEAD"}, -- "Reinforced Sapphirium Helmet"
  [65217] = {4,372,"INVTYPE_LEGS"}, -- "Reinforced Sapphirium Legplates"
  [65218] = {4,372,"INVTYPE_SHOULDER"}, -- "Reinforced Sapphirium Pauldrons"
  [65219] = {4,372,"INVTYPE_CHEST"}, -- "Reinforced Sapphirium Breastplate"
  [65220] = {4,372,"INVTYPE_HAND"}, -- "Reinforced Sapphirium Gloves"
  [65221] = {4,372,"INVTYPE_HEAD"}, -- "Reinforced Sapphirium Headguard"
  [65222] = {4,372,"INVTYPE_LEGS"}, -- "Reinforced Sapphirium Greaves"
  [65223] = {4,372,"INVTYPE_SHOULDER"}, -- "Reinforced Sapphirium Mantle"
  [65224] = {4,372,"INVTYPE_CHEST"}, -- "Reinforced Sapphirium Chestguard"
  [65225] = {4,372,"INVTYPE_HAND"}, -- "Reinforced Sapphirium Handguards"
  [65226] = {4,372,"INVTYPE_HEAD"}, -- "Reinforced Sapphirium Faceguard"
  [65227] = {4,372,"INVTYPE_LEGS"}, -- "Reinforced Sapphirium Legguards"
  [65228] = {4,372,"INVTYPE_SHOULDER"}, -- "Reinforced Sapphirium Shoulderguards"
  [65229] = {4,372,"INVTYPE_HAND"}, -- "Mercurial Handwraps"
  [65230] = {4,372,"INVTYPE_HEAD"}, -- "Mercurial Cowl"
  [65231] = {4,372,"INVTYPE_LEGS"}, -- "Mercurial Legwraps"
  [65232] = {4,372,"INVTYPE_ROBE"}, -- "Mercurial Robes"
  [65233] = {4,372,"INVTYPE_SHOULDER"}, -- "Mercurial Mantle"
  [65234] = {4,372,"INVTYPE_HAND"}, -- "Mercurial Gloves"
  [65235] = {4,372,"INVTYPE_HEAD"}, -- "Mercurial Hood"
  [65236] = {4,372,"INVTYPE_LEGS"}, -- "Mercurial Leggings"
  [65237] = {4,372,"INVTYPE_ROBE"}, -- "Mercurial Vestment"
  [65238] = {4,372,"INVTYPE_SHOULDER"}, -- "Mercurial Shoulderwraps"
  [65239] = {4,372,"INVTYPE_CHEST"}, -- "Wind Dancer's Tunic"
  [65240] = {4,372,"INVTYPE_HAND"}, -- "Wind Dancer's Gloves"
  [65241] = {4,372,"INVTYPE_HEAD"}, -- "Wind Dancer's Helmet"
  [65242] = {4,372,"INVTYPE_LEGS"}, -- "Wind Dancer's Legguards"
  [65243] = {4,372,"INVTYPE_SHOULDER"}, -- "Wind Dancer's Spaulders"
  [65244] = {4,372,"INVTYPE_CHEST"}, -- "Tunic of the Raging Elements"
  [65245] = {4,372,"INVTYPE_HAND"}, -- "Handwraps of the Raging Elements"
  [65246] = {4,372,"INVTYPE_HEAD"}, -- "Faceguard of the Raging Elements"
  [65247] = {4,372,"INVTYPE_LEGS"}, -- "Legwraps of the Raging Elements"
  [65248] = {4,372,"INVTYPE_SHOULDER"}, -- "Mantle of the Raging Elements"
  [65249] = {4,372,"INVTYPE_CHEST"}, -- "Cuirass of the Raging Elements"
  [65250] = {4,372,"INVTYPE_HAND"}, -- "Grips of the Raging Elements"
  [65251] = {4,372,"INVTYPE_HEAD"}, -- "Helmet of the Raging Elements"
  [65252] = {4,372,"INVTYPE_LEGS"}, -- "Legguards of the Raging Elements"
  [65253] = {4,372,"INVTYPE_SHOULDER"}, -- "Spaulders of the Raging Elements"
  [65254] = {4,372,"INVTYPE_CHEST"}, -- "Hauberk of the Raging Elements"
  [65255] = {4,372,"INVTYPE_HAND"}, -- "Gloves of the Raging Elements"
  [65256] = {4,372,"INVTYPE_HEAD"}, -- "Headpiece of the Raging Elements"
  [65257] = {4,372,"INVTYPE_LEGS"}, -- "Kilt of the Raging Elements"
  [65258] = {4,372,"INVTYPE_SHOULDER"}, -- "Shoulderwraps of the Raging Elements"
  [65259] = {4,372,"INVTYPE_HAND"}, -- "Shadowflame Handwraps"
  [65260] = {4,372,"INVTYPE_HEAD"}, -- "Shadowflame Hood"
  [65261] = {4,372,"INVTYPE_LEGS"}, -- "Shadowflame Leggings"
  [65262] = {4,372,"INVTYPE_ROBE"}, -- "Shadowflame Robes"
  [65263] = {4,372,"INVTYPE_SHOULDER"}, -- "Shadowflame Mantle"
  [65264] = {4,372,"INVTYPE_CHEST"}, -- "Earthen Battleplate"
  [65265] = {4,372,"INVTYPE_HAND"}, -- "Earthen Gauntlets"
  [65266] = {4,372,"INVTYPE_HEAD"}, -- "Earthen Helmet"
  [65267] = {4,372,"INVTYPE_LEGS"}, -- "Earthen Legplates"
  [65268] = {4,372,"INVTYPE_SHOULDER"}, -- "Earthen Pauldrons"
  [65269] = {4,372,"INVTYPE_CHEST"}, -- "Earthen Chestguard"
  [65270] = {4,372,"INVTYPE_HAND"}, -- "Earthen Handguards"
  [65271] = {4,372,"INVTYPE_HEAD"}, -- "Earthen Faceguard"
  [65272] = {4,372,"INVTYPE_LEGS"}, -- "Earthen Legguards"
  [65273] = {4,372,"INVTYPE_SHOULDER"}, -- "Earthen Shoulderguards"
  [65274] = {4,359,"INVTYPE_CLOAK"}, -- "Cloak of Coordination"
  [65360] = {4,359,"INVTYPE_CLOAK"}, -- "Cloak of Coordination"
  [65367] = {4,372,"INVTYPE_FINGER"}, -- "Mistral Circle"
  [65368] = {4,372,"INVTYPE_WAIST"}, -- "Star Chaser Belt"
  [65369] = {4,372,"INVTYPE_WAIST"}, -- "Sky Strider Belt"
  [65370] = {4,372,"INVTYPE_WAIST"}, -- "Thunder Wall Belt"
  [65371] = {4,372,"INVTYPE_WAIST"}, -- "Wind Stalker Belt"
  [65372] = {4,372,"INVTYPE_FINGER"}, -- "Permafrost Signet"
  [65373] = {4,372,"INVTYPE_FINGER"}, -- "Planetary Band"
  [65374] = {4,372,"INVTYPE_WAIST"}, -- "Gale Rouser Belt"
  [65375] = {4,372,"INVTYPE_WAIST"}, -- "Tempest Keeper Belt"
  [65376] = {4,372,"INVTYPE_WAIST"}, -- "Soul Breath Belt"
  [65377] = {4,372,"INVTYPE_WAIST"}, -- "Lightning Well Belt"
  [65378] = {4,372,"INVTYPE_LEGS"}, -- "Star Chaser Legguards"
  [65379] = {4,372,"INVTYPE_LEGS"}, -- "Sky Strider Greaves"
  [65380] = {4,372,"INVTYPE_LEGS"}, -- "Thunder Wall Greaves"
  [65381] = {4,372,"INVTYPE_LEGS"}, -- "Wind Stalker Leggings"
  [65382] = {4,372,"INVTYPE_FINGER"}, -- "Cloudburst Ring"
  [65383] = {4,372,"INVTYPE_LEGS"}, -- "Soul Breath Leggings"
  [65384] = {4,372,"INVTYPE_LEGS"}, -- "Gale Rouser Leggings"
  [65385] = {4,372,"INVTYPE_LEGS"}, -- "Tempest Keeper Leggings"
  [65386] = {4,372,"INVTYPE_LEGS"}, -- "Lightning Well Legguards"
  [66540] = {4,378,"INVTYPE_WEAPON"}, -- "Miniature Winter Veil Tree"
  [67129] = {4,359,"INVTYPE_FINGER"}, -- "Signet of High Arcanist Savor"
  [67130] = {4,359,"INVTYPE_NECK"}, -- "Dorian's Lost Necklace"
  [67131] = {4,359,"INVTYPE_CLOAK"}, -- "Ritssyn's Ruminous Drape"
  [67132] = {4,359,"INVTYPE_HAND"}, -- "Grips of the Failed Immortal"
  [67133] = {4,359,"INVTYPE_ROBE"}, -- "Dizze's Whirling Robe"
  [67134] = {4,359,"INVTYPE_CLOAK"}, -- "Dory's Finery"
  [67135] = {4,359,"INVTYPE_CHEST"}, -- "Morrie's Waywalker Wrap"
  [67136] = {4,359,"INVTYPE_FINGER"}, -- "Gilnean Ring of Ruination"
  [67137] = {4,359,"INVTYPE_NECK"}, -- "Don Rodrigo's Fabulous Necklace"
  [67138] = {4,359,"INVTYPE_NECK"}, -- "Buc-Zakai Choker"
  [67139] = {4,359,"INVTYPE_FINGER"}, -- "Blauvelt's Family Crest"
  [67140] = {4,359,"INVTYPE_CLOAK"}, -- "Drape of Inimitable Fate"
  [67141] = {4,359,"INVTYPE_LEGS"}, -- "Corefire Legplates"
  [67142] = {4,359,"INVTYPE_CLOAK"}, -- "Zom's Electrostatic Cloak"
  [67143] = {4,359,"INVTYPE_CHEST"}, -- "Icebone Hauberk"
  [67144] = {4,359,"INVTYPE_SHOULDER"}, -- "Pauldrons of Edward the Odd"
  [67145] = {4,359,"INVTYPE_SHIELD"}, -- "Blockade's Lost Shield"
  [67146] = {4,359,"INVTYPE_HAND"}, -- "Woundsplicer Handwraps"
  [67147] = {4,359,"INVTYPE_HEAD"}, -- "Je'Tze's Sparkling Tiara"
  [67148] = {4,359,"INVTYPE_LEGS"}, -- "Kilt of Trollish Dreams"
  [67149] = {4,359,"INVTYPE_HOLDABLE"}, -- "Heartbound Tome"
  [67150] = {4,359,"INVTYPE_LEGS"}, -- "Arrowsinger Legguards"
  [68127] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Stormwake, the Tempest's Reach"
  [68128] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Stormwake, the Tempest's Reach"
  [68129] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Stormwake, the Tempest's Reach"
  [68130] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Stormwake, the Tempest's Reach"
  [68131] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Stormwake, the Tempest's Reach"
  [68132] = {4,372,"INVTYPE_WEAPONMAINHAND"}, -- "Stormwake, the Tempest's Reach"
  [68161] = {4,359,"INVTYPE_WEAPON"}, -- "Krol Decapitator"
  [68162] = {4,359,"INVTYPE_THROWN"}, -- "Spinerender"
  [68163] = {4,359,"INVTYPE_WEAPON"}, -- "The Twilight Blade"
  [68600] = {4,372,"INVTYPE_WEAPON"}, -- "Uhn'agh Fash, the Darkest Betrayal"
  [68601] = {4,359,"INVTYPE_WEAPON"}, -- "Scaleslicer"
  [68608] = {4,359,"INVTYPE_THROWN"}, -- "Dragonwreck Throwing Axe"
  [68709] = {4,359,"INVTYPE_TRINKET"}, -- "Unsolvable Riddle"
  [68710] = {4,359,"INVTYPE_TRINKET"}, -- "Stump of Time"
  [68711] = {4,359,"INVTYPE_TRINKET"}, -- "Mandala of Stirring Patterns"
  [68712] = {4,359,"INVTYPE_TRINKET"}, -- "Impatience of Youth"
  [68713] = {4,359,"INVTYPE_TRINKET"}, -- "Mirror of Broken Images"
  [68775] = {4,359,"INVTYPE_TRINKET"}, -- "Volatile Alchemist Stone"
  [68776] = {4,359,"INVTYPE_TRINKET"}, -- "Quicksilver Alchemist Stone"
  [68777] = {4,359,"INVTYPE_TRINKET"}, -- "Vibrant Alchemist Stone"
  [68812] = {4,359,"INVTYPE_FINGER"}, -- "Hornet-Sting Band"
  [68915] = {4,378,"INVTYPE_TRINKET"}, -- "Scales of Life"
  [68925] = {4,384,"INVTYPE_TRINKET"}, -- "Variable Pulse Lightning Capacitor"
  [68926] = {4,378,"INVTYPE_TRINKET"}, -- "Jaws of Defeat"
  [68927] = {4,378,"INVTYPE_TRINKET"}, -- "The Hungerer"
  [68972] = {4,378,"INVTYPE_TRINKET"}, -- "Apparatus of Khaz'goroth"
  [68981] = {4,378,"INVTYPE_TRINKET"}, -- "Spidersilk Spindle"
  [68982] = {4,378,"INVTYPE_TRINKET"}, -- "Necromantic Focus"
  [68983] = {4,378,"INVTYPE_TRINKET"}, -- "Eye of Blazing Power"
  [68994] = {4,384,"INVTYPE_TRINKET"}, -- "Matrix Restabilizer"
  [68995] = {4,384,"INVTYPE_TRINKET"}, -- "Vessel of Acceleration"
  [68996] = {4,378,"INVTYPE_TRINKET"}, -- "Stay of Execution"
  [68998] = {4,378,"INVTYPE_TRINKET"}, -- "Rune of Zeth"
  [69000] = {4,378,"INVTYPE_TRINKET"}, -- "Fiery Quintessence"
  [69001] = {4,378,"INVTYPE_TRINKET"}, -- "Ancient Petrified Seed"
  [69002] = {4,378,"INVTYPE_TRINKET"}, -- "Essence of the Eternal Flame"
  [69109] = {4,391,"INVTYPE_TRINKET"}, -- "Scales of Life"
  [69110] = {4,397,"INVTYPE_TRINKET"}, -- "Variable Pulse Lightning Capacitor"
  [69111] = {4,391,"INVTYPE_TRINKET"}, -- "Jaws of Defeat"
  [69112] = {4,391,"INVTYPE_TRINKET"}, -- "The Hungerer"
  [69113] = {4,391,"INVTYPE_TRINKET"}, -- "Apparatus of Khaz'goroth"
  [69138] = {4,391,"INVTYPE_TRINKET"}, -- "Spidersilk Spindle"
  [69139] = {4,391,"INVTYPE_TRINKET"}, -- "Necromantic Focus"
  [69149] = {4,391,"INVTYPE_TRINKET"}, -- "Eye of Blazing Power"
  [69150] = {4,397,"INVTYPE_TRINKET"}, -- "Matrix Restabilizer"
  [69167] = {4,397,"INVTYPE_TRINKET"}, -- "Vessel of Acceleration"
  [69184] = {4,391,"INVTYPE_TRINKET"}, -- "Stay of Execution"
  [69185] = {4,391,"INVTYPE_TRINKET"}, -- "Rune of Zeth"
  [69198] = {4,391,"INVTYPE_TRINKET"}, -- "Fiery Quintessence"
  [69199] = {4,391,"INVTYPE_TRINKET"}, -- "Ancient Petrified Seed"
  [69200] = {4,391,"INVTYPE_TRINKET"}, -- "Essence of the Eternal Flame"
  [69764] = {4,359,"INVTYPE_SHIELD"}, -- "Extinct Turtle Shell"
  [69781] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Mark of Cruelty"
  [69783] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Mark of Meditation"
  [69784] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Symbol of Cruelty"
  [69785] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Symbol of Tenacity"
  [69786] = {4,365,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Symbol of Meditation"
  [69827] = {4,359,"INVTYPE_NECK"}, -- "Mistral Pendant"
  [69828] = {4,359,"INVTYPE_NECK"}, -- "Permafrost Choker"
  [69829] = {4,359,"INVTYPE_NECK"}, -- "Cloudburst Necklace"
  [69830] = {4,359,"INVTYPE_NECK"}, -- "Planetary Amulet"
  [69831] = {4,359,"INVTYPE_CLOAK"}, -- "Mistral Drape"
  [69833] = {4,359,"INVTYPE_CLOAK"}, -- "Permafrost Cape"
  [69834] = {4,359,"INVTYPE_CLOAK"}, -- "Cloudburst Cloak"
  [69835] = {4,359,"INVTYPE_CLOAK"}, -- "Planetary Drape"
  [69842] = {4,359,"INVTYPE_WAIST"}, -- "Garr's Reinforced Girdle of Memories"
  [69843] = {4,359,"INVTYPE_2HWEAPON"}, -- "Mobus's Dripping Halberd"
  [69844] = {4,359,"INVTYPE_WEAPONMAINHAND"}, -- "Vitreous Beak of Julak-Doom"
  [69876] = {4,359,"INVTYPE_HAND"}, -- "Xariona's Spectral Gauntlets"
  [69877] = {4,359,"INVTYPE_WAIST"}, -- "Belt of a Thousand Gaping Mouths"
  [69878] = {4,372,"INVTYPE_CLOAK"}, -- "Permafrost Cape"
  [69879] = {4,372,"INVTYPE_CLOAK"}, -- "Cloudburst Cloak"
  [69880] = {4,372,"INVTYPE_NECK"}, -- "Mistral Pendant"
  [69881] = {4,372,"INVTYPE_CLOAK"}, -- "Planetary Drape"
  [69882] = {4,372,"INVTYPE_NECK"}, -- "Planetary Amulet"
  [69883] = {4,372,"INVTYPE_NECK"}, -- "Permafrost Choker"
  [69884] = {4,372,"INVTYPE_CLOAK"}, -- "Mistral Drape"
  [69885] = {4,372,"INVTYPE_NECK"}, -- "Cloudburst Necklace"
  [69897] = {4,378,"INVTYPE_2HWEAPON"}, -- "Fandral's Flamescythe"
  [69936] = {4,378,"INVTYPE_HAND"}, -- "Fists of Fury"
  [69937] = {4,378,"INVTYPE_HAND"}, -- "Eternal Elementium Handguards"
  [69938] = {4,378,"INVTYPE_HAND"}, -- "Holy Flame Gauntlets"
  [69939] = {4,378,"INVTYPE_HAND"}, -- "Dragonfire Gloves"
  [69941] = {4,378,"INVTYPE_HAND"}, -- "Gloves of Unforgiving Flame"
  [69942] = {4,378,"INVTYPE_HAND"}, -- "Clutches of Evil"
  [69943] = {4,378,"INVTYPE_HAND"}, -- "Heavenly Gloves of the Moon"
  [69944] = {4,378,"INVTYPE_HAND"}, -- "Grips of Altered Reality"
  [69945] = {4,378,"INVTYPE_HAND"}, -- "Don Tayo's Inferno Mittens"
  [69946] = {4,378,"INVTYPE_FEET"}, -- "Warboots of Mighty Lords"
  [69947] = {4,378,"INVTYPE_FEET"}, -- "Mirrored Boots"
  [69948] = {4,378,"INVTYPE_FEET"}, -- "Emberforged Elementium Boots"
  [69949] = {4,378,"INVTYPE_FEET"}, -- "Earthen Scale Sabatons"
  [69950] = {4,378,"INVTYPE_FEET"}, -- "Footwraps of Quenched Fire"
  [69951] = {4,378,"INVTYPE_FEET"}, -- "Treads of the Craft"
  [69952] = {4,378,"INVTYPE_FEET"}, -- "Ethereal Footfalls"
  [69953] = {4,378,"INVTYPE_FEET"}, -- "Endless Dream Walkers"
  [69954] = {4,378,"INVTYPE_FEET"}, -- "Boots of the Black Flame"
  [70105] = {4,365,"INVTYPE_FINGER"}, -- "Matoclaw's Band"
  [70106] = {4,365,"INVTYPE_NECK"}, -- "Nightweaver's Amulet"
  [70107] = {4,365,"INVTYPE_NECK"}, -- "Fireheart Necklace"
  [70108] = {4,365,"INVTYPE_FEET"}, -- "Pyrelord Greaves"
  [70109] = {4,365,"INVTYPE_RELIC"}, -- "Relic of Elune's Shadow"
  [70110] = {4,365,"INVTYPE_FINGER"}, -- "Band of Glittering Lights"
  [70111] = {4,365,"INVTYPE_RELIC"}, -- "Relic of Elune's Light"
  [70112] = {4,365,"INVTYPE_HOLDABLE"}, -- "Globe of Moonlight"
  [70113] = {4,365,"INVTYPE_FINGER"}, -- "Moon Blessed Band"
  [70114] = {4,365,"INVTYPE_WAIST"}, -- "Fireplume Girdle"
  [70115] = {4,365,"INVTYPE_FEET"}, -- "Fiery Treads"
  [70116] = {4,365,"INVTYPE_HAND"}, -- "Gauntlets of Living Obsidium"
  [70117] = {4,365,"INVTYPE_WAIST"}, -- "Belt of Living Obsidium"
  [70118] = {4,365,"INVTYPE_HAND"}, -- "Widow's Clutches"
  [70119] = {4,365,"INVTYPE_FINGER"}, -- "Meteorite Ring"
  [70120] = {4,365,"INVTYPE_WAIST"}, -- "Rickety Belt"
  [70121] = {4,365,"INVTYPE_WRIST"}, -- "Ricket's Gun Show"
  [70122] = {4,365,"INVTYPE_HAND"}, -- "Aviana's Grips"
  [70123] = {4,365,"INVTYPE_FEET"}, -- "Lancer's Greaves"
  [70124] = {4,365,"INVTYPE_FINGER"}, -- "Spirit Fragment Band"
  [70125] = {4,365,"INVTYPE_RELIC"}, -- "Relic of Lo'Gosh"
  [70126] = {4,365,"INVTYPE_FINGER"}, -- "Nemesis Shell Band"
  [70127] = {4,365,"INVTYPE_FINGER"}, -- "Lylagar Horn Ring"
  [70128] = {4,365,"INVTYPE_RELIC"}, -- "Relic of Tortolla"
  [70141] = {4,365,"INVTYPE_TRINKET"}, -- "Dwyer's Caber"
  [70142] = {4,365,"INVTYPE_TRINKET"}, -- "Moonwell Chalice"
  [70143] = {4,365,"INVTYPE_TRINKET"}, -- "Moonwell Phial"
  [70144] = {4,365,"INVTYPE_TRINKET"}, -- "Ricket's Magnetic Fireball"
  [70155] = {4,365,"INVTYPE_WEAPON"}, -- "Brainsplinter"
  [70156] = {4,365,"INVTYPE_WEAPONMAINHAND"}, -- "Masterwork Elementium Spellblade"
  [70157] = {4,365,"INVTYPE_WEAPONMAINHAND"}, -- "Lightforged Elementium Hammer"
  [70158] = {4,365,"INVTYPE_WEAPON"}, -- "Elementium-Edged Scalper"
  [70162] = {4,365,"INVTYPE_WEAPON"}, -- "Pyrium Spellward"
  [70163] = {4,365,"INVTYPE_WEAPON"}, -- "Unbreakable Guardian"
  [70164] = {4,365,"INVTYPE_2HWEAPON"}, -- "Masterwork Elementium Deathblade"
  [70165] = {4,365,"INVTYPE_2HWEAPON"}, -- "Witch-Hunter's Harvester"
  [70390] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Cruelty"
  [70391] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Meditation"
  [70393] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Cruelty"
  [70394] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Meditation"
  [70396] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Emblem of Cruelty"
  [70397] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Emblem of Meditation"
  [70409] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Mark of Cruelty"
  [70411] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Mark of Meditation"
  [70412] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Symbol of Cruelty"
  [70413] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Symbol of Tenacity"
  [70414] = {4,384,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Symbol of Meditation"
  [70563] = {4,371,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Cruelty"
  [70564] = {4,371,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Emblem of Meditation"
  [70602] = {4,371,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Cruelty"
  [70603] = {4,371,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Cruelty"
  [70604] = {4,371,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Meditation"
  [70605] = {4,371,"INVTYPE_TRINKET"}, -- "Vicious Gladiator's Medallion of Meditation"
  [70723] = {4,397,"INVTYPE_2HWEAPON"}, -- "Sulfuras, the Extinguished Hand"
  [70733] = {4,378,"INVTYPE_WEAPON"}, -- "Alysra's Razor"
  [70734] = {4,378,"INVTYPE_HEAD"}, -- "Greathelm of the Voracious Maw"
  [70735] = {4,378,"INVTYPE_WRIST"}, -- "Flickering Wristbands"
  [70736] = {4,378,"INVTYPE_LEGS"}, -- "Moltenfeather Leggings"
  [70737] = {4,378,"INVTYPE_SHOULDER"}, -- "Spaulders of Recurring Flame"
  [70738] = {4,378,"INVTYPE_FINGER"}, -- "Alysrazor's Band"
  [70739] = {4,378,"INVTYPE_LEGS"}, -- "Lavaworm Legplates"
  [70912] = {4,378,"INVTYPE_FEET"}, -- "Cracked Obsidian Stompers"
  [70913] = {4,378,"INVTYPE_LEGS"}, -- "Legplates of Frenzied Devotion"
  [70914] = {4,378,"INVTYPE_CHEST"}, -- "Carapace of Imbibed Flame"
  [70915] = {4,378,"INVTYPE_SHIELD"}, -- "Shard of Torment"
  [70916] = {4,378,"INVTYPE_HEAD"}, -- "Helm of Blazing Glory"
  [70917] = {4,378,"INVTYPE_HAND"}, -- "Flickering Handguards"
  [70920] = {4,378,"INVTYPE_WRIST"}, -- "Bracers of the Fiery Path"
  [70921] = {4,384,"INVTYPE_SHOULDER"}, -- "Pauldrons of Roaring Flame"
  [70922] = {4,378,"INVTYPE_WEAPON"}, -- "Mandible of Beth'tilac"
  [70929] = {4,378,"INVTYPE_NECK"}, -- "Firebound Gorget"
  [70930] = {4,378,"INVTYPE_CLOAK"}, -- "Durable Flamewrath Greatcloak"
  [70933] = {4,378,"INVTYPE_WAIST"}, -- "Girdle of the Indomitable Flame"
  [70934] = {4,391,"INVTYPE_FINGER"}, -- "Adamantine Signet of the Avengers"
  [70935] = {4,378,"INVTYPE_NECK"}, -- "Stoneheart Necklace"
  [70937] = {4,378,"INVTYPE_WRIST"}, -- "Bracers of Regal Force"
  [70939] = {4,378,"INVTYPE_RELIC"}, -- "Deathclutch Figurine"
  [70940] = {4,378,"INVTYPE_FINGER"}, -- "Deflecting Brimstone Band"
  [70941] = {4,378,"INVTYPE_SHOULDER"}, -- "Shoulderguards of the Molten Giant"
  [70942] = {4,378,"INVTYPE_LEGS"}, -- "Legguards of the Molten Giant"
  [70943] = {4,378,"INVTYPE_HAND"}, -- "Handguards of the Molten Giant"
  [70944] = {4,378,"INVTYPE_HEAD"}, -- "Faceguard of the Molten Giant"
  [70945] = {4,378,"INVTYPE_CHEST"}, -- "Chestguard of the Molten Giant"
  [70946] = {4,378,"INVTYPE_SHOULDER"}, -- "Immolation Shoulderguards"
  [70947] = {4,378,"INVTYPE_LEGS"}, -- "Immolation Legguards"
  [70948] = {4,378,"INVTYPE_HEAD"}, -- "Immolation Faceguard"
  [70949] = {4,378,"INVTYPE_HAND"}, -- "Immolation Handguards"
  [70950] = {4,378,"INVTYPE_ROBE"}, -- "Immolation Chestguard"
  [70951] = {4,378,"INVTYPE_SHOULDER"}, -- "Elementium Deathplate Shoulderguards"
  [70952] = {4,378,"INVTYPE_LEGS"}, -- "Elementium Deathplate Legguards"
  [70953] = {4,378,"INVTYPE_HAND"}, -- "Elementium Deathplate Handguards"
  [70954] = {4,378,"INVTYPE_HEAD"}, -- "Elementium Deathplate Faceguard"
  [70955] = {4,378,"INVTYPE_CHEST"}, -- "Elementium Deathplate Chestguard"
  [70985] = {4,378,"INVTYPE_SHOULDER"}, -- "Craterflame Spaulders"
  [70986] = {4,378,"INVTYPE_HAND"}, -- "Clawshaper Gauntlets"
  [70987] = {4,378,"INVTYPE_FEET"}, -- "Phoenix-Down Treads"
  [70988] = {4,378,"INVTYPE_ROBE"}, -- "Clutch of the Firemother"
  [70989] = {4,378,"INVTYPE_LEGS"}, -- "Leggings of Billowing Fire"
  [70990] = {4,378,"INVTYPE_CLOAK"}, -- "Wings of Flame"
  [70991] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Arbalest of Erupting Fury"
  [70992] = {4,378,"INVTYPE_CLOAK"}, -- "Dreadfire Drape"
  [70993] = {4,378,"INVTYPE_HAND"}, -- "Fireskin Gauntlets"
  [71003] = {4,378,"INVTYPE_HEAD"}, -- "Hood of Rampant Disdain"
  [71004] = {4,378,"INVTYPE_WRIST"}, -- "Earthcrack Bracers"
  [71005] = {4,378,"INVTYPE_CHEST"}, -- "Flaming Core Chestguard"
  [71006] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Volcanospike"
  [71007] = {4,378,"INVTYPE_HAND"}, -- "Grips of the Raging Giant"
  [71009] = {4,378,"INVTYPE_WRIST"}, -- "Lava Line Wristbands"
  [71010] = {4,378,"INVTYPE_CHEST"}, -- "Incendic Chestguard"
  [71011] = {4,378,"INVTYPE_HEAD"}, -- "Flickering Cowl"
  [71012] = {4,378,"INVTYPE_NECK"}, -- "Heartstone of Rhyolith"
  [71013] = {4,378,"INVTYPE_WEAPON"}, -- "Feeding Frenzy"
  [71014] = {4,378,"INVTYPE_2HWEAPON"}, -- "Skullstealer Greataxe"
  [71018] = {4,378,"INVTYPE_HEAD"}, -- "Scalp of the Bandit Prince"
  [71019] = {4,378,"INVTYPE_NECK"}, -- "Necklace of Fetishes"
  [71020] = {4,378,"INVTYPE_HAND"}, -- "Gloves of Dissolving Smoke"
  [71021] = {4,378,"INVTYPE_WAIST"}, -- "Uncrushable Belt of Fury"
  [71022] = {4,378,"INVTYPE_HOLDABLE"}, -- "Goblet of Anger"
  [71023] = {4,378,"INVTYPE_FEET"}, -- "Coalwalker Sandals"
  [71024] = {4,378,"INVTYPE_FINGER"}, -- "Crystal Prison Band"
  [71025] = {4,378,"INVTYPE_SHOULDER"}, -- "Flickering Shoulderpads"
  [71026] = {4,378,"INVTYPE_WRIST"}, -- "Bracers of the Dread Hunter"
  [71027] = {4,378,"INVTYPE_FEET"}, -- "Treads of Implicit Obedience"
  [71028] = {4,378,"INVTYPE_LEGS"}, -- "Legplates of Absolute Control"
  [71029] = {4,378,"INVTYPE_FEET"}, -- "Arachnaflame Treads"
  [71030] = {4,378,"INVTYPE_SHOULDER"}, -- "Flickering Shoulders"
  [71031] = {4,378,"INVTYPE_LEGS"}, -- "Cinderweb Leggings"
  [71032] = {4,378,"INVTYPE_FINGER"}, -- "Widow's Kiss"
  [71038] = {4,378,"INVTYPE_SHIELD"}, -- "Ward of the Red Widow"
  [71039] = {4,378,"INVTYPE_2HWEAPON"}, -- "Funeral Pyre"
  [71040] = {4,378,"INVTYPE_HEAD"}, -- "Cowl of the Clicking Menace"
  [71041] = {4,378,"INVTYPE_ROBE"}, -- "Robes of Smoldering Devastation"
  [71042] = {4,378,"INVTYPE_LEGS"}, -- "Thoracic Flame Kilt"
  [71043] = {4,378,"INVTYPE_SHOULDER"}, -- "Spaulders of Manifold Eyes"
  [71044] = {4,378,"INVTYPE_HAND"}, -- "Cindersilk Gloves"
  [71045] = {4,378,"INVTYPE_CHEST"}, -- "Dark Phoenix Tunic"
  [71046] = {4,378,"INVTYPE_HAND"}, -- "Dark Phoenix Gloves"
  [71047] = {4,378,"INVTYPE_HEAD"}, -- "Dark Phoenix Helmet"
  [71048] = {4,378,"INVTYPE_LEGS"}, -- "Dark Phoenix Legguards"
  [71049] = {4,378,"INVTYPE_SHOULDER"}, -- "Dark Phoenix Spaulders"
  [71050] = {4,378,"INVTYPE_HAND"}, -- "Flamewaker's Gloves"
  [71051] = {4,378,"INVTYPE_HEAD"}, -- "Flamewaker's Headguard"
  [71052] = {4,378,"INVTYPE_LEGS"}, -- "Flamewaker's Legguards"
  [71053] = {4,378,"INVTYPE_SHOULDER"}, -- "Flamewaker's Spaulders"
  [71054] = {4,378,"INVTYPE_CHEST"}, -- "Flamewaker's Tunic"
  [71058] = {4,378,"INVTYPE_CHEST"}, -- "Elementium Deathplate Breastplate"
  [71059] = {4,378,"INVTYPE_HAND"}, -- "Elementium Deathplate Gauntlets"
  [71060] = {4,378,"INVTYPE_HEAD"}, -- "Elementium Deathplate Helmet"
  [71061] = {4,378,"INVTYPE_LEGS"}, -- "Elementium Deathplate Greaves"
  [71062] = {4,378,"INVTYPE_SHOULDER"}, -- "Elementium Deathplate Pauldrons"
  [71063] = {4,378,"INVTYPE_ROBE"}, -- "Immolation Battleplate"
  [71064] = {4,378,"INVTYPE_HAND"}, -- "Immolation Gauntlets"
  [71065] = {4,378,"INVTYPE_HEAD"}, -- "Immolation Helmet"
  [71066] = {4,378,"INVTYPE_LEGS"}, -- "Immolation Legplates"
  [71067] = {4,378,"INVTYPE_SHOULDER"}, -- "Immolation Pauldrons"
  [71068] = {4,378,"INVTYPE_CHEST"}, -- "Battleplate of the Molten Giant"
  [71069] = {4,378,"INVTYPE_HAND"}, -- "Gauntlets of the Molten Giant"
  [71070] = {4,378,"INVTYPE_HEAD"}, -- "Helmet of the Molten Giant"
  [71071] = {4,378,"INVTYPE_LEGS"}, -- "Legplates of the Molten Giant"
  [71072] = {4,378,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Molten Giant"
  [71077] = {4,365,"INVTYPE_RANGEDRIGHT"}, -- "Extreme-Impact Hole Puncher"
  [71084] = {4,378,"INVTYPE_2HWEAPON"}, -- "Branch of Nordrassil"
  [71085] = {4,391,"INVTYPE_2HWEAPON"}, -- "Runestaff of Nordrassil"
  [71091] = {4,378,"INVTYPE_ROBE"}, -- "Immolation Breastplate"
  [71092] = {4,378,"INVTYPE_HAND"}, -- "Immolation Gloves"
  [71093] = {4,378,"INVTYPE_HEAD"}, -- "Immolation Headguard"
  [71094] = {4,378,"INVTYPE_LEGS"}, -- "Immolation Greaves"
  [71095] = {4,378,"INVTYPE_SHOULDER"}, -- "Immolation Mantle"
  [71097] = {4,378,"INVTYPE_HAND"}, -- "Obsidian Arborweave Grips"
  [71098] = {4,378,"INVTYPE_HEAD"}, -- "Obsidian Arborweave Headpiece"
  [71099] = {4,378,"INVTYPE_LEGS"}, -- "Obsidian Arborweave Legguards"
  [71100] = {4,378,"INVTYPE_CHEST"}, -- "Obsidian Arborweave Raiment"
  [71101] = {4,378,"INVTYPE_SHOULDER"}, -- "Obsidian Arborweave Spaulders"
  [71102] = {4,378,"INVTYPE_HAND"}, -- "Obsidian Arborweave Handwraps"
  [71103] = {4,378,"INVTYPE_HEAD"}, -- "Obsidian Arborweave Helm"
  [71104] = {4,378,"INVTYPE_LEGS"}, -- "Obsidian Arborweave Legwraps"
  [71105] = {4,378,"INVTYPE_CHEST"}, -- "Obsidian Arborweave Tunic"
  [71106] = {4,378,"INVTYPE_SHOULDER"}, -- "Obsidian Arborweave Mantle"
  [71107] = {4,378,"INVTYPE_HAND"}, -- "Obsidian Arborweave Gloves"
  [71108] = {4,378,"INVTYPE_HEAD"}, -- "Obsidian Arborweave Cover"
  [71109] = {4,378,"INVTYPE_LEGS"}, -- "Obsidian Arborweave Leggings"
  [71110] = {4,378,"INVTYPE_CHEST"}, -- "Obsidian Arborweave Vestment"
  [71111] = {4,378,"INVTYPE_SHOULDER"}, -- "Obsidian Arborweave Shoulderwraps"
  [71129] = {4,378,"INVTYPE_NECK"}, -- "Necklace of Smoke Signals"
  [71130] = {4,378,"INVTYPE_WRIST"}, -- "Flamebinder Bracers"
  [71131] = {4,378,"INVTYPE_WAIST"}, -- "Flamebinding Girdle"
  [71146] = {4,378,"INVTYPE_RELIC"}, -- "Covenant of the Flame"
  [71147] = {4,378,"INVTYPE_RELIC"}, -- "Relic of the Elemental Lords"
  [71148] = {4,378,"INVTYPE_RELIC"}, -- "Soulflame Vial"
  [71149] = {4,378,"INVTYPE_RELIC"}, -- "Singed Plume of Aviana"
  [71150] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Scorchvine Wand"
  [71151] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Trail of Embers"
  [71152] = {4,378,"INVTYPE_THROWN"}, -- "Morningstar Shard"
  [71154] = {4,378,"INVTYPE_THROWN"}, -- "Giantslicer"
  [71208] = {4,378,"INVTYPE_FINGER"}, -- "Serrated Brimstone Signet"
  [71209] = {4,378,"INVTYPE_FINGER"}, -- "Splintered Brimstone Seal"
  [71210] = {4,378,"INVTYPE_FINGER"}, -- "Crystalline Brimstone Ring"
  [71211] = {4,378,"INVTYPE_FINGER"}, -- "Soothing Brimstone Circle"
  [71212] = {4,378,"INVTYPE_NECK"}, -- "Stoneheart Choker"
  [71213] = {4,378,"INVTYPE_NECK"}, -- "Amulet of Burning Brilliance"
  [71214] = {4,378,"INVTYPE_NECK"}, -- "Firemind Pendant"
  [71215] = {4,391,"INVTYPE_FINGER"}, -- "Obsidian Signet of the Avengers"
  [71216] = {4,391,"INVTYPE_FINGER"}, -- "Viridian Signet of the Avengers"
  [71217] = {4,391,"INVTYPE_FINGER"}, -- "Infernal Signet of the Avengers"
  [71218] = {4,378,"INVTYPE_THROWN"}, -- "Deflecting Star"
  [71227] = {4,378,"INVTYPE_CLOAK"}, -- "Bladed Flamewrath Cover"
  [71228] = {4,378,"INVTYPE_CLOAK"}, -- "Sleek Flamewrath Cloak"
  [71229] = {4,378,"INVTYPE_CLOAK"}, -- "Flowing Flamewrath Cape"
  [71230] = {4,378,"INVTYPE_CLOAK"}, -- "Rippling Flamewrath Drape"
  [71237] = {4,391,"INVTYPE_FINGER"}, -- "Quicksilver Signet of the Avengers"
  [71249] = {4,378,"INVTYPE_WAIST"}, -- "Firescar Sash"
  [71250] = {4,378,"INVTYPE_WAIST"}, -- "Cinch of the Flaming Ember"
  [71253] = {4,378,"INVTYPE_WAIST"}, -- "Belt of the Seven Seals"
  [71254] = {4,378,"INVTYPE_WAIST"}, -- "Firemend Cinch"
  [71255] = {4,378,"INVTYPE_WAIST"}, -- "Firearrow Belt"
  [71258] = {4,378,"INVTYPE_WAIST"}, -- "Embereye Belt"
  [71260] = {4,378,"INVTYPE_WRIST"}, -- "Bracers of Imperious Truths"
  [71261] = {4,378,"INVTYPE_WRIST"}, -- "Gigantiform Bracers"
  [71262] = {4,378,"INVTYPE_WRIST"}, -- "Smolderskull Bindings"
  [71263] = {4,378,"INVTYPE_WRIST"}, -- "Bracers of Misting Ash"
  [71264] = {4,378,"INVTYPE_WRIST"}, -- "Bracers of Forked Lightning"
  [71265] = {4,378,"INVTYPE_WRIST"}, -- "Emberflame Bracers"
  [71266] = {4,378,"INVTYPE_WRIST"}, -- "Firesoul Wristguards"
  [71267] = {4,365,"INVTYPE_CLOAK"}, -- "Mantle of Desire"
  [71268] = {4,365,"INVTYPE_CLOAK"}, -- "Mantle of Doubt"
  [71269] = {4,365,"INVTYPE_CLOAK"}, -- "Mantle of Fury"
  [71270] = {4,365,"INVTYPE_CLOAK"}, -- "Mantle of Patience"
  [71271] = {4,378,"INVTYPE_HAND"}, -- "Handwraps of the Cleansing Flame"
  [71272] = {4,378,"INVTYPE_HEAD"}, -- "Cowl of the Cleansing Flame"
  [71273] = {4,378,"INVTYPE_LEGS"}, -- "Legwraps of the Cleansing Flame"
  [71274] = {4,378,"INVTYPE_ROBE"}, -- "Robes of the Cleansing Flame"
  [71275] = {4,378,"INVTYPE_SHOULDER"}, -- "Mantle of the Cleansing Flame"
  [71276] = {4,378,"INVTYPE_HAND"}, -- "Gloves of the Cleansing Flame"
  [71277] = {4,378,"INVTYPE_HEAD"}, -- "Hood of the Cleansing Flame"
  [71278] = {4,378,"INVTYPE_LEGS"}, -- "Leggings of the Cleansing Flame"
  [71279] = {4,378,"INVTYPE_ROBE"}, -- "Vestment of the Cleansing Flame"
  [71280] = {4,378,"INVTYPE_SHOULDER"}, -- "Shoulderwraps of the Cleansing Flame"
  [71281] = {4,378,"INVTYPE_HAND"}, -- "Balespider's Handwraps"
  [71282] = {4,378,"INVTYPE_HEAD"}, -- "Balespider's Hood"
  [71283] = {4,378,"INVTYPE_LEGS"}, -- "Balespider's Leggings"
  [71284] = {4,378,"INVTYPE_ROBE"}, -- "Balespider's Robes"
  [71285] = {4,378,"INVTYPE_SHOULDER"}, -- "Balespider's Mantle"
  [71286] = {4,378,"INVTYPE_HAND"}, -- "Firehawk Gloves"
  [71287] = {4,378,"INVTYPE_HEAD"}, -- "Firehawk Hood"
  [71288] = {4,378,"INVTYPE_LEGS"}, -- "Firehawk Leggings"
  [71289] = {4,378,"INVTYPE_ROBE"}, -- "Firehawk Robes"
  [71290] = {4,378,"INVTYPE_SHOULDER"}, -- "Firehawk Mantle"
  [71291] = {4,378,"INVTYPE_ROBE"}, -- "Erupting Volcanic Hauberk"
  [71292] = {4,378,"INVTYPE_HAND"}, -- "Erupting Volcanic Gloves"
  [71293] = {4,378,"INVTYPE_HEAD"}, -- "Erupting Volcanic Headpiece"
  [71294] = {4,378,"INVTYPE_LEGS"}, -- "Erupting Volcanic Kilt"
  [71295] = {4,378,"INVTYPE_SHOULDER"}, -- "Erupting Volcanic Shoulderwraps"
  [71296] = {4,378,"INVTYPE_ROBE"}, -- "Erupting Volcanic Tunic"
  [71297] = {4,378,"INVTYPE_HAND"}, -- "Erupting Volcanic Handwraps"
  [71298] = {4,378,"INVTYPE_HEAD"}, -- "Erupting Volcanic Faceguard"
  [71299] = {4,378,"INVTYPE_LEGS"}, -- "Erupting Volcanic Legwraps"
  [71300] = {4,378,"INVTYPE_SHOULDER"}, -- "Erupting Volcanic Mantle"
  [71301] = {4,378,"INVTYPE_ROBE"}, -- "Erupting Volcanic Cuirass"
  [71302] = {4,378,"INVTYPE_HAND"}, -- "Erupting Volcanic Grips"
  [71303] = {4,378,"INVTYPE_HEAD"}, -- "Erupting Volcanic Helmet"
  [71304] = {4,378,"INVTYPE_LEGS"}, -- "Erupting Volcanic Legguards"
  [71305] = {4,378,"INVTYPE_SHOULDER"}, -- "Erupting Volcanic Spaulders"
  [71312] = {4,378,"INVTYPE_WEAPON"}, -- "Gatecrasher"
  [71313] = {4,378,"INVTYPE_FEET"}, -- "Sandals of Leaping Coals"
  [71314] = {4,378,"INVTYPE_CHEST"}, -- "Breastplate of the Incendiary Soul"
  [71315] = {4,378,"INVTYPE_FEET"}, -- "Decimation Treads"
  [71323] = {4,378,"INVTYPE_HOLDABLE"}, -- "Molten Scream"
  [71325] = {4,365,"INVTYPE_WEAPONMAINHAND"}, -- "The Horseman's Sinister Saber"
  [71326] = {4,365,"INVTYPE_HEAD"}, -- "The Horseman's Horrific Helmet"
  [71327] = {4,365,"INVTYPE_FINGER"}, -- "Band of Ghoulish Glee"
  [71328] = {4,365,"INVTYPE_FINGER"}, -- "The Horseman's Signet"
  [71329] = {4,365,"INVTYPE_FINGER"}, -- "Wicked Witch's Ring"
  [71330] = {4,365,"INVTYPE_FINGER"}, -- "Seal of the Petrified Pumpkin"
  [71331] = {4,365,"INVTYPE_WEAPON"}, -- "Direbrew's Bloodied Shanker"
  [71332] = {4,365,"INVTYPE_WEAPON"}, -- "Tremendous Tankard O' Terror"
  [71333] = {4,365,"INVTYPE_TRINKET"}, -- "Bitterer Balebrew Charm"
  [71334] = {4,365,"INVTYPE_TRINKET"}, -- "Bubblier Brightbrew Charm"
  [71335] = {4,365,"INVTYPE_TRINKET"}, -- "Coren's Chilled Chromium Coaster"
  [71336] = {4,365,"INVTYPE_TRINKET"}, -- "Petrified Pickled Egg"
  [71337] = {4,365,"INVTYPE_TRINKET"}, -- "Mithril Stopwatch"
  [71338] = {4,365,"INVTYPE_TRINKET"}, -- "Brawler's Trophy"
  [71340] = {4,378,"INVTYPE_ROBE"}, -- "Gatekeeper's Embrace"
  [71341] = {4,378,"INVTYPE_WRIST"}, -- "Glowing Wing Bracers"
  [71342] = {4,378,"INVTYPE_HEAD"}, -- "Casque of Flame"
  [71343] = {4,378,"INVTYPE_SHOULDER"}, -- "Mantle of Closed Doors"
  [71344] = {4,378,"INVTYPE_CHEST"}, -- "Breastplate of Shifting Visions"
  [71345] = {4,378,"INVTYPE_SHOULDER"}, -- "Shoulderpads of the Forgotten Gate"
  [71346] = {4,378,"INVTYPE_HAND"}, -- "Grips of Unerring Precision"
  [71347] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Stinger of the Flaming Scorpion"
  [71348] = {4,378,"INVTYPE_NECK"}, -- "Flowform Choker"
  [71349] = {4,378,"INVTYPE_LEGS"}, -- "Firecat Leggings"
  [71350] = {4,378,"INVTYPE_WRIST"}, -- "Wristwraps of Arrogant Doom"
  [71351] = {4,378,"INVTYPE_FEET"}, -- "Treads of the Penitent Man"
  [71352] = {4,384,"INVTYPE_2HWEAPON"}, -- "Sulfuras, the Extinguished Hand"
  [71353] = {4,384,"INVTYPE_RANGED"}, -- "Arathar, the Eye of Flame"
  [71354] = {4,384,"INVTYPE_NECK"}, -- "Choker of the Vanquished Lord"
  [71355] = {4,384,"INVTYPE_WEAPONMAINHAND"}, -- "Ko'gun, Hammer of the Firelord"
  [71356] = {4,384,"INVTYPE_HEAD"}, -- "Crown of Flame"
  [71357] = {4,384,"INVTYPE_WAIST"}, -- "Majordomo's Chain of Office"
  [71358] = {4,384,"INVTYPE_HAND"}, -- "Fingers of Incineration"
  [71359] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Chelley's Sterilized Scalpel"
  [71360] = {4,378,"INVTYPE_2HWEAPON"}, -- "Spire of Scarlet Pain"
  [71361] = {4,378,"INVTYPE_2HWEAPON"}, -- "Ranseur of Hatred"
  [71362] = {4,378,"INVTYPE_WEAPON"}, -- "Obsidium Cleaver"
  [71365] = {4,378,"INVTYPE_WRIST"}, -- "Hide-Bound Chains"
  [71366] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Lava Bolt Crossbow"
  [71367] = {4,378,"INVTYPE_FINGER"}, -- "Theck's Emberseal"
  [71388] = {4,391,"INVTYPE_CLOAK"}, -- "Sleek Flamewrath Cloak"
  [71389] = {4,391,"INVTYPE_CLOAK"}, -- "Rippling Flamewrath Drape"
  [71390] = {4,391,"INVTYPE_CLOAK"}, -- "Flowing Flamewrath Cape"
  [71391] = {4,391,"INVTYPE_CLOAK"}, -- "Bladed Flamewrath Cover"
  [71392] = {4,391,"INVTYPE_CLOAK"}, -- "Durable Flamewrath Greatcloak"
  [71393] = {4,391,"INVTYPE_WAIST"}, -- "Embereye Belt"
  [71394] = {4,391,"INVTYPE_WAIST"}, -- "Flamebinding Girdle"
  [71395] = {4,391,"INVTYPE_WAIST"}, -- "Firescar Sash"
  [71396] = {4,391,"INVTYPE_WAIST"}, -- "Firearrow Belt"
  [71397] = {4,391,"INVTYPE_WAIST"}, -- "Firemend Cinch"
  [71398] = {4,391,"INVTYPE_WAIST"}, -- "Belt of the Seven Seals"
  [71399] = {4,391,"INVTYPE_WAIST"}, -- "Cinch of the Flaming Ember"
  [71400] = {4,391,"INVTYPE_WAIST"}, -- "Girdle of the Indomitable Flame"
  [71401] = {4,391,"INVTYPE_FINGER"}, -- "Widow's Kiss"
  [71402] = {4,391,"INVTYPE_LEGS"}, -- "Cinderweb Leggings"
  [71403] = {4,391,"INVTYPE_SHOULDER"}, -- "Flickering Shoulders"
  [71404] = {4,391,"INVTYPE_FEET"}, -- "Arachnaflame Treads"
  [71405] = {4,391,"INVTYPE_CHEST"}, -- "Carapace of Imbibed Flame"
  [71406] = {4,391,"INVTYPE_WEAPON"}, -- "Mandible of Beth'tilac"
  [71407] = {4,391,"INVTYPE_ROBE"}, -- "Robes of Smoldering Devastation"
  [71408] = {4,391,"INVTYPE_SHIELD"}, -- "Ward of the Red Widow"
  [71409] = {4,391,"INVTYPE_2HWEAPON"}, -- "Funeral Pyre"
  [71410] = {4,391,"INVTYPE_HAND"}, -- "Cindersilk Gloves"
  [71411] = {4,391,"INVTYPE_HEAD"}, -- "Cowl of the Clicking Menace"
  [71412] = {4,391,"INVTYPE_LEGS"}, -- "Thoracic Flame Kilt"
  [71413] = {4,391,"INVTYPE_SHOULDER"}, -- "Spaulders of Manifold Eyes"
  [71414] = {4,391,"INVTYPE_RANGEDRIGHT"}, -- "Arbalest of Erupting Fury"
  [71415] = {4,391,"INVTYPE_CLOAK"}, -- "Dreadfire Drape"
  [71416] = {4,391,"INVTYPE_HEAD"}, -- "Hood of Rampant Disdain"
  [71417] = {4,391,"INVTYPE_CHEST"}, -- "Flaming Core Chestguard"
  [71418] = {4,391,"INVTYPE_WRIST"}, -- "Earthcrack Bracers"
  [71419] = {4,391,"INVTYPE_HAND"}, -- "Fireskin Gauntlets"
  [71420] = {4,391,"INVTYPE_FEET"}, -- "Cracked Obsidian Stompers"
  [71421] = {4,391,"INVTYPE_HEAD"}, -- "Flickering Cowl"
  [71422] = {4,391,"INVTYPE_WEAPONMAINHAND"}, -- "Volcanospike"
  [71423] = {4,391,"INVTYPE_NECK"}, -- "Heartstone of Rhyolith"
  [71424] = {4,391,"INVTYPE_CHEST"}, -- "Incendic Chestguard"
  [71425] = {4,391,"INVTYPE_WRIST"}, -- "Lava Line Wristbands"
  [71426] = {4,391,"INVTYPE_HAND"}, -- "Grips of the Raging Giant"
  [71427] = {4,391,"INVTYPE_WEAPON"}, -- "Alysra's Razor"
  [71428] = {4,391,"INVTYPE_WRIST"}, -- "Flickering Wristbands"
  [71429] = {4,391,"INVTYPE_LEGS"}, -- "Moltenfeather Leggings"
  [71430] = {4,391,"INVTYPE_HEAD"}, -- "Greathelm of the Voracious Maw"
  [71431] = {4,391,"INVTYPE_LEGS"}, -- "Lavaworm Legplates"
  [71432] = {4,391,"INVTYPE_SHOULDER"}, -- "Spaulders of Recurring Flame"
  [71433] = {4,391,"INVTYPE_FINGER"}, -- "Alysrazor's Band"
  [71434] = {4,391,"INVTYPE_CLOAK"}, -- "Wings of Flame"
  [71435] = {4,391,"INVTYPE_LEGS"}, -- "Leggings of Billowing Fire"
  [71436] = {4,391,"INVTYPE_FEET"}, -- "Phoenix-Down Treads"
  [71437] = {4,391,"INVTYPE_HAND"}, -- "Clawshaper Gauntlets"
  [71438] = {4,391,"INVTYPE_SHOULDER"}, -- "Craterflame Spaulders"
  [71439] = {4,391,"INVTYPE_ROBE"}, -- "Clutch of the Firemother"
  [71440] = {4,391,"INVTYPE_HAND"}, -- "Gloves of Dissolving Smoke"
  [71441] = {4,391,"INVTYPE_WEAPON"}, -- "Feeding Frenzy"
  [71442] = {4,391,"INVTYPE_HEAD"}, -- "Scalp of the Bandit Prince"
  [71443] = {4,391,"INVTYPE_WAIST"}, -- "Uncrushable Belt of Fury"
  [71444] = {4,391,"INVTYPE_LEGS"}, -- "Legplates of Frenzied Devotion"
  [71445] = {4,391,"INVTYPE_2HWEAPON"}, -- "Skullstealer Greataxe"
  [71446] = {4,391,"INVTYPE_NECK"}, -- "Necklace of Fetishes"
  [71447] = {4,391,"INVTYPE_FEET"}, -- "Coalwalker Sandals"
  [71448] = {4,391,"INVTYPE_HOLDABLE"}, -- "Goblet of Anger"
  [71449] = {4,391,"INVTYPE_FINGER"}, -- "Crystal Prison Band"
  [71450] = {4,391,"INVTYPE_SHOULDER"}, -- "Flickering Shoulderpads"
  [71451] = {4,391,"INVTYPE_FEET"}, -- "Treads of Implicit Obedience"
  [71452] = {4,391,"INVTYPE_WRIST"}, -- "Bracers of the Dread Hunter"
  [71453] = {4,391,"INVTYPE_LEGS"}, -- "Legplates of Absolute Control"
  [71454] = {4,391,"INVTYPE_WEAPON"}, -- "Gatecrasher"
  [71455] = {4,391,"INVTYPE_CHEST"}, -- "Breastplate of the Incendiary Soul"
  [71456] = {4,391,"INVTYPE_SHOULDER"}, -- "Shoulderpads of the Forgotten Gate"
  [71457] = {4,391,"INVTYPE_FEET"}, -- "Decimation Treads"
  [71458] = {4,391,"INVTYPE_HAND"}, -- "Flickering Handguards"
  [71459] = {4,391,"INVTYPE_HEAD"}, -- "Helm of Blazing Glory"
  [71460] = {4,391,"INVTYPE_SHIELD"}, -- "Shard of Torment"
  [71461] = {4,391,"INVTYPE_SHOULDER"}, -- "Mantle of Closed Doors"
  [71462] = {4,391,"INVTYPE_HOLDABLE"}, -- "Molten Scream"
  [71463] = {4,391,"INVTYPE_WRIST"}, -- "Glowing Wing Bracers"
  [71464] = {4,391,"INVTYPE_ROBE"}, -- "Gatekeeper's Embrace"
  [71465] = {4,391,"INVTYPE_HEAD"}, -- "Casque of Flame"
  [71466] = {4,391,"INVTYPE_2HWEAPON"}, -- "Fandral's Flamescythe"
  [71467] = {4,391,"INVTYPE_FEET"}, -- "Sandals of Leaping Coals"
  [71468] = {4,391,"INVTYPE_HAND"}, -- "Grips of Unerring Precision"
  [71469] = {4,391,"INVTYPE_CHEST"}, -- "Breastplate of Shifting Visions"
  [71470] = {4,391,"INVTYPE_WRIST"}, -- "Bracers of the Fiery Path"
  [71471] = {4,391,"INVTYPE_WRIST"}, -- "Wristwraps of Arrogant Doom"
  [71472] = {4,391,"INVTYPE_NECK"}, -- "Flowform Choker"
  [71473] = {4,391,"INVTYPE_RANGEDRIGHT"}, -- "Stinger of the Flaming Scorpion"
  [71474] = {4,391,"INVTYPE_LEGS"}, -- "Firecat Leggings"
  [71475] = {4,391,"INVTYPE_FEET"}, -- "Treads of the Penitent Man"
  [71476] = {4,391,"INVTYPE_CHEST"}, -- "Elementium Deathplate Breastplate"
  [71477] = {4,391,"INVTYPE_HAND"}, -- "Elementium Deathplate Gauntlets"
  [71478] = {4,391,"INVTYPE_HEAD"}, -- "Elementium Deathplate Helmet"
  [71479] = {4,391,"INVTYPE_LEGS"}, -- "Elementium Deathplate Greaves"
  [71480] = {4,391,"INVTYPE_SHOULDER"}, -- "Elementium Deathplate Pauldrons"
  [71481] = {4,391,"INVTYPE_CHEST"}, -- "Elementium Deathplate Chestguard"
  [71482] = {4,391,"INVTYPE_HAND"}, -- "Elementium Deathplate Handguards"
  [71483] = {4,391,"INVTYPE_HEAD"}, -- "Elementium Deathplate Faceguard"
  [71484] = {4,391,"INVTYPE_LEGS"}, -- "Elementium Deathplate Legguards"
  [71485] = {4,391,"INVTYPE_SHOULDER"}, -- "Elementium Deathplate Shoulderguards"
  [71486] = {4,391,"INVTYPE_CHEST"}, -- "Obsidian Arborweave Raiment"
  [71487] = {4,391,"INVTYPE_HAND"}, -- "Obsidian Arborweave Grips"
  [71488] = {4,391,"INVTYPE_HEAD"}, -- "Obsidian Arborweave Headpiece"
  [71489] = {4,391,"INVTYPE_LEGS"}, -- "Obsidian Arborweave Legguards"
  [71490] = {4,391,"INVTYPE_SHOULDER"}, -- "Obsidian Arborweave Spaulders"
  [71491] = {4,391,"INVTYPE_HAND"}, -- "Obsidian Arborweave Handwraps"
  [71492] = {4,391,"INVTYPE_HEAD"}, -- "Obsidian Arborweave Helm"
  [71493] = {4,391,"INVTYPE_LEGS"}, -- "Obsidian Arborweave Legwraps"
  [71494] = {4,391,"INVTYPE_CHEST"}, -- "Obsidian Arborweave Tunic"
  [71495] = {4,391,"INVTYPE_SHOULDER"}, -- "Obsidian Arborweave Mantle"
  [71496] = {4,391,"INVTYPE_HAND"}, -- "Obsidian Arborweave Gloves"
  [71497] = {4,391,"INVTYPE_HEAD"}, -- "Obsidian Arborweave Cover"
  [71498] = {4,391,"INVTYPE_LEGS"}, -- "Obsidian Arborweave Leggings"
  [71499] = {4,391,"INVTYPE_CHEST"}, -- "Obsidian Arborweave Vestment"
  [71500] = {4,391,"INVTYPE_SHOULDER"}, -- "Obsidian Arborweave Shoulderwraps"
  [71501] = {4,391,"INVTYPE_CHEST"}, -- "Flamewaker's Tunic"
  [71502] = {4,391,"INVTYPE_HAND"}, -- "Flamewaker's Gloves"
  [71503] = {4,391,"INVTYPE_HEAD"}, -- "Flamewaker's Headguard"
  [71504] = {4,391,"INVTYPE_LEGS"}, -- "Flamewaker's Legguards"
  [71505] = {4,391,"INVTYPE_SHOULDER"}, -- "Flamewaker's Spaulders"
  [71507] = {4,391,"INVTYPE_HAND"}, -- "Firehawk Gloves"
  [71508] = {4,391,"INVTYPE_HEAD"}, -- "Firehawk Hood"
  [71509] = {4,391,"INVTYPE_LEGS"}, -- "Firehawk Leggings"
  [71510] = {4,391,"INVTYPE_ROBE"}, -- "Firehawk Robes"
  [71511] = {4,391,"INVTYPE_SHOULDER"}, -- "Firehawk Mantle"
  [71512] = {4,391,"INVTYPE_ROBE"}, -- "Immolation Battleplate"
  [71513] = {4,391,"INVTYPE_HAND"}, -- "Immolation Gauntlets"
  [71514] = {4,391,"INVTYPE_HEAD"}, -- "Immolation Helmet"
  [71515] = {4,391,"INVTYPE_LEGS"}, -- "Immolation Legplates"
  [71516] = {4,391,"INVTYPE_SHOULDER"}, -- "Immolation Pauldrons"
  [71517] = {4,391,"INVTYPE_ROBE"}, -- "Immolation Breastplate"
  [71518] = {4,391,"INVTYPE_HAND"}, -- "Immolation Gloves"
  [71519] = {4,391,"INVTYPE_HEAD"}, -- "Immolation Headguard"
  [71520] = {4,391,"INVTYPE_LEGS"}, -- "Immolation Greaves"
  [71521] = {4,391,"INVTYPE_SHOULDER"}, -- "Immolation Mantle"
  [71522] = {4,391,"INVTYPE_ROBE"}, -- "Immolation Chestguard"
  [71523] = {4,391,"INVTYPE_HAND"}, -- "Immolation Handguards"
  [71524] = {4,391,"INVTYPE_HEAD"}, -- "Immolation Faceguard"
  [71525] = {4,391,"INVTYPE_LEGS"}, -- "Immolation Legguards"
  [71526] = {4,391,"INVTYPE_SHOULDER"}, -- "Immolation Shoulderguards"
  [71527] = {4,391,"INVTYPE_HAND"}, -- "Handwraps of the Cleansing Flame"
  [71528] = {4,391,"INVTYPE_HEAD"}, -- "Cowl of the Cleansing Flame"
  [71529] = {4,391,"INVTYPE_LEGS"}, -- "Legwraps of the Cleansing Flame"
  [71530] = {4,391,"INVTYPE_ROBE"}, -- "Robes of the Cleansing Flame"
  [71531] = {4,391,"INVTYPE_SHOULDER"}, -- "Mantle of the Cleansing Flame"
  [71532] = {4,391,"INVTYPE_HAND"}, -- "Gloves of the Cleansing Flame"
  [71533] = {4,391,"INVTYPE_HEAD"}, -- "Hood of the Cleansing Flame"
  [71534] = {4,391,"INVTYPE_LEGS"}, -- "Leggings of the Cleansing Flame"
  [71535] = {4,391,"INVTYPE_ROBE"}, -- "Vestment of the Cleansing Flame"
  [71536] = {4,391,"INVTYPE_SHOULDER"}, -- "Shoulderwraps of the Cleansing Flame"
  [71537] = {4,391,"INVTYPE_CHEST"}, -- "Dark Phoenix Tunic"
  [71538] = {4,391,"INVTYPE_HAND"}, -- "Dark Phoenix Gloves"
  [71539] = {4,391,"INVTYPE_HEAD"}, -- "Dark Phoenix Helmet"
  [71540] = {4,391,"INVTYPE_LEGS"}, -- "Dark Phoenix Legguards"
  [71541] = {4,391,"INVTYPE_SHOULDER"}, -- "Dark Phoenix Spaulders"
  [71542] = {4,391,"INVTYPE_ROBE"}, -- "Erupting Volcanic Tunic"
  [71543] = {4,391,"INVTYPE_HAND"}, -- "Erupting Volcanic Handwraps"
  [71544] = {4,391,"INVTYPE_HEAD"}, -- "Erupting Volcanic Faceguard"
  [71545] = {4,391,"INVTYPE_LEGS"}, -- "Erupting Volcanic Legwraps"
  [71546] = {4,391,"INVTYPE_SHOULDER"}, -- "Erupting Volcanic Mantle"
  [71547] = {4,391,"INVTYPE_ROBE"}, -- "Erupting Volcanic Cuirass"
  [71548] = {4,391,"INVTYPE_HAND"}, -- "Erupting Volcanic Grips"
  [71549] = {4,391,"INVTYPE_HEAD"}, -- "Erupting Volcanic Helmet"
  [71550] = {4,391,"INVTYPE_LEGS"}, -- "Erupting Volcanic Legguards"
  [71551] = {4,391,"INVTYPE_SHOULDER"}, -- "Erupting Volcanic Spaulders"
  [71552] = {4,391,"INVTYPE_ROBE"}, -- "Erupting Volcanic Hauberk"
  [71553] = {4,391,"INVTYPE_HAND"}, -- "Erupting Volcanic Gloves"
  [71554] = {4,391,"INVTYPE_HEAD"}, -- "Erupting Volcanic Headpiece"
  [71555] = {4,391,"INVTYPE_LEGS"}, -- "Erupting Volcanic Kilt"
  [71556] = {4,391,"INVTYPE_SHOULDER"}, -- "Erupting Volcanic Shoulderwraps"
  [71557] = {4,391,"INVTYPE_2HWEAPON"}, -- "Ranseur of Hatred"
  [71558] = {4,391,"INVTYPE_RANGEDRIGHT"}, -- "Lava Bolt Crossbow"
  [71559] = {4,391,"INVTYPE_2HWEAPON"}, -- "Spire of Scarlet Pain"
  [71560] = {4,391,"INVTYPE_WEAPONMAINHAND"}, -- "Chelley's Sterilized Scalpel"
  [71561] = {4,391,"INVTYPE_WRIST"}, -- "Hide-Bound Chains"
  [71562] = {4,391,"INVTYPE_WEAPON"}, -- "Obsidium Cleaver"
  [71563] = {4,391,"INVTYPE_NECK"}, -- "Firebound Gorget"
  [71564] = {4,391,"INVTYPE_FINGER"}, -- "Theck's Emberseal"
  [71565] = {4,391,"INVTYPE_NECK"}, -- "Necklace of Smoke Signals"
  [71566] = {4,391,"INVTYPE_FINGER"}, -- "Splintered Brimstone Seal"
  [71567] = {4,391,"INVTYPE_RELIC"}, -- "Covenant of the Flame"
  [71568] = {4,391,"INVTYPE_THROWN"}, -- "Morningstar Shard"
  [71569] = {4,391,"INVTYPE_WRIST"}, -- "Flamebinder Bracers"
  [71570] = {4,391,"INVTYPE_WRIST"}, -- "Bracers of Forked Lightning"
  [71571] = {4,391,"INVTYPE_WRIST"}, -- "Emberflame Bracers"
  [71572] = {4,391,"INVTYPE_WRIST"}, -- "Firesoul Wristguards"
  [71573] = {4,391,"INVTYPE_NECK"}, -- "Amulet of Burning Brilliance"
  [71574] = {4,391,"INVTYPE_FINGER"}, -- "Crystalline Brimstone Ring"
  [71575] = {4,391,"INVTYPE_RANGEDRIGHT"}, -- "Trail of Embers"
  [71576] = {4,391,"INVTYPE_NECK"}, -- "Firemind Pendant"
  [71577] = {4,391,"INVTYPE_RELIC"}, -- "Singed Plume of Aviana"
  [71578] = {4,391,"INVTYPE_FINGER"}, -- "Soothing Brimstone Circle"
  [71579] = {4,391,"INVTYPE_RANGEDRIGHT"}, -- "Scorchvine Wand"
  [71580] = {4,391,"INVTYPE_RELIC"}, -- "Soulflame Vial"
  [71581] = {4,391,"INVTYPE_WRIST"}, -- "Smolderskull Bindings"
  [71582] = {4,391,"INVTYPE_WRIST"}, -- "Bracers of Misting Ash"
  [71583] = {4,391,"INVTYPE_WRIST"}, -- "Bracers of Imperious Truths"
  [71584] = {4,391,"INVTYPE_WRIST"}, -- "Gigantiform Bracers"
  [71585] = {4,391,"INVTYPE_WRIST"}, -- "Bracers of Regal Force"
  [71586] = {4,391,"INVTYPE_NECK"}, -- "Stoneheart Choker"
  [71587] = {4,391,"INVTYPE_RELIC"}, -- "Relic of the Elemental Lords"
  [71588] = {4,391,"INVTYPE_FINGER"}, -- "Serrated Brimstone Signet"
  [71589] = {4,391,"INVTYPE_NECK"}, -- "Stoneheart Necklace"
  [71590] = {4,391,"INVTYPE_RELIC"}, -- "Deathclutch Figurine"
  [71591] = {4,391,"INVTYPE_FINGER"}, -- "Deflecting Brimstone Band"
  [71592] = {4,391,"INVTYPE_THROWN"}, -- "Deflecting Star"
  [71593] = {4,391,"INVTYPE_THROWN"}, -- "Giantslicer"
  [71594] = {4,391,"INVTYPE_HAND"}, -- "Balespider's Handwraps"
  [71595] = {4,391,"INVTYPE_HEAD"}, -- "Balespider's Hood"
  [71596] = {4,391,"INVTYPE_LEGS"}, -- "Balespider's Leggings"
  [71597] = {4,391,"INVTYPE_ROBE"}, -- "Balespider's Robes"
  [71598] = {4,391,"INVTYPE_SHOULDER"}, -- "Balespider's Mantle"
  [71599] = {4,391,"INVTYPE_HEAD"}, -- "Helmet of the Molten Giant"
  [71600] = {4,391,"INVTYPE_CHEST"}, -- "Battleplate of the Molten Giant"
  [71601] = {4,391,"INVTYPE_HAND"}, -- "Gauntlets of the Molten Giant"
  [71602] = {4,391,"INVTYPE_LEGS"}, -- "Legplates of the Molten Giant"
  [71603] = {4,391,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Molten Giant"
  [71604] = {4,391,"INVTYPE_CHEST"}, -- "Chestguard of the Molten Giant"
  [71605] = {4,391,"INVTYPE_HAND"}, -- "Handguards of the Molten Giant"
  [71606] = {4,391,"INVTYPE_HEAD"}, -- "Faceguard of the Molten Giant"
  [71607] = {4,391,"INVTYPE_LEGS"}, -- "Legguards of the Molten Giant"
  [71608] = {4,391,"INVTYPE_SHOULDER"}, -- "Shoulderguards of the Molten Giant"
  [71610] = {4,397,"INVTYPE_NECK"}, -- "Choker of the Vanquished Lord"
  [71611] = {4,397,"INVTYPE_RANGED"}, -- "Arathar, the Eye of Flame"
  [71612] = {4,397,"INVTYPE_SHOULDER"}, -- "Pauldrons of Roaring Flame"
  [71613] = {4,397,"INVTYPE_WAIST"}, -- "Majordomo's Chain of Office"
  [71614] = {4,397,"INVTYPE_HAND"}, -- "Fingers of Incineration"
  [71615] = {4,397,"INVTYPE_WEAPONMAINHAND"}, -- "Ko'gun, Hammer of the Firelord"
  [71616] = {4,397,"INVTYPE_HEAD"}, -- "Crown of Flame"
  [71633] = {4,365,"INVTYPE_TRINKET"}, -- "Aella's Bottle"
  [71640] = {4,378,"INVTYPE_WAIST"}, -- "Riplimb's Lost Collar"
  [71641] = {4,391,"INVTYPE_WAIST"}, -- "Riplimb's Lost Collar"
  [71774] = {4,391,"INVTYPE_2HWEAPON"}, -- "Smoldering Censer of Purity"
  [71775] = {4,378,"INVTYPE_2HWEAPON"}, -- "Smoldering Censer of Purity"
  [71776] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Eye of Purification"
  [71777] = {4,391,"INVTYPE_WEAPONMAINHAND"}, -- "Eye of Purification"
  [71778] = {4,391,"INVTYPE_WEAPON"}, -- "Avool's Incendiary Shanker"
  [71779] = {4,378,"INVTYPE_WEAPON"}, -- "Avool's Incendiary Shanker"
  [71780] = {4,378,"INVTYPE_2HWEAPON"}, -- "Zoid's Firelit Greatsword"
  [71781] = {4,391,"INVTYPE_2HWEAPON"}, -- "Zoid's Firelit Greatsword"
  [71782] = {4,378,"INVTYPE_WEAPON"}, -- "Shatterskull Bonecrusher"
  [71783] = {4,391,"INVTYPE_WEAPON"}, -- "Shatterskull Bonecrusher"
  [71784] = {4,391,"INVTYPE_WEAPONMAINHAND"}, -- "Firethorn Mindslicer"
  [71785] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Firethorn Mindslicer"
  [71786] = {4,391,"INVTYPE_WEAPON"}, -- "Entrail Disgorger"
  [71787] = {4,378,"INVTYPE_WEAPON"}, -- "Entrail Disgorger"
  [71797] = {4,397,"INVTYPE_2HWEAPON"}, -- "Sho'ravon, Greatstaff of Annihilation"
  [71798] = {4,384,"INVTYPE_2HWEAPON"}, -- "Sho'ravon, Greatstaff of Annihilation"
  [71980] = {4,397,"INVTYPE_LEGS"}, -- "Lavaquake Legwraps"
  [71981] = {4,397,"INVTYPE_LEGS"}, -- "World Mender's Pants"
  [71982] = {4,397,"INVTYPE_LEGS"}, -- "Pyrium Legplates of Purified Evil"
  [71983] = {4,397,"INVTYPE_LEGS"}, -- "Unstoppable Destroyer's Legplates"
  [71984] = {4,397,"INVTYPE_LEGS"}, -- "Foundations of Courage"
  [71985] = {4,397,"INVTYPE_LEGS"}, -- "Bladeshadow Leggings"
  [71986] = {4,397,"INVTYPE_LEGS"}, -- "Leggings of Nature's Champion"
  [71987] = {4,397,"INVTYPE_LEGS"}, -- "Rended Earth Leggings"
  [71988] = {4,397,"INVTYPE_LEGS"}, -- "Deathscale Leggings"
  [71989] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of Unconquered Power"
  [71990] = {4,397,"INVTYPE_WRIST"}, -- "Dreamwraps of the Light"
  [71991] = {4,397,"INVTYPE_WRIST"}, -- "Soul Redeemer Bracers"
  [71992] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of Destructive Strength"
  [71993] = {4,397,"INVTYPE_WRIST"}, -- "Titanguard Wristplates"
  [71994] = {4,397,"INVTYPE_WRIST"}, -- "Bladeshadow Wristguards"
  [71995] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of Flowing Serenity"
  [71996] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of the Hunter-Killer"
  [71997] = {4,397,"INVTYPE_WRIST"}, -- "Thundering Deathscale Wristguards"
  [72359] = {4,390,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Emblem of Cruelty"
  [72361] = {4,390,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Emblem of Meditation"
  [72410] = {4,390,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Cruelty"
  [72411] = {4,390,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Cruelty"
  [72414] = {4,390,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Meditation"
  [72415] = {4,390,"INVTYPE_TRINKET"}, -- "Ruthless Gladiator's Medallion of Meditation"
  [72798] = {4,378,"INVTYPE_WAIST"}, -- "Cord of Lost Hope"
  [72799] = {4,378,"INVTYPE_FEET"}, -- "Dead End Boots"
  [72800] = {4,378,"INVTYPE_HAND"}, -- "Gauntlets of Temporal Interference"
  [72801] = {4,378,"INVTYPE_CHEST"}, -- "Breastplate of Sorrow"
  [72802] = {4,378,"INVTYPE_LEGS"}, -- "Time Traveler's Leggings"
  [72803] = {4,378,"INVTYPE_WAIST"}, -- "Girdle of Lost Heroes"
  [72804] = {4,378,"INVTYPE_WEAPON"}, -- "Dragonshrine Scepter"
  [72805] = {4,378,"INVTYPE_HAND"}, -- "Gloves of the Hollow"
  [72806] = {4,378,"INVTYPE_HEAD"}, -- "Echoing Headguard"
  [72807] = {4,378,"INVTYPE_WAIST"}, -- "Waistguard of Lost Time"
  [72808] = {4,378,"INVTYPE_2HWEAPON"}, -- "Jaina's Staff"
  [72809] = {4,378,"INVTYPE_SHIELD"}, -- "Ward of Incantations"
  [72810] = {4,378,"INVTYPE_RANGED"}, -- "Windrunner's Bow"
  [72811] = {4,378,"INVTYPE_CLOAK"}, -- "Cloak of the Banshee Queen"
  [72812] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Crescent Moon"
  [72813] = {4,378,"INVTYPE_ROBE"}, -- "Whisperwind Robes"
  [72814] = {4,378,"INVTYPE_2HWEAPON"}, -- "Axe of the Tauren Chieftains"
  [72815] = {4,378,"INVTYPE_LEGS"}, -- "Bloodhoof Legguards"
  [72816] = {4,378,"INVTYPE_LEGS"}, -- "Distortion Greaves"
  [72817] = {4,378,"INVTYPE_LEGS"}, -- "Time Altered Legguards"
  [72818] = {4,378,"INVTYPE_CHEST"}, -- "Breastplate of Tarnished Bronze"
  [72819] = {4,378,"INVTYPE_FEET"}, -- "Chrono Boots"
  [72820] = {4,378,"INVTYPE_HEAD"}, -- "Crown of Epochs"
  [72821] = {4,378,"INVTYPE_SHOULDER"}, -- "Temporal Pauldrons"
  [72822] = {4,378,"INVTYPE_WEAPON"}, -- "Jagged Edge of Time"
  [72823] = {4,378,"INVTYPE_HEAD"}, -- "Timeway Headgear"
  [72824] = {4,378,"INVTYPE_CHEST"}, -- "Time Twisted Tunic"
  [72825] = {4,378,"INVTYPE_SHOULDER"}, -- "Mantle of Time"
  [72826] = {4,378,"INVTYPE_ROBE"}, -- "Robes of Fate"
  [72827] = {4,378,"INVTYPE_WEAPON"}, -- "Gavel of Peroth'arn"
  [72828] = {4,378,"INVTYPE_WEAPON"}, -- "Trickster's Edge"
  [72829] = {4,378,"INVTYPE_HOLDABLE"}, -- "Orb of the First Satyrs"
  [72830] = {4,378,"INVTYPE_WAIST"}, -- "Peroth'arn's Belt"
  [72831] = {4,378,"INVTYPE_FINGER"}, -- "Horned Band"
  [72832] = {4,378,"INVTYPE_WAIST"}, -- "Girdle of the Queen's Champion"
  [72833] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Scepter of Azshara"
  [72834] = {4,378,"INVTYPE_CHEST"}, -- "Breastplate of the Queen's Guard"
  [72835] = {4,378,"INVTYPE_LEGS"}, -- "Puppeteer's Pantaloons"
  [72836] = {4,378,"INVTYPE_FEET"}, -- "Slippers of Wizardry"
  [72837] = {4,378,"INVTYPE_FINGER"}, -- "Queen's Boon"
  [72838] = {4,378,"INVTYPE_CLOAK"}, -- "Cloak of the Royal Protector"
  [72839] = {4,378,"INVTYPE_HEAD"}, -- "Cowl of Highborne Sorcerors"
  [72840] = {4,378,"INVTYPE_SHOULDER"}, -- "Spaulders of Eternity"
  [72841] = {4,378,"INVTYPE_CHEST"}, -- "Demonsbane Chestguard"
  [72842] = {4,378,"INVTYPE_HEAD"}, -- "Annihilan Helm"
  [72843] = {4,378,"INVTYPE_HEAD"}, -- "Helm of Power"
  [72844] = {4,378,"INVTYPE_2HWEAPON"}, -- "Pit Lord's Destroyer"
  [72845] = {4,378,"INVTYPE_FINGER"}, -- "Mannoroth's Signet"
  [72846] = {4,378,"INVTYPE_2HWEAPON"}, -- "Thornwood Staff"
  [72847] = {4,378,"INVTYPE_HEAD"}, -- "Helm of Thorns"
  [72848] = {4,378,"INVTYPE_LEGS"}, -- "Legguards of the Legion"
  [72849] = {4,378,"INVTYPE_FEET"}, -- "Wayfinder Boots"
  [72850] = {4,378,"INVTYPE_FEET"}, -- "Surestride Boots"
  [72851] = {4,378,"INVTYPE_WAIST"}, -- "Chillbane Belt"
  [72852] = {4,378,"INVTYPE_HAND"}, -- "Archivist's Gloves"
  [72853] = {4,378,"INVTYPE_LEGS"}, -- "Arcurion Legguards"
  [72854] = {4,378,"INVTYPE_CLOAK"}, -- "Iceward Cloak"
  [72855] = {4,378,"INVTYPE_SHIELD"}, -- "Corrupted Carapace"
  [72856] = {4,378,"INVTYPE_SHOULDER"}, -- "Pauldrons of Midnight Whispers"
  [72857] = {4,378,"INVTYPE_LEGS"}, -- "Leggings of Blinding Speed"
  [72858] = {4,378,"INVTYPE_HAND"}, -- "Safeguard Gloves"
  [72859] = {4,378,"INVTYPE_HEAD"}, -- "Dawnslayer Helm"
  [72860] = {4,378,"INVTYPE_WEAPONOFFHAND"}, -- "Mandible of the Old Ones"
  [72861] = {4,378,"INVTYPE_SHOULDER"}, -- "Pauldrons of the Dragonblight"
  [72862] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Fanged Tentacle"
  [72863] = {4,378,"INVTYPE_2HWEAPON"}, -- "Stalk of Corruption"
  [72864] = {4,378,"INVTYPE_SHOULDER"}, -- "Pauldrons of Conviction"
  [72865] = {4,378,"INVTYPE_SHOULDER"}, -- "Mantle of False Virtue"
  [72866] = {4,378,"INVTYPE_WEAPON"}, -- "Treachery's Bite"
  [72867] = {4,378,"INVTYPE_WEAPONMAINHAND"}, -- "Clattering Claw"
  [72868] = {4,378,"INVTYPE_SHOULDER"}, -- "Desecrated Shoulderguards"
  [72869] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Dragonsmaw Blaster"
  [72870] = {4,378,"INVTYPE_SHOULDER"}, -- "Betrayer's Pauldrons"
  [72871] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Crescent Wand"
  [72872] = {4,378,"INVTYPE_HAND"}, -- "Time Strand Gauntlets"
  [72873] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Bronze Blaster"
  [72874] = {4,378,"INVTYPE_FEET"}, -- "Boots of the Forked Road"
  [72875] = {4,378,"INVTYPE_HAND"}, -- "Time Twister's Gauntlets"
  [72876] = {4,378,"INVTYPE_RANGED"}, -- "Ironfeather Longbow"
  [72877] = {4,378,"INVTYPE_WAIST"}, -- "Chain of the Demon Hunter"
  [72878] = {4,378,"INVTYPE_HOLDABLE"}, -- "Demonic Skull"
  [72879] = {4,378,"INVTYPE_FEET"}, -- "Boots of the Treacherous Path"
  [72880] = {4,378,"INVTYPE_FINGER"}, -- "Alurmi's Ring"
  [72881] = {4,378,"INVTYPE_FEET"}, -- "Treads of the Past"
  [72882] = {4,378,"INVTYPE_CHEST"}, -- "Chronicler's Chestguard"
  [72883] = {4,378,"INVTYPE_WAIST"}, -- "Historian's Sash"
  [72884] = {4,378,"INVTYPE_RANGEDRIGHT"}, -- "Writhing Wand"
  [72886] = {4,378,"INVTYPE_FINGER"}, -- "Thrall's Gratitude"
  [72887] = {4,378,"INVTYPE_WAIST"}, -- "Cinch of the World Shaman"
  [72888] = {4,378,"INVTYPE_FINGER"}, -- "Ring of the Loyal Companion"
  [72897] = {4,378,"INVTYPE_TRINKET"}, -- "Arrow of Time"
  [72898] = {4,378,"INVTYPE_TRINKET"}, -- "Foul Gift of the Demon Lord"
  [72899] = {4,378,"INVTYPE_TRINKET"}, -- "Varo'then's Brooch"
  [72900] = {4,378,"INVTYPE_TRINKET"}, -- "Veil of Lies"
  [72901] = {4,378,"INVTYPE_TRINKET"}, -- "Rosary of Light"
  [73499] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Symbol of Meditation"
  [73500] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Symbol of Tenacity"
  [73501] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Symbol of Cruelty"
  [73534] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Medallion of Meditation"
  [73535] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Medallion of Meditation"
  [73538] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Medallion of Cruelty"
  [73539] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Medallion of Cruelty"
  [73577] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Mark of Meditation"
  [73579] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Mark of Cruelty"
  [73591] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Emblem of Meditation"
  [73593] = {4,403,"INVTYPE_TRINKET"}, -- "Cataclysmic Gladiator's Emblem of Cruelty"
  [74035] = {4,378,"INVTYPE_TRINKET"}, -- "Master Pit Fighter"
  [76150] = {4,378,"INVTYPE_WRIST"}, -- "Evergreen Wristbands"
  [76151] = {4,378,"INVTYPE_CLOAK"}, -- "Cloak of Subtle Light"
  [76152] = {4,378,"INVTYPE_HEAD"}, -- "Cowl of Destiny"
  [76153] = {4,378,"INVTYPE_FINGER"}, -- "Signet of the Twilight Prophet"
  [76154] = {4,378,"INVTYPE_CHEST"}, -- "Breastplate of Despair"
  [76155] = {4,378,"INVTYPE_THROWN"}, -- "Thorns of the Dying Day"
  [76156] = {4,378,"INVTYPE_WRIST"}, -- "Bindings of the End Times"
  [76157] = {4,378,"INVTYPE_HAND"}, -- "Waterworn Handguards"
  [76158] = {4,378,"INVTYPE_FEET"}, -- "Courtier's Slippers"
  [76159] = {4,378,"INVTYPE_WRIST"}, -- "Legion Bindings"
  [76160] = {4,378,"INVTYPE_CLOAK"}, -- "Drapes of the Dragonshrine"
  [76161] = {4,378,"INVTYPE_HAND"}, -- "Gauntlets of the Twilight Hour"
  [76162] = {4,378,"INVTYPE_NECK"}, -- "Twilight Amulet"
  [76212] = {4,397,"INVTYPE_HAND"}, -- "Time Lord's Gloves"
  [76213] = {4,397,"INVTYPE_HEAD"}, -- "Time Lord's Hood"
  [76214] = {4,397,"INVTYPE_LEGS"}, -- "Time Lord's Leggings"
  [76215] = {4,397,"INVTYPE_ROBE"}, -- "Time Lord's Robes"
  [76216] = {4,397,"INVTYPE_SHOULDER"}, -- "Time Lord's Mantle"
  [76339] = {4,397,"INVTYPE_SHOULDER"}, -- "Mantle of the Faceless Shroud"
  [76340] = {4,397,"INVTYPE_ROBE"}, -- "Robes of the Faceless Shroud"
  [76341] = {4,397,"INVTYPE_LEGS"}, -- "Leggings of the Faceless Shroud"
  [76342] = {4,397,"INVTYPE_HEAD"}, -- "Hood of the Faceless Shroud"
  [76343] = {4,397,"INVTYPE_HAND"}, -- "Gloves of the Faceless Shroud"
  [76344] = {4,397,"INVTYPE_SHOULDER"}, -- "Mantle of Dying Light"
  [76345] = {4,397,"INVTYPE_ROBE"}, -- "Robes of Dying Light"
  [76346] = {4,397,"INVTYPE_LEGS"}, -- "Leggings of Dying Light"
  [76347] = {4,397,"INVTYPE_HEAD"}, -- "Hood of Dying Light"
  [76348] = {4,397,"INVTYPE_HAND"}, -- "Gloves of Dying Light"
  [76357] = {4,397,"INVTYPE_HAND"}, -- "Handwraps of Dying Light"
  [76358] = {4,397,"INVTYPE_HEAD"}, -- "Cowl of Dying Light"
  [76359] = {4,397,"INVTYPE_LEGS"}, -- "Legwraps of Dying Light"
  [76360] = {4,397,"INVTYPE_ROBE"}, -- "Robes of Dying Light"
  [76361] = {4,397,"INVTYPE_SHOULDER"}, -- "Mantle of Dying Light"
  [76749] = {4,397,"INVTYPE_HAND"}, -- "Deep Earth Handwraps"
  [76750] = {4,397,"INVTYPE_HEAD"}, -- "Deep Earth Helm"
  [76751] = {4,397,"INVTYPE_LEGS"}, -- "Deep Earth Legwraps"
  [76752] = {4,397,"INVTYPE_ROBE"}, -- "Deep Earth Robes"
  [76753] = {4,397,"INVTYPE_SHOULDER"}, -- "Deep Earth Mantle"
  [76756] = {4,397,"INVTYPE_ROBE"}, -- "Spiritwalker's Tunic"
  [76757] = {4,397,"INVTYPE_HAND"}, -- "Spiritwalker's Handwraps"
  [76758] = {4,397,"INVTYPE_HEAD"}, -- "Spiritwalker's Faceguard"
  [76759] = {4,397,"INVTYPE_LEGS"}, -- "Spiritwalker's Legwraps"
  [76760] = {4,397,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Mantle"
  [76765] = {4,397,"INVTYPE_CHEST"}, -- "Breastplate of Radiant Glory"
  [76766] = {4,397,"INVTYPE_HAND"}, -- "Gloves of Radiant Glory"
  [76767] = {4,397,"INVTYPE_HEAD"}, -- "Headguard of Radiant Glory"
  [76768] = {4,397,"INVTYPE_LEGS"}, -- "Greaves of Radiant Glory"
  [76769] = {4,397,"INVTYPE_SHOULDER"}, -- "Mantle of Radiant Glory"
  [76874] = {4,397,"INVTYPE_CHEST"}, -- "Battleplate of Radiant Glory"
  [76875] = {4,397,"INVTYPE_HAND"}, -- "Gauntlets of Radiant Glory"
  [76876] = {4,397,"INVTYPE_HEAD"}, -- "Helmet of Radiant Glory"
  [76877] = {4,397,"INVTYPE_LEGS"}, -- "Legplates of Radiant Glory"
  [76878] = {4,397,"INVTYPE_SHOULDER"}, -- "Pauldrons of Radiant Glory"
  [76974] = {4,397,"INVTYPE_CHEST"}, -- "Necrotic Boneplate Breastplate"
  [76975] = {4,397,"INVTYPE_HAND"}, -- "Necrotic Boneplate Gauntlets"
  [76976] = {4,397,"INVTYPE_HEAD"}, -- "Necrotic Boneplate Helmet"
  [76977] = {4,397,"INVTYPE_LEGS"}, -- "Necrotic Boneplate Greaves"
  [76978] = {4,397,"INVTYPE_SHOULDER"}, -- "Necrotic Boneplate Pauldrons"
  [76983] = {4,397,"INVTYPE_HEAD"}, -- "Colossal Dragonplate Helmet"
  [76984] = {4,397,"INVTYPE_CHEST"}, -- "Colossal Dragonplate Battleplate"
  [76985] = {4,397,"INVTYPE_HAND"}, -- "Colossal Dragonplate Gauntlets"
  [76986] = {4,397,"INVTYPE_LEGS"}, -- "Colossal Dragonplate Legplates"
  [76987] = {4,397,"INVTYPE_SHOULDER"}, -- "Colossal Dragonplate Pauldrons"
  [76988] = {4,397,"INVTYPE_CHEST"}, -- "Colossal Dragonplate Chestguard"
  [76989] = {4,397,"INVTYPE_HAND"}, -- "Colossal Dragonplate Handguards"
  [76990] = {4,397,"INVTYPE_HEAD"}, -- "Colossal Dragonplate Faceguard"
  [76991] = {4,397,"INVTYPE_LEGS"}, -- "Colossal Dragonplate Legguards"
  [76992] = {4,397,"INVTYPE_SHOULDER"}, -- "Colossal Dragonplate Shoulderguards"
  [77003] = {4,397,"INVTYPE_CHEST"}, -- "Chestguard of Radiant Glory"
  [77004] = {4,397,"INVTYPE_HAND"}, -- "Handguards of Radiant Glory"
  [77005] = {4,397,"INVTYPE_HEAD"}, -- "Faceguard of Radiant Glory"
  [77006] = {4,397,"INVTYPE_LEGS"}, -- "Legguards of Radiant Glory"
  [77007] = {4,397,"INVTYPE_SHOULDER"}, -- "Shoulderguards of Radiant Glory"
  [77008] = {4,397,"INVTYPE_CHEST"}, -- "Necrotic Boneplate Chestguard"
  [77009] = {4,397,"INVTYPE_HAND"}, -- "Necrotic Boneplate Handguards"
  [77010] = {4,397,"INVTYPE_HEAD"}, -- "Necrotic Boneplate Faceguard"
  [77011] = {4,397,"INVTYPE_LEGS"}, -- "Necrotic Boneplate Legguards"
  [77012] = {4,397,"INVTYPE_SHOULDER"}, -- "Necrotic Boneplate Shoulderguards"
  [77013] = {4,397,"INVTYPE_ROBE"}, -- "Deep Earth Raiment"
  [77014] = {4,397,"INVTYPE_HAND"}, -- "Deep Earth Grips"
  [77015] = {4,397,"INVTYPE_HEAD"}, -- "Deep Earth Headpiece"
  [77016] = {4,397,"INVTYPE_LEGS"}, -- "Deep Earth Legguards"
  [77017] = {4,397,"INVTYPE_SHOULDER"}, -- "Deep Earth Spaulders"
  [77018] = {4,397,"INVTYPE_HAND"}, -- "Deep Earth Gloves"
  [77019] = {4,397,"INVTYPE_HEAD"}, -- "Deep Earth Cover"
  [77020] = {4,397,"INVTYPE_LEGS"}, -- "Deep Earth Leggings"
  [77021] = {4,397,"INVTYPE_ROBE"}, -- "Deep Earth Vestment"
  [77022] = {4,397,"INVTYPE_SHOULDER"}, -- "Deep Earth Shoulderwraps"
  [77023] = {4,397,"INVTYPE_CHEST"}, -- "Blackfang Battleweave Tunic"
  [77024] = {4,397,"INVTYPE_HAND"}, -- "Blackfang Battleweave Gloves"
  [77025] = {4,397,"INVTYPE_HEAD"}, -- "Blackfang Battleweave Helmet"
  [77026] = {4,397,"INVTYPE_LEGS"}, -- "Blackfang Battleweave Legguards"
  [77027] = {4,397,"INVTYPE_SHOULDER"}, -- "Blackfang Battleweave Spaulders"
  [77028] = {4,397,"INVTYPE_CHEST"}, -- "Wyrmstalker's Tunic"
  [77029] = {4,397,"INVTYPE_HAND"}, -- "Wyrmstalker's Gloves"
  [77030] = {4,397,"INVTYPE_HEAD"}, -- "Wyrmstalker's Headguard"
  [77031] = {4,397,"INVTYPE_LEGS"}, -- "Wyrmstalker's Legguards"
  [77032] = {4,397,"INVTYPE_SHOULDER"}, -- "Wyrmstalker's Spaulders"
  [77035] = {4,397,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Shoulderwraps"
  [77036] = {4,397,"INVTYPE_LEGS"}, -- "Spiritwalker's Kilt"
  [77037] = {4,397,"INVTYPE_HEAD"}, -- "Spiritwalker's Headpiece"
  [77038] = {4,397,"INVTYPE_HAND"}, -- "Spiritwalker's Gloves"
  [77039] = {4,397,"INVTYPE_ROBE"}, -- "Spiritwalker's Hauberk"
  [77040] = {4,397,"INVTYPE_ROBE"}, -- "Spiritwalker's Cuirass"
  [77041] = {4,397,"INVTYPE_HAND"}, -- "Spiritwalker's Grips"
  [77042] = {4,397,"INVTYPE_HEAD"}, -- "Spiritwalker's Helmet"
  [77043] = {4,397,"INVTYPE_LEGS"}, -- "Spiritwalker's Legguards"
  [77044] = {4,397,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Spaulders"
  [77078] = {4,397,"INVTYPE_RANGEDRIGHT"}, -- "Scintillating Rods"
  [77079] = {4,397,"INVTYPE_RANGEDRIGHT"}, -- "Hungermouth Wand"
  [77080] = {4,397,"INVTYPE_RELIC"}, -- "Ripfang Relic"
  [77081] = {4,397,"INVTYPE_RELIC"}, -- "Gutripper Shard"
  [77082] = {4,397,"INVTYPE_RELIC"}, -- "Mindbender Lens"
  [77083] = {4,397,"INVTYPE_RELIC"}, -- "Lightning Spirit in a Bottle"
  [77084] = {4,397,"INVTYPE_RELIC"}, -- "Stoutheart Talisman"
  [77085] = {4,397,"INVTYPE_THROWN"}, -- "Unexpected Backup"
  [77086] = {4,397,"INVTYPE_THROWN"}, -- "Windslicer Boomerang"
  [77087] = {4,397,"INVTYPE_THROWN"}, -- "Darting Chakram"
  [77088] = {4,397,"INVTYPE_NECK"}, -- "Opal of the Secret Order"
  [77089] = {4,397,"INVTYPE_NECK"}, -- "Threadlinked Chain"
  [77090] = {4,397,"INVTYPE_NECK"}, -- "Necklace of Black Dragon's Teeth"
  [77091] = {4,397,"INVTYPE_NECK"}, -- "Cameo of Terrible Memories"
  [77092] = {4,397,"INVTYPE_NECK"}, -- "Guardspike Choker"
  [77095] = {4,397,"INVTYPE_CLOAK"}, -- "Batwing Cloak"
  [77096] = {4,397,"INVTYPE_CLOAK"}, -- "Woundlicker Cover"
  [77097] = {4,397,"INVTYPE_CLOAK"}, -- "Dreamcrusher Drape"
  [77098] = {4,397,"INVTYPE_CLOAK"}, -- "Nanoprecise Cape"
  [77099] = {4,397,"INVTYPE_CLOAK"}, -- "Indefatigable Greatcloak"
  [77108] = {4,397,"INVTYPE_FINGER"}, -- "Seal of the Grand Architect"
  [77109] = {4,397,"INVTYPE_FINGER"}, -- "Band of Reconstruction"
  [77110] = {4,397,"INVTYPE_FINGER"}, -- "Ring of Torn Flesh"
  [77111] = {4,397,"INVTYPE_FINGER"}, -- "Emergency Descent Loop"
  [77112] = {4,397,"INVTYPE_FINGER"}, -- "Signet of the Resolute"
  [77113] = {4,397,"INVTYPE_TRINKET"}, -- "Kiroptyric Sigil"
  [77114] = {4,397,"INVTYPE_TRINKET"}, -- "Bottled Wishes"
  [77115] = {4,397,"INVTYPE_TRINKET"}, -- "Reflection of the Light"
  [77116] = {4,397,"INVTYPE_TRINKET"}, -- "Rotting Skull"
  [77117] = {4,397,"INVTYPE_TRINKET"}, -- "Fire of the Deep"
  [77119] = {4,397,"INVTYPE_CHEST"}, -- "Bones of the Damned"
  [77120] = {4,397,"INVTYPE_CHEST"}, -- "Chestplate of the Unshakable Titan"
  [77121] = {4,397,"INVTYPE_ROBE"}, -- "Lightwarper Vestments"
  [77122] = {4,397,"INVTYPE_ROBE"}, -- "Robes of Searing Shadow"
  [77123] = {4,397,"INVTYPE_CHEST"}, -- "Shining Carapace of Glory"
  [77124] = {4,397,"INVTYPE_CHEST"}, -- "Dragonflayer Vest"
  [77125] = {4,397,"INVTYPE_CHEST"}, -- "Ghostworld Chestguard"
  [77126] = {4,397,"INVTYPE_CHEST"}, -- "Shadowbinder Chestguard"
  [77127] = {4,397,"INVTYPE_ROBE"}, -- "Decaying Herbalist's Robes"
  [77146] = {4,397,"INVTYPE_HEAD"}, -- "Soulgaze Cowl"
  [77147] = {4,397,"INVTYPE_HEAD"}, -- "Hood of Hidden Flesh"
  [77148] = {4,397,"INVTYPE_HEAD"}, -- "Nocturnal Gaze"
  [77149] = {4,397,"INVTYPE_HEAD"}, -- "Helmet of Perpetual Rebirth"
  [77150] = {4,397,"INVTYPE_HEAD"}, -- "Zeherah's Dragonskull Crown"
  [77151] = {4,397,"INVTYPE_HEAD"}, -- "Wolfdream Circlet"
  [77153] = {4,397,"INVTYPE_HEAD"}, -- "Glowing Wings of Hope"
  [77155] = {4,397,"INVTYPE_HEAD"}, -- "Visage of Petrification"
  [77156] = {4,397,"INVTYPE_HEAD"}, -- "Jaw of Repudiation"
  [77157] = {4,397,"INVTYPE_HAND"}, -- "The Hands of Gilly"
  [77159] = {4,397,"INVTYPE_HAND"}, -- "Clockwinder's Immaculate Gloves"
  [77160] = {4,397,"INVTYPE_HAND"}, -- "Fungus-Born Gloves"
  [77161] = {4,397,"INVTYPE_HAND"}, -- "Lightfinger Handwraps"
  [77162] = {4,397,"INVTYPE_HAND"}, -- "Arrowflick Gauntlets"
  [77163] = {4,397,"INVTYPE_HAND"}, -- "Gloves of Ghostly Dreams"
  [77164] = {4,397,"INVTYPE_HAND"}, -- "Gleaming Grips of Mending"
  [77165] = {4,397,"INVTYPE_HAND"}, -- "Grimfist Crushers"
  [77166] = {4,397,"INVTYPE_HAND"}, -- "Gauntlets of Feathery Blows"
  [77169] = {4,397,"INVTYPE_FEET"}, -- "Silver Sabatons of Fury"
  [77170] = {4,397,"INVTYPE_FEET"}, -- "Kneebreaker Boots"
  [77171] = {4,397,"INVTYPE_FEET"}, -- "Bladeshatter Treads"
  [77172] = {4,397,"INVTYPE_FEET"}, -- "Boots of Fungoid Growth"
  [77173] = {4,397,"INVTYPE_FEET"}, -- "Rooftop Griptoes"
  [77174] = {4,397,"INVTYPE_FEET"}, -- "Sabatons of the Graceful Spirit"
  [77175] = {4,397,"INVTYPE_FEET"}, -- "Boneshard Boots"
  [77176] = {4,397,"INVTYPE_FEET"}, -- "Kavan's Forsaken Treads"
  [77177] = {4,397,"INVTYPE_FEET"}, -- "Splinterfoot Sandals"
  [77179] = {4,397,"INVTYPE_WAIST"}, -- "Tentacular Belt"
  [77180] = {4,397,"INVTYPE_WAIST"}, -- "Belt of Hidden Keys"
  [77181] = {4,397,"INVTYPE_WAIST"}, -- "Belt of Universal Curing"
  [77182] = {4,397,"INVTYPE_WAIST"}, -- "Cord of Dragon Sinew"
  [77183] = {4,397,"INVTYPE_WAIST"}, -- "Girdle of Shamanic Fury"
  [77184] = {4,397,"INVTYPE_WAIST"}, -- "Blinding Girdle of Truth"
  [77185] = {4,397,"INVTYPE_WAIST"}, -- "Demonbone Waistguard"
  [77186] = {4,397,"INVTYPE_WAIST"}, -- "Forgesmelter Waistplate"
  [77187] = {4,397,"INVTYPE_WAIST"}, -- "Vestal's Irrepressible Girdle"
  [77188] = {4,403,"INVTYPE_WEAPON"}, -- "No'Kaled, the Elements of Death"
  [77189] = {4,403,"INVTYPE_WEAPON"}, -- "Blade of the Unmaker"
  [77190] = {4,403,"INVTYPE_2HWEAPON"}, -- "Ti'tahk, the Steps of Time"
  [77191] = {4,403,"INVTYPE_2HWEAPON"}, -- "Gurthalak, Voice of the Deeps"
  [77192] = {4,397,"INVTYPE_RANGEDRIGHT"}, -- "Ruinblaster Shotgun"
  [77193] = {4,403,"INVTYPE_WEAPON"}, -- "Souldrinker"
  [77194] = {4,403,"INVTYPE_2HWEAPON"}, -- "Kiril, Fury of Beasts"
  [77195] = {4,403,"INVTYPE_WEAPONMAINHAND"}, -- "Rathrak, the Poisonous Mind"
  [77196] = {4,403,"INVTYPE_WEAPONMAINHAND"}, -- "Maw of the Dragonlord"
  [77197] = {4,403,"INVTYPE_TRINKET"}, -- "Wrath of Unchaining"
  [77198] = {4,403,"INVTYPE_TRINKET"}, -- "Will of Unbinding"
  [77199] = {4,403,"INVTYPE_TRINKET"}, -- "Heart of Unliving"
  [77200] = {4,403,"INVTYPE_TRINKET"}, -- "Eye of Unmaking"
  [77201] = {4,403,"INVTYPE_TRINKET"}, -- "Resolve of Undying"
  [77202] = {4,397,"INVTYPE_TRINKET"}, -- "Starcatcher Compass"
  [77203] = {4,397,"INVTYPE_TRINKET"}, -- "Insignia of the Corrupted Mind"
  [77204] = {4,397,"INVTYPE_TRINKET"}, -- "Seal of the Seven Signs"
  [77205] = {4,397,"INVTYPE_TRINKET"}, -- "Creche of the Final Dragon"
  [77206] = {4,397,"INVTYPE_TRINKET"}, -- "Soulshifter Vortex"
  [77207] = {4,397,"INVTYPE_TRINKET"}, -- "Vial of Shadows"
  [77208] = {4,397,"INVTYPE_TRINKET"}, -- "Cunning of the Cruel"
  [77209] = {4,397,"INVTYPE_TRINKET"}, -- "Windward Heart"
  [77210] = {4,397,"INVTYPE_TRINKET"}, -- "Bone-Link Fetish"
  [77211] = {4,397,"INVTYPE_TRINKET"}, -- "Indomitable Pride"
  [77212] = {4,397,"INVTYPE_WEAPON"}, -- "Hand of Morchok"
  [77213] = {4,397,"INVTYPE_THROWN"}, -- "Razor Saronite Chip"
  [77214] = {4,397,"INVTYPE_WEAPONMAINHAND"}, -- "Vagaries of Time"
  [77215] = {4,397,"INVTYPE_RANGEDRIGHT"}, -- "Horrifying Horn Arbalest"
  [77216] = {4,397,"INVTYPE_RANGEDRIGHT"}, -- "Finger of Zon'ozz"
  [77217] = {4,397,"INVTYPE_2HWEAPON"}, -- "Experimental Specimen Slicer"
  [77218] = {4,397,"INVTYPE_2HWEAPON"}, -- "Spire of Coagulated Globules"
  [77219] = {4,397,"INVTYPE_WEAPONMAINHAND"}, -- "Scalpel of Unrelenting Agony"
  [77220] = {4,397,"INVTYPE_WEAPON"}, -- "Electrowing Dagger"
  [77221] = {4,397,"INVTYPE_2HWEAPON"}, -- "Lightning Rod"
  [77223] = {4,397,"INVTYPE_WEAPON"}, -- "Morningstar of Heroic Will"
  [77224] = {4,397,"INVTYPE_2HWEAPON"}, -- "Ataraxis, Cudgel of the Warmaster"
  [77225] = {4,397,"INVTYPE_2HWEAPON"}, -- "Visage of the Destroyer"
  [77226] = {4,397,"INVTYPE_SHIELD"}, -- "Blackhorn's Mighty Bulwark"
  [77227] = {4,397,"INVTYPE_SHIELD"}, -- "Timepiece of the Bronze Flight"
  [77228] = {4,397,"INVTYPE_FINGER"}, -- "Infinite Loop"
  [77229] = {4,397,"INVTYPE_FINGER"}, -- "Signet of Suturing"
  [77230] = {4,397,"INVTYPE_FINGER"}, -- "Breathstealer Band"
  [77231] = {4,397,"INVTYPE_FINGER"}, -- "Seal of Primordial Shadow"
  [77232] = {4,397,"INVTYPE_FINGER"}, -- "Hardheart Ring"
  [77234] = {4,397,"INVTYPE_FEET"}, -- "Janglespur Jackboots"
  [77235] = {4,403,"INVTYPE_HAND"}, -- "Gauntlets of the Golden Thorn"
  [77236] = {4,403,"INVTYPE_SHOULDER"}, -- "Backbreaker Spaulders"
  [77237] = {4,403,"INVTYPE_WAIST"}, -- "Belt of Shattered Elementium"
  [77238] = {4,403,"INVTYPE_FEET"}, -- "Molten Blood Footpads"
  [77239] = {4,397,"INVTYPE_WAIST"}, -- "Goriona's Collar"
  [77240] = {4,397,"INVTYPE_WRIST"}, -- "Shadow Wing Armbands"
  [77241] = {4,397,"INVTYPE_WAIST"}, -- "Belt of the Beloved Companion"
  [77242] = {4,397,"INVTYPE_SHOULDER"}, -- "Imperfect Specimens 27 and 28"
  [77243] = {4,397,"INVTYPE_FEET"}, -- "Treads of Sordid Screams"
  [77244] = {4,397,"INVTYPE_WAIST"}, -- "Dragonfracture Belt"
  [77245] = {4,397,"INVTYPE_HOLDABLE"}, -- "Ledger of Revolting Rituals"
  [77246] = {4,397,"INVTYPE_FEET"}, -- "Stillheart Warboots"
  [77247] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of Looming Darkness"
  [77248] = {4,397,"INVTYPE_WAIST"}, -- "Girdle of the Grotesque"
  [77249] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of the Banished"
  [77250] = {4,397,"INVTYPE_WAIST"}, -- "Runescriven Demon Collar"
  [77251] = {4,397,"INVTYPE_FEET"}, -- "Treads of Dormant Dreams"
  [77252] = {4,397,"INVTYPE_FEET"}, -- "Mindstrainer Treads"
  [77253] = {4,397,"INVTYPE_WRIST"}, -- "Heartblood Wristplates"
  [77254] = {4,397,"INVTYPE_FEET"}, -- "Interrogator's Bloody Footpads"
  [77255] = {4,397,"INVTYPE_WAIST"}, -- "Cord of the Slain Champion"
  [77257] = {4,397,"INVTYPE_WRIST"}, -- "Grotesquely Writhing Bracers"
  [77258] = {4,397,"INVTYPE_WRIST"}, -- "Graveheart Bracers"
  [77259] = {4,397,"INVTYPE_FEET"}, -- "Treads of Crushed Flesh"
  [77260] = {4,397,"INVTYPE_WAIST"}, -- "Belt of Flayed Skin"
  [77261] = {4,397,"INVTYPE_WRIST"}, -- "Mycosynth Wristguards"
  [77262] = {4,397,"INVTYPE_NECK"}, -- "Petrified Fungal Heart"
  [77263] = {4,397,"INVTYPE_ROBE"}, -- "Robe of Glowing Stone"
  [77265] = {4,397,"INVTYPE_FEET"}, -- "Pillarfoot Greaves"
  [77266] = {4,397,"INVTYPE_WAIST"}, -- "Girdle of Shattered Stone"
  [77267] = {4,397,"INVTYPE_SHOULDER"}, -- "Mosswrought Shoulderguards"
  [77268] = {4,397,"INVTYPE_SHOULDER"}, -- "Brackenshell Shoulderplates"
  [77269] = {4,397,"INVTYPE_HAND"}, -- "Sporebeard Gauntlets"
  [77270] = {4,397,"INVTYPE_WRIST"}, -- "Rockhide Bracers"
  [77271] = {4,397,"INVTYPE_SHOULDER"}, -- "Underdweller's Spaulders"
  [77316] = {4,397,"INVTYPE_WRIST"}, -- "Flashing Bracers of Warmth"
  [77317] = {4,397,"INVTYPE_WRIST"}, -- "Heartcrusher Wristplates"
  [77318] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of Unrelenting Excellence"
  [77319] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of the Spectral Wolf"
  [77320] = {4,397,"INVTYPE_WRIST"}, -- "Luminescent Bracers"
  [77321] = {4,397,"INVTYPE_WRIST"}, -- "Dragonbelly Bracers"
  [77322] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of Manifold Pockets"
  [77323] = {4,397,"INVTYPE_WRIST"}, -- "Bracers of the Black Dream"
  [77324] = {4,397,"INVTYPE_WRIST"}, -- "Chronoboost Bracers"
  [77938] = {4,397,"INVTYPE_HOLDABLE"}, -- "Dragonfire Orb"
  [77945] = {4,397,"INVTYPE_WEAPONMAINHAND"}, -- "Fear"
  [77946] = {4,397,"INVTYPE_WEAPONOFFHAND"}, -- "Vengeance"
  [77947] = {4,406,"INVTYPE_WEAPONMAINHAND"}, -- "The Sleeper"
  [77948] = {4,406,"INVTYPE_WEAPONOFFHAND"}, -- "The Dreamer"
  [77969] = {4,384,"INVTYPE_TRINKET"}, -- "Seal of the Seven Signs"
  [77970] = {4,384,"INVTYPE_TRINKET"}, -- "Soulshifter Vortex"
  [77971] = {4,384,"INVTYPE_TRINKET"}, -- "Insignia of the Corrupted Mind"
  [77972] = {4,384,"INVTYPE_TRINKET"}, -- "Creche of the Final Dragon"
  [77973] = {4,384,"INVTYPE_TRINKET"}, -- "Starcatcher Compass"
  [77974] = {4,390,"INVTYPE_TRINKET"}, -- "Wrath of Unchaining"
  [77975] = {4,390,"INVTYPE_TRINKET"}, -- "Will of Unbinding"
  [77976] = {4,390,"INVTYPE_TRINKET"}, -- "Heart of Unliving"
  [77977] = {4,390,"INVTYPE_TRINKET"}, -- "Eye of Unmaking"
  [77978] = {4,390,"INVTYPE_TRINKET"}, -- "Resolve of Undying"
  [77979] = {4,384,"INVTYPE_TRINKET"}, -- "Vial of Shadows"
  [77980] = {4,384,"INVTYPE_TRINKET"}, -- "Cunning of the Cruel"
  [77981] = {4,384,"INVTYPE_TRINKET"}, -- "Windward Heart"
  [77982] = {4,384,"INVTYPE_TRINKET"}, -- "Bone-Link Fetish"
  [77983] = {4,384,"INVTYPE_TRINKET"}, -- "Indomitable Pride"
  [77984] = {4,384,"INVTYPE_TRINKET"}, -- "Kiroptyric Sigil"
  [77985] = {4,384,"INVTYPE_TRINKET"}, -- "Bottled Wishes"
  [77986] = {4,384,"INVTYPE_TRINKET"}, -- "Reflection of the Light"
  [77987] = {4,384,"INVTYPE_TRINKET"}, -- "Rotting Skull"
  [77988] = {4,384,"INVTYPE_TRINKET"}, -- "Fire of the Deep"
  [77989] = {4,410,"INVTYPE_TRINKET"}, -- "Seal of the Seven Signs"
  [77990] = {4,410,"INVTYPE_TRINKET"}, -- "Soulshifter Vortex"
  [77991] = {4,410,"INVTYPE_TRINKET"}, -- "Insignia of the Corrupted Mind"
  [77992] = {4,410,"INVTYPE_TRINKET"}, -- "Creche of the Final Dragon"
  [77993] = {4,410,"INVTYPE_TRINKET"}, -- "Starcatcher Compass"
  [77994] = {4,416,"INVTYPE_TRINKET"}, -- "Wrath of Unchaining"
  [77995] = {4,416,"INVTYPE_TRINKET"}, -- "Will of Unbinding"
  [77996] = {4,416,"INVTYPE_TRINKET"}, -- "Heart of Unliving"
  [77997] = {4,416,"INVTYPE_TRINKET"}, -- "Eye of Unmaking"
  [77998] = {4,416,"INVTYPE_TRINKET"}, -- "Resolve of Undying"
  [77999] = {4,410,"INVTYPE_TRINKET"}, -- "Vial of Shadows"
  [78000] = {4,410,"INVTYPE_TRINKET"}, -- "Cunning of the Cruel"
  [78001] = {4,410,"INVTYPE_TRINKET"}, -- "Windward Heart"
  [78002] = {4,410,"INVTYPE_TRINKET"}, -- "Bone-Link Fetish"
  [78003] = {4,410,"INVTYPE_TRINKET"}, -- "Indomitable Pride"
  [78004] = {4,410,"INVTYPE_TRINKET"}, -- "Kiroptyric Sigil"
  [78005] = {4,410,"INVTYPE_TRINKET"}, -- "Bottled Wishes"
  [78006] = {4,410,"INVTYPE_TRINKET"}, -- "Reflection of the Light"
  [78007] = {4,410,"INVTYPE_TRINKET"}, -- "Rotting Skull"
  [78008] = {4,410,"INVTYPE_TRINKET"}, -- "Fire of the Deep"
  [78011] = {4,397,"INVTYPE_FINGER"}, -- "Signet of Grasping Mouths"
  [78012] = {4,397,"INVTYPE_FINGER"}, -- "Ring of the Riven"
  [78013] = {4,397,"INVTYPE_FINGER"}, -- "Curled Twilight Claw"
  [78357] = {4,403,"INVTYPE_HAND"}, -- "Gloves of Liquid Smoke"
  [78359] = {4,403,"INVTYPE_RANGED"}, -- "Vishanka, Jaws of the Earth"
  [78361] = {4,410,"INVTYPE_FEET"}, -- "Pillarfoot Greaves"
  [78362] = {4,410,"INVTYPE_HAND"}, -- "Sporebeard Gauntlets"
  [78363] = {4,410,"INVTYPE_WEAPONMAINHAND"}, -- "Vagaries of Time"
  [78364] = {4,410,"INVTYPE_NECK"}, -- "Petrified Fungal Heart"
  [78365] = {4,410,"INVTYPE_ROBE"}, -- "Robe of Glowing Stone"
  [78366] = {4,410,"INVTYPE_SHOULDER"}, -- "Mosswrought Shoulderguards"
  [78367] = {4,410,"INVTYPE_SHOULDER"}, -- "Brackenshell Shoulderplates"
  [78368] = {4,410,"INVTYPE_SHOULDER"}, -- "Underdweller's Spaulders"
  [78369] = {4,410,"INVTYPE_THROWN"}, -- "Razor Saronite Chip"
  [78370] = {4,410,"INVTYPE_WAIST"}, -- "Girdle of Shattered Stone"
  [78371] = {4,410,"INVTYPE_WEAPON"}, -- "Hand of Morchok"
  [78372] = {4,410,"INVTYPE_WRIST"}, -- "Mycosynth Wristguards"
  [78373] = {4,410,"INVTYPE_WRIST"}, -- "Rockhide Bracers"
  [78374] = {4,384,"INVTYPE_THROWN"}, -- "Razor Saronite Chip"
  [78375] = {4,384,"INVTYPE_SHOULDER"}, -- "Underdweller's Spaulders"
  [78376] = {4,384,"INVTYPE_HAND"}, -- "Sporebeard Gauntlets"
  [78377] = {4,384,"INVTYPE_WRIST"}, -- "Rockhide Bracers"
  [78378] = {4,384,"INVTYPE_SHOULDER"}, -- "Brackenshell Shoulderplates"
  [78379] = {4,384,"INVTYPE_WEAPON"}, -- "Hand of Morchok"
  [78380] = {4,384,"INVTYPE_ROBE"}, -- "Robe of Glowing Stone"
  [78381] = {4,384,"INVTYPE_SHOULDER"}, -- "Mosswrought Shoulderguards"
  [78382] = {4,384,"INVTYPE_NECK"}, -- "Petrified Fungal Heart"
  [78383] = {4,384,"INVTYPE_WEAPONMAINHAND"}, -- "Vagaries of Time"
  [78384] = {4,384,"INVTYPE_WRIST"}, -- "Mycosynth Wristguards"
  [78385] = {4,384,"INVTYPE_WAIST"}, -- "Girdle of Shattered Stone"
  [78386] = {4,384,"INVTYPE_FEET"}, -- "Pillarfoot Greaves"
  [78387] = {4,410,"INVTYPE_RANGEDRIGHT"}, -- "Horrifying Horn Arbalest"
  [78388] = {4,410,"INVTYPE_WAIST"}, -- "Belt of Flayed Skin"
  [78389] = {4,410,"INVTYPE_FEET"}, -- "Treads of Crushed Flesh"
  [78390] = {4,410,"INVTYPE_WRIST"}, -- "Graveheart Bracers"
  [78391] = {4,410,"INVTYPE_WAIST"}, -- "Cord of the Slain Champion"
  [78392] = {4,410,"INVTYPE_RANGEDRIGHT"}, -- "Finger of Zon'ozz"
  [78393] = {4,410,"INVTYPE_WRIST"}, -- "Grotesquely Writhing Bracers"
  [78394] = {4,384,"INVTYPE_RANGEDRIGHT"}, -- "Horrifying Horn Arbalest"
  [78395] = {4,384,"INVTYPE_WAIST"}, -- "Belt of Flayed Skin"
  [78396] = {4,384,"INVTYPE_FEET"}, -- "Treads of Crushed Flesh"
  [78397] = {4,384,"INVTYPE_WRIST"}, -- "Graveheart Bracers"
  [78398] = {4,384,"INVTYPE_WAIST"}, -- "Cord of the Slain Champion"
  [78399] = {4,384,"INVTYPE_RANGEDRIGHT"}, -- "Finger of Zon'ozz"
  [78400] = {4,384,"INVTYPE_WRIST"}, -- "Grotesquely Writhing Bracers"
  [78401] = {4,410,"INVTYPE_2HWEAPON"}, -- "Spire of Coagulated Globules"
  [78402] = {4,410,"INVTYPE_FEET"}, -- "Interrogator's Bloody Footpads"
  [78403] = {4,410,"INVTYPE_2HWEAPON"}, -- "Experimental Specimen Slicer"
  [78404] = {4,410,"INVTYPE_WEAPONMAINHAND"}, -- "Scalpel of Unrelenting Agony"
  [78405] = {4,410,"INVTYPE_FEET"}, -- "Mindstrainer Treads"
  [78406] = {4,410,"INVTYPE_WRIST"}, -- "Heartblood Wristplates"
  [78407] = {4,384,"INVTYPE_2HWEAPON"}, -- "Spire of Coagulated Globules"
  [78408] = {4,384,"INVTYPE_FEET"}, -- "Interrogator's Bloody Footpads"
  [78409] = {4,384,"INVTYPE_2HWEAPON"}, -- "Experimental Specimen Slicer"
  [78410] = {4,384,"INVTYPE_WEAPONMAINHAND"}, -- "Scalpel of Unrelenting Agony"
  [78411] = {4,384,"INVTYPE_FEET"}, -- "Mindstrainer Treads"
  [78412] = {4,384,"INVTYPE_WRIST"}, -- "Heartblood Wristplates"
  [78413] = {4,410,"INVTYPE_FINGER"}, -- "Signet of Grasping Mouths"
  [78414] = {4,410,"INVTYPE_WEAPON"}, -- "Electrowing Dagger"
  [78415] = {4,410,"INVTYPE_FEET"}, -- "Treads of Dormant Dreams"
  [78416] = {4,410,"INVTYPE_WAIST"}, -- "Runescriven Demon Collar"
  [78417] = {4,410,"INVTYPE_WRIST"}, -- "Bracers of the Banished"
  [78418] = {4,410,"INVTYPE_2HWEAPON"}, -- "Lightning Rod"
  [78419] = {4,410,"INVTYPE_FINGER"}, -- "Ring of the Riven"
  [78420] = {4,410,"INVTYPE_WAIST"}, -- "Girdle of the Grotesque"
  [78421] = {4,384,"INVTYPE_FINGER"}, -- "Signet of Grasping Mouths"
  [78422] = {4,384,"INVTYPE_WEAPON"}, -- "Electrowing Dagger"
  [78423] = {4,384,"INVTYPE_FEET"}, -- "Treads of Dormant Dreams"
  [78424] = {4,384,"INVTYPE_WAIST"}, -- "Runescriven Demon Collar"
  [78425] = {4,384,"INVTYPE_WRIST"}, -- "Bracers of the Banished"
  [78426] = {4,384,"INVTYPE_2HWEAPON"}, -- "Lightning Rod"
  [78427] = {4,384,"INVTYPE_FINGER"}, -- "Ring of the Riven"
  [78428] = {4,384,"INVTYPE_WAIST"}, -- "Girdle of the Grotesque"
  [78429] = {4,410,"INVTYPE_WEAPON"}, -- "Morningstar of Heroic Will"
  [78430] = {4,410,"INVTYPE_WRIST"}, -- "Bracers of Looming Darkness"
  [78431] = {4,410,"INVTYPE_FEET"}, -- "Stillheart Warboots"
  [78432] = {4,410,"INVTYPE_FINGER"}, -- "Curled Twilight Claw"
  [78433] = {4,410,"INVTYPE_HOLDABLE"}, -- "Ledger of Revolting Rituals"
  [78434] = {4,410,"INVTYPE_FEET"}, -- "Treads of Sordid Screams"
  [78435] = {4,410,"INVTYPE_SHOULDER"}, -- "Imperfect Specimens 27 and 28"
  [78436] = {4,410,"INVTYPE_WAIST"}, -- "Dragonfracture Belt"
  [78437] = {4,384,"INVTYPE_WEAPON"}, -- "Morningstar of Heroic Will"
  [78438] = {4,384,"INVTYPE_WRIST"}, -- "Bracers of Looming Darkness"
  [78439] = {4,384,"INVTYPE_FEET"}, -- "Stillheart Warboots"
  [78440] = {4,384,"INVTYPE_FINGER"}, -- "Curled Twilight Claw"
  [78441] = {4,384,"INVTYPE_HOLDABLE"}, -- "Ledger of Revolting Rituals"
  [78442] = {4,384,"INVTYPE_FEET"}, -- "Treads of Sordid Screams"
  [78443] = {4,384,"INVTYPE_SHOULDER"}, -- "Imperfect Specimens 27 and 28"
  [78444] = {4,384,"INVTYPE_WAIST"}, -- "Dragonfracture Belt"
  [78445] = {4,410,"INVTYPE_2HWEAPON"}, -- "Ataraxis, Cudgel of the Warmaster"
  [78446] = {4,410,"INVTYPE_WRIST"}, -- "Shadow Wing Armbands"
  [78447] = {4,410,"INVTYPE_WAIST"}, -- "Belt of the Beloved Companion"
  [78448] = {4,410,"INVTYPE_SHIELD"}, -- "Blackhorn's Mighty Bulwark"
  [78449] = {4,410,"INVTYPE_FEET"}, -- "Janglespur Jackboots"
  [78450] = {4,410,"INVTYPE_SHIELD"}, -- "Timepiece of the Bronze Flight"
  [78451] = {4,410,"INVTYPE_2HWEAPON"}, -- "Visage of the Destroyer"
  [78452] = {4,410,"INVTYPE_WAIST"}, -- "Goriona's Collar"
  [78453] = {4,384,"INVTYPE_2HWEAPON"}, -- "Ataraxis, Cudgel of the Warmaster"
  [78454] = {4,384,"INVTYPE_WRIST"}, -- "Shadow Wing Armbands"
  [78455] = {4,384,"INVTYPE_WAIST"}, -- "Belt of the Beloved Companion"
  [78456] = {4,384,"INVTYPE_SHIELD"}, -- "Blackhorn's Mighty Bulwark"
  [78457] = {4,384,"INVTYPE_FEET"}, -- "Janglespur Jackboots"
  [78458] = {4,384,"INVTYPE_SHIELD"}, -- "Timepiece of the Bronze Flight"
  [78459] = {4,384,"INVTYPE_2HWEAPON"}, -- "Visage of the Destroyer"
  [78460] = {4,384,"INVTYPE_WAIST"}, -- "Goriona's Collar"
  [78461] = {4,416,"INVTYPE_HAND"}, -- "Gloves of Liquid Smoke"
  [78462] = {4,416,"INVTYPE_FEET"}, -- "Molten Blood Footpads"
  [78463] = {4,416,"INVTYPE_WAIST"}, -- "Belt of Shattered Elementium"
  [78464] = {4,416,"INVTYPE_HAND"}, -- "Gauntlets of the Golden Thorn"
  [78465] = {4,416,"INVTYPE_SHOULDER"}, -- "Backbreaker Spaulders"
  [78466] = {4,390,"INVTYPE_HAND"}, -- "Gloves of Liquid Smoke"
  [78467] = {4,390,"INVTYPE_FEET"}, -- "Molten Blood Footpads"
  [78468] = {4,390,"INVTYPE_WAIST"}, -- "Belt of Shattered Elementium"
  [78469] = {4,390,"INVTYPE_HAND"}, -- "Gauntlets of the Golden Thorn"
  [78470] = {4,390,"INVTYPE_SHOULDER"}, -- "Backbreaker Spaulders"
  [78471] = {4,416,"INVTYPE_RANGED"}, -- "Vishanka, Jaws of the Earth"
  [78472] = {4,416,"INVTYPE_WEAPON"}, -- "No'Kaled, the Elements of Death"
  [78473] = {4,416,"INVTYPE_2HWEAPON"}, -- "Kiril, Fury of Beasts"
  [78474] = {4,416,"INVTYPE_WEAPON"}, -- "Blade of the Unmaker"
  [78475] = {4,416,"INVTYPE_WEAPONMAINHAND"}, -- "Rathrak, the Poisonous Mind"
  [78476] = {4,416,"INVTYPE_WEAPONMAINHAND"}, -- "Maw of the Dragonlord"
  [78477] = {4,416,"INVTYPE_2HWEAPON"}, -- "Ti'tahk, the Steps of Time"
  [78478] = {4,416,"INVTYPE_2HWEAPON"}, -- "Gurthalak, Voice of the Deeps"
  [78479] = {4,416,"INVTYPE_WEAPON"}, -- "Souldrinker"
  [78480] = {4,390,"INVTYPE_RANGED"}, -- "Vishanka, Jaws of the Earth"
  [78481] = {4,390,"INVTYPE_WEAPON"}, -- "No'Kaled, the Elements of Death"
  [78482] = {4,390,"INVTYPE_2HWEAPON"}, -- "Kiril, Fury of Beasts"
  [78483] = {4,390,"INVTYPE_WEAPON"}, -- "Blade of the Unmaker"
  [78484] = {4,390,"INVTYPE_WEAPONMAINHAND"}, -- "Rathrak, the Poisonous Mind"
  [78485] = {4,390,"INVTYPE_WEAPONMAINHAND"}, -- "Maw of the Dragonlord"
  [78486] = {4,390,"INVTYPE_2HWEAPON"}, -- "Ti'tahk, the Steps of Time"
  [78487] = {4,390,"INVTYPE_2HWEAPON"}, -- "Gurthalak, Voice of the Deeps"
  [78488] = {4,390,"INVTYPE_WEAPON"}, -- "Souldrinker"
  [78489] = {4,410,"INVTYPE_FINGER"}, -- "Seal of Primordial Shadow"
  [78490] = {4,410,"INVTYPE_FINGER"}, -- "Infinite Loop"
  [78491] = {4,410,"INVTYPE_FINGER"}, -- "Signet of Suturing"
  [78492] = {4,410,"INVTYPE_FINGER"}, -- "Breathstealer Band"
  [78493] = {4,410,"INVTYPE_FINGER"}, -- "Hardheart Ring"
  [78494] = {4,384,"INVTYPE_FINGER"}, -- "Seal of Primordial Shadow"
  [78495] = {4,384,"INVTYPE_FINGER"}, -- "Infinite Loop"
  [78496] = {4,384,"INVTYPE_FINGER"}, -- "Signet of Suturing"
  [78497] = {4,384,"INVTYPE_FINGER"}, -- "Breathstealer Band"
  [78498] = {4,384,"INVTYPE_FINGER"}, -- "Hardheart Ring"
  [78499] = {4,410,"INVTYPE_CHEST"}, -- "Bones of the Damned"
  [78500] = {4,410,"INVTYPE_CHEST"}, -- "Chestplate of the Unshakable Titan"
  [78501] = {4,410,"INVTYPE_CHEST"}, -- "Dragonflayer Vest"
  [78502] = {4,410,"INVTYPE_CHEST"}, -- "Ghostworld Chestguard"
  [78503] = {4,410,"INVTYPE_CHEST"}, -- "Shining Carapace of Glory"
  [78504] = {4,410,"INVTYPE_CHEST"}, -- "Shadowbinder Chestguard"
  [78505] = {4,410,"INVTYPE_ROBE"}, -- "Decaying Herbalist's Robes"
  [78506] = {4,410,"INVTYPE_CLOAK"}, -- "Dreamcrusher Drape"
  [78507] = {4,410,"INVTYPE_CLOAK"}, -- "Indefatigable Greatcloak"
  [78508] = {4,410,"INVTYPE_CLOAK"}, -- "Woundlicker Cover"
  [78509] = {4,410,"INVTYPE_CLOAK"}, -- "Batwing Cloak"
  [78510] = {4,410,"INVTYPE_CLOAK"}, -- "Nanoprecise Cape"
  [78511] = {4,410,"INVTYPE_FEET"}, -- "Bladeshatter Treads"
  [78512] = {4,410,"INVTYPE_FEET"}, -- "Boneshard Boots"
  [78513] = {4,410,"INVTYPE_FEET"}, -- "Sabatons of the Graceful Spirit"
  [78514] = {4,410,"INVTYPE_FEET"}, -- "Silver Sabatons of Fury"
  [78515] = {4,410,"INVTYPE_FEET"}, -- "Kneebreaker Boots"
  [78516] = {4,410,"INVTYPE_FEET"}, -- "Rooftop Griptoes"
  [78517] = {4,410,"INVTYPE_FEET"}, -- "Boots of Fungoid Growth"
  [78518] = {4,410,"INVTYPE_FEET"}, -- "Kavan's Forsaken Treads"
  [78519] = {4,410,"INVTYPE_FEET"}, -- "Splinterfoot Sandals"
  [78520] = {4,410,"INVTYPE_FINGER"}, -- "Ring of Torn Flesh"
  [78521] = {4,410,"INVTYPE_FINGER"}, -- "Signet of the Resolute"
  [78522] = {4,410,"INVTYPE_FINGER"}, -- "Seal of the Grand Architect"
  [78523] = {4,410,"INVTYPE_FINGER"}, -- "Band of Reconstruction"
  [78524] = {4,410,"INVTYPE_FINGER"}, -- "Emergency Descent Loop"
  [78525] = {4,410,"INVTYPE_HAND"}, -- "Grimfist Crushers"
  [78526] = {4,410,"INVTYPE_HAND"}, -- "Gauntlets of Feathery Blows"
  [78527] = {4,410,"INVTYPE_HAND"}, -- "Arrowflick Gauntlets"
  [78528] = {4,410,"INVTYPE_HAND"}, -- "Gloves of Ghostly Dreams"
  [78529] = {4,410,"INVTYPE_HAND"}, -- "Gleaming Grips of Mending"
  [78530] = {4,410,"INVTYPE_HAND"}, -- "Lightfinger Handwraps"
  [78531] = {4,410,"INVTYPE_HAND"}, -- "Fungus-Born Gloves"
  [78532] = {4,410,"INVTYPE_HAND"}, -- "Clockwinder's Immaculate Gloves"
  [78533] = {4,410,"INVTYPE_HAND"}, -- "The Hands of Gilly"
  [78534] = {4,410,"INVTYPE_HEAD"}, -- "Visage of Petrification"
  [78535] = {4,410,"INVTYPE_HEAD"}, -- "Jaw of Repudiation"
  [78536] = {4,410,"INVTYPE_HEAD"}, -- "Zeherah's Dragonskull Crown"
  [78537] = {4,410,"INVTYPE_HEAD"}, -- "Wolfdream Circlet"
  [78538] = {4,410,"INVTYPE_HEAD"}, -- "Glowing Wings of Hope"
  [78539] = {4,410,"INVTYPE_HEAD"}, -- "Nocturnal Gaze"
  [78540] = {4,410,"INVTYPE_HEAD"}, -- "Helmet of Perpetual Rebirth"
  [78541] = {4,410,"INVTYPE_HEAD"}, -- "Hood of Hidden Flesh"
  [78542] = {4,410,"INVTYPE_HEAD"}, -- "Soulgaze Cowl"
  [78543] = {4,410,"INVTYPE_NECK"}, -- "Necklace of Black Dragon's Teeth"
  [78544] = {4,410,"INVTYPE_NECK"}, -- "Guardspike Choker"
  [78545] = {4,410,"INVTYPE_NECK"}, -- "Threadlinked Chain"
  [78546] = {4,410,"INVTYPE_NECK"}, -- "Cameo of Terrible Memories"
  [78547] = {4,410,"INVTYPE_NECK"}, -- "Opal of the Secret Order"
  [78548] = {4,410,"INVTYPE_RANGEDRIGHT"}, -- "Hungermouth Wand"
  [78549] = {4,410,"INVTYPE_RANGEDRIGHT"}, -- "Scintillating Rods"
  [78550] = {4,410,"INVTYPE_RELIC"}, -- "Gutripper Shard"
  [78551] = {4,410,"INVTYPE_RELIC"}, -- "Stoutheart Talisman"
  [78552] = {4,410,"INVTYPE_RELIC"}, -- "Lightning Spirit in a Bottle"
  [78553] = {4,410,"INVTYPE_RELIC"}, -- "Mindbender Lens"
  [78554] = {4,410,"INVTYPE_RELIC"}, -- "Ripfang Relic"
  [78555] = {4,410,"INVTYPE_ROBE"}, -- "Robes of Searing Shadow"
  [78556] = {4,410,"INVTYPE_ROBE"}, -- "Lightwarper Vestments"
  [78557] = {4,410,"INVTYPE_THROWN"}, -- "Unexpected Backup"
  [78558] = {4,410,"INVTYPE_THROWN"}, -- "Darting Chakram"
  [78559] = {4,410,"INVTYPE_THROWN"}, -- "Windslicer Boomerang"
  [78560] = {4,410,"INVTYPE_WAIST"}, -- "Forgesmelter Waistplate"
  [78561] = {4,410,"INVTYPE_WAIST"}, -- "Cord of Dragon Sinew"
  [78562] = {4,410,"INVTYPE_WAIST"}, -- "Girdle of Shamanic Fury"
  [78563] = {4,410,"INVTYPE_WAIST"}, -- "Blinding Girdle of Truth"
  [78564] = {4,410,"INVTYPE_WAIST"}, -- "Demonbone Waistguard"
  [78565] = {4,410,"INVTYPE_WAIST"}, -- "Belt of Hidden Keys"
  [78566] = {4,410,"INVTYPE_WAIST"}, -- "Belt of Universal Curing"
  [78567] = {4,410,"INVTYPE_WAIST"}, -- "Tentacular Belt"
  [78568] = {4,410,"INVTYPE_WAIST"}, -- "Vestal's Irrepressible Girdle"
  [78569] = {4,410,"INVTYPE_WRIST"}, -- "Heartcrusher Wristplates"
  [78570] = {4,410,"INVTYPE_WRIST"}, -- "Bracers of Unrelenting Excellence"
  [78571] = {4,410,"INVTYPE_WRIST"}, -- "Dragonbelly Bracers"
  [78572] = {4,410,"INVTYPE_WRIST"}, -- "Bracers of the Spectral Wolf"
  [78573] = {4,410,"INVTYPE_WRIST"}, -- "Flashing Bracers of Warmth"
  [78574] = {4,410,"INVTYPE_WRIST"}, -- "Bracers of Manifold Pockets"
  [78575] = {4,410,"INVTYPE_WRIST"}, -- "Luminescent Bracers"
  [78576] = {4,410,"INVTYPE_WRIST"}, -- "Chronoboost Bracers"
  [78577] = {4,410,"INVTYPE_WRIST"}, -- "Bracers of the Black Dream"
  [78578] = {4,384,"INVTYPE_CHEST"}, -- "Shining Carapace of Glory"
  [78579] = {4,384,"INVTYPE_CHEST"}, -- "Dragonflayer Vest"
  [78580] = {4,384,"INVTYPE_CHEST"}, -- "Ghostworld Chestguard"
  [78581] = {4,384,"INVTYPE_CHEST"}, -- "Shadowbinder Chestguard"
  [78582] = {4,384,"INVTYPE_ROBE"}, -- "Decaying Herbalist's Robes"
  [78583] = {4,384,"INVTYPE_CHEST"}, -- "Bones of the Damned"
  [78584] = {4,384,"INVTYPE_CHEST"}, -- "Chestplate of the Unshakable Titan"
  [78585] = {4,384,"INVTYPE_CLOAK"}, -- "Woundlicker Cover"
  [78586] = {4,384,"INVTYPE_CLOAK"}, -- "Dreamcrusher Drape"
  [78587] = {4,384,"INVTYPE_CLOAK"}, -- "Batwing Cloak"
  [78588] = {4,384,"INVTYPE_CLOAK"}, -- "Nanoprecise Cape"
  [78589] = {4,384,"INVTYPE_CLOAK"}, -- "Indefatigable Greatcloak"
  [78590] = {4,384,"INVTYPE_FEET"}, -- "Kneebreaker Boots"
  [78591] = {4,384,"INVTYPE_FEET"}, -- "Bladeshatter Treads"
  [78592] = {4,384,"INVTYPE_FEET"}, -- "Boots of Fungoid Growth"
  [78593] = {4,384,"INVTYPE_FEET"}, -- "Silver Sabatons of Fury"
  [78594] = {4,384,"INVTYPE_FEET"}, -- "Rooftop Griptoes"
  [78595] = {4,384,"INVTYPE_FEET"}, -- "Sabatons of the Graceful Spirit"
  [78596] = {4,384,"INVTYPE_FEET"}, -- "Boneshard Boots"
  [78597] = {4,384,"INVTYPE_FEET"}, -- "Kavan's Forsaken Treads"
  [78598] = {4,384,"INVTYPE_FEET"}, -- "Splinterfoot Sandals"
  [78599] = {4,384,"INVTYPE_FINGER"}, -- "Emergency Descent Loop"
  [78600] = {4,384,"INVTYPE_FINGER"}, -- "Seal of the Grand Architect"
  [78601] = {4,384,"INVTYPE_FINGER"}, -- "Band of Reconstruction"
  [78602] = {4,384,"INVTYPE_FINGER"}, -- "Signet of the Resolute"
  [78603] = {4,384,"INVTYPE_FINGER"}, -- "Ring of Torn Flesh"
  [78604] = {4,384,"INVTYPE_HAND"}, -- "Fungus-Born Gloves"
  [78605] = {4,384,"INVTYPE_HAND"}, -- "Grimfist Crushers"
  [78606] = {4,384,"INVTYPE_HAND"}, -- "Gauntlets of Feathery Blows"
  [78607] = {4,384,"INVTYPE_HAND"}, -- "The Hands of Gilly"
  [78608] = {4,384,"INVTYPE_HAND"}, -- "Clockwinder's Immaculate Gloves"
  [78609] = {4,384,"INVTYPE_HAND"}, -- "Lightfinger Handwraps"
  [78610] = {4,384,"INVTYPE_HAND"}, -- "Arrowflick Gauntlets"
  [78611] = {4,384,"INVTYPE_HAND"}, -- "Gloves of Ghostly Dreams"
  [78612] = {4,384,"INVTYPE_HAND"}, -- "Gleaming Grips of Mending"
  [78613] = {4,384,"INVTYPE_HEAD"}, -- "Wolfdream Circlet"
  [78614] = {4,384,"INVTYPE_HEAD"}, -- "Visage of Petrification"
  [78615] = {4,384,"INVTYPE_HEAD"}, -- "Jaw of Repudiation"
  [78616] = {4,384,"INVTYPE_HEAD"}, -- "Hood of Hidden Flesh"
  [78617] = {4,384,"INVTYPE_HEAD"}, -- "Nocturnal Gaze"
  [78618] = {4,384,"INVTYPE_HEAD"}, -- "Helmet of Perpetual Rebirth"
  [78619] = {4,384,"INVTYPE_HEAD"}, -- "Zeherah's Dragonskull Crown"
  [78620] = {4,384,"INVTYPE_HEAD"}, -- "Soulgaze Cowl"
  [78621] = {4,384,"INVTYPE_HEAD"}, -- "Glowing Wings of Hope"
  [78622] = {4,384,"INVTYPE_NECK"}, -- "Cameo of Terrible Memories"
  [78623] = {4,384,"INVTYPE_NECK"}, -- "Guardspike Choker"
  [78624] = {4,384,"INVTYPE_NECK"}, -- "Opal of the Secret Order"
  [78625] = {4,384,"INVTYPE_NECK"}, -- "Necklace of Black Dragon's Teeth"
  [78626] = {4,384,"INVTYPE_NECK"}, -- "Threadlinked Chain"
  [78627] = {4,384,"INVTYPE_RANGEDRIGHT"}, -- "Hungermouth Wand"
  [78628] = {4,384,"INVTYPE_RANGEDRIGHT"}, -- "Scintillating Rods"
  [78629] = {4,384,"INVTYPE_RELIC"}, -- "Gutripper Shard"
  [78630] = {4,384,"INVTYPE_RELIC"}, -- "Mindbender Lens"
  [78631] = {4,384,"INVTYPE_RELIC"}, -- "Lightning Spirit in a Bottle"
  [78632] = {4,384,"INVTYPE_RELIC"}, -- "Stoutheart Talisman"
  [78633] = {4,384,"INVTYPE_RELIC"}, -- "Ripfang Relic"
  [78634] = {4,384,"INVTYPE_ROBE"}, -- "Robes of Searing Shadow"
  [78635] = {4,384,"INVTYPE_ROBE"}, -- "Lightwarper Vestments"
  [78636] = {4,384,"INVTYPE_THROWN"}, -- "Unexpected Backup"
  [78637] = {4,384,"INVTYPE_THROWN"}, -- "Windslicer Boomerang"
  [78638] = {4,384,"INVTYPE_THROWN"}, -- "Darting Chakram"
  [78639] = {4,384,"INVTYPE_WAIST"}, -- "Tentacular Belt"
  [78640] = {4,384,"INVTYPE_WAIST"}, -- "Belt of Hidden Keys"
  [78641] = {4,384,"INVTYPE_WAIST"}, -- "Belt of Universal Curing"
  [78642] = {4,384,"INVTYPE_WAIST"}, -- "Cord of Dragon Sinew"
  [78643] = {4,384,"INVTYPE_WAIST"}, -- "Girdle of Shamanic Fury"
  [78644] = {4,384,"INVTYPE_WAIST"}, -- "Blinding Girdle of Truth"
  [78645] = {4,384,"INVTYPE_WAIST"}, -- "Demonbone Waistguard"
  [78646] = {4,384,"INVTYPE_WAIST"}, -- "Forgesmelter Waistplate"
  [78647] = {4,384,"INVTYPE_WAIST"}, -- "Vestal's Irrepressible Girdle"
  [78648] = {4,384,"INVTYPE_WRIST"}, -- "Flashing Bracers of Warmth"
  [78649] = {4,384,"INVTYPE_WRIST"}, -- "Heartcrusher Wristplates"
  [78650] = {4,384,"INVTYPE_WRIST"}, -- "Bracers of Unrelenting Excellence"
  [78651] = {4,384,"INVTYPE_WRIST"}, -- "Bracers of the Spectral Wolf"
  [78652] = {4,384,"INVTYPE_WRIST"}, -- "Luminescent Bracers"
  [78653] = {4,384,"INVTYPE_WRIST"}, -- "Dragonbelly Bracers"
  [78654] = {4,384,"INVTYPE_WRIST"}, -- "Bracers of Manifold Pockets"
  [78655] = {4,384,"INVTYPE_WRIST"}, -- "Bracers of the Black Dream"
  [78656] = {4,384,"INVTYPE_WRIST"}, -- "Chronoboost Bracers"
  [78657] = {4,410,"INVTYPE_CHEST"}, -- "Colossal Dragonplate Battleplate"
  [78658] = {4,410,"INVTYPE_CHEST"}, -- "Colossal Dragonplate Chestguard"
  [78659] = {4,410,"INVTYPE_CHEST"}, -- "Necrotic Boneplate Breastplate"
  [78660] = {4,410,"INVTYPE_ROBE"}, -- "Deep Earth Robes"
  [78661] = {4,410,"INVTYPE_CHEST"}, -- "Wyrmstalker's Tunic"
  [78662] = {4,410,"INVTYPE_ROBE"}, -- "Deep Earth Vestment"
  [78663] = {4,410,"INVTYPE_CHEST"}, -- "Necrotic Boneplate Chestguard"
  [78664] = {4,410,"INVTYPE_CHEST"}, -- "Blackfang Battleweave Tunic"
  [78665] = {4,410,"INVTYPE_ROBE"}, -- "Deep Earth Raiment"
  [78666] = {4,410,"INVTYPE_HAND"}, -- "Spiritwalker's Gloves"
  [78667] = {4,410,"INVTYPE_HAND"}, -- "Spiritwalker's Grips"
  [78668] = {4,410,"INVTYPE_HAND"}, -- "Colossal Dragonplate Gauntlets"
  [78669] = {4,410,"INVTYPE_HAND"}, -- "Colossal Dragonplate Handguards"
  [78670] = {4,410,"INVTYPE_HAND"}, -- "Necrotic Boneplate Gauntlets"
  [78671] = {4,410,"INVTYPE_HAND"}, -- "Time Lord's Gloves"
  [78672] = {4,410,"INVTYPE_HAND"}, -- "Spiritwalker's Handwraps"
  [78673] = {4,410,"INVTYPE_HAND"}, -- "Gloves of Radiant Glory"
  [78674] = {4,410,"INVTYPE_HAND"}, -- "Wyrmstalker's Gloves"
  [78675] = {4,410,"INVTYPE_HAND"}, -- "Gauntlets of Radiant Glory"
  [78676] = {4,410,"INVTYPE_HAND"}, -- "Deep Earth Gloves"
  [78677] = {4,410,"INVTYPE_HAND"}, -- "Handguards of Radiant Glory"
  [78678] = {4,410,"INVTYPE_HAND"}, -- "Necrotic Boneplate Handguards"
  [78679] = {4,410,"INVTYPE_HAND"}, -- "Blackfang Battleweave Gloves"
  [78680] = {4,410,"INVTYPE_HAND"}, -- "Deep Earth Handwraps"
  [78681] = {4,410,"INVTYPE_HAND"}, -- "Gloves of the Faceless Shroud"
  [78682] = {4,410,"INVTYPE_HAND"}, -- "Gloves of Dying Light"
  [78683] = {4,410,"INVTYPE_HAND"}, -- "Handwraps of Dying Light"
  [78684] = {4,410,"INVTYPE_HAND"}, -- "Deep Earth Grips"
  [78685] = {4,410,"INVTYPE_HEAD"}, -- "Spiritwalker's Headpiece"
  [78686] = {4,410,"INVTYPE_HEAD"}, -- "Spiritwalker's Helmet"
  [78687] = {4,410,"INVTYPE_HEAD"}, -- "Necrotic Boneplate Helmet"
  [78688] = {4,410,"INVTYPE_HEAD"}, -- "Colossal Dragonplate Helmet"
  [78689] = {4,410,"INVTYPE_HEAD"}, -- "Colossal Dragonplate Faceguard"
  [78690] = {4,410,"INVTYPE_HEAD"}, -- "Deep Earth Helm"
  [78691] = {4,410,"INVTYPE_HEAD"}, -- "Spiritwalker's Faceguard"
  [78692] = {4,410,"INVTYPE_HEAD"}, -- "Headguard of Radiant Glory"
  [78693] = {4,410,"INVTYPE_HEAD"}, -- "Helmet of Radiant Glory"
  [78694] = {4,410,"INVTYPE_HEAD"}, -- "Deep Earth Headpiece"
  [78695] = {4,410,"INVTYPE_HEAD"}, -- "Faceguard of Radiant Glory"
  [78696] = {4,410,"INVTYPE_HEAD"}, -- "Deep Earth Cover"
  [78697] = {4,410,"INVTYPE_HEAD"}, -- "Necrotic Boneplate Faceguard"
  [78698] = {4,410,"INVTYPE_HEAD"}, -- "Wyrmstalker's Headguard"
  [78699] = {4,410,"INVTYPE_HEAD"}, -- "Blackfang Battleweave Helmet"
  [78700] = {4,410,"INVTYPE_HEAD"}, -- "Cowl of Dying Light"
  [78701] = {4,410,"INVTYPE_HEAD"}, -- "Time Lord's Hood"
  [78702] = {4,410,"INVTYPE_HEAD"}, -- "Hood of the Faceless Shroud"
  [78703] = {4,410,"INVTYPE_HEAD"}, -- "Hood of Dying Light"
  [78704] = {4,410,"INVTYPE_LEGS"}, -- "Spiritwalker's Legguards"
  [78705] = {4,410,"INVTYPE_LEGS"}, -- "Colossal Dragonplate Legguards"
  [78706] = {4,410,"INVTYPE_LEGS"}, -- "Colossal Dragonplate Legplates"
  [78707] = {4,410,"INVTYPE_LEGS"}, -- "Necrotic Boneplate Greaves"
  [78708] = {4,410,"INVTYPE_LEGS"}, -- "Blackfang Battleweave Legguards"
  [78709] = {4,410,"INVTYPE_LEGS"}, -- "Wyrmstalker's Legguards"
  [78710] = {4,410,"INVTYPE_LEGS"}, -- "Deep Earth Legwraps"
  [78711] = {4,410,"INVTYPE_LEGS"}, -- "Spiritwalker's Kilt"
  [78712] = {4,410,"INVTYPE_LEGS"}, -- "Legplates of Radiant Glory"
  [78713] = {4,410,"INVTYPE_LEGS"}, -- "Deep Earth Legguards"
  [78714] = {4,410,"INVTYPE_LEGS"}, -- "Deep Earth Leggings"
  [78715] = {4,410,"INVTYPE_LEGS"}, -- "Legguards of Radiant Glory"
  [78716] = {4,410,"INVTYPE_LEGS"}, -- "Necrotic Boneplate Legguards"
  [78717] = {4,410,"INVTYPE_LEGS"}, -- "Greaves of Radiant Glory"
  [78718] = {4,410,"INVTYPE_LEGS"}, -- "Spiritwalker's Legwraps"
  [78719] = {4,410,"INVTYPE_LEGS"}, -- "Legwraps of Dying Light"
  [78720] = {4,410,"INVTYPE_LEGS"}, -- "Time Lord's Leggings"
  [78721] = {4,410,"INVTYPE_LEGS"}, -- "Leggings of the Faceless Shroud"
  [78722] = {4,410,"INVTYPE_LEGS"}, -- "Leggings of Dying Light"
  [78723] = {4,410,"INVTYPE_ROBE"}, -- "Spiritwalker's Hauberk"
  [78724] = {4,410,"INVTYPE_ROBE"}, -- "Spiritwalker's Cuirass"
  [78725] = {4,410,"INVTYPE_ROBE"}, -- "Spiritwalker's Tunic"
  [78726] = {4,410,"INVTYPE_CHEST"}, -- "Breastplate of Radiant Glory"
  [78727] = {4,410,"INVTYPE_CHEST"}, -- "Battleplate of Radiant Glory"
  [78728] = {4,410,"INVTYPE_ROBE"}, -- "Robes of Dying Light"
  [78729] = {4,410,"INVTYPE_ROBE"}, -- "Time Lord's Robes"
  [78730] = {4,410,"INVTYPE_ROBE"}, -- "Robes of the Faceless Shroud"
  [78731] = {4,410,"INVTYPE_ROBE"}, -- "Robes of Dying Light"
  [78732] = {4,410,"INVTYPE_CHEST"}, -- "Chestguard of Radiant Glory"
  [78733] = {4,410,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Spaulders"
  [78734] = {4,410,"INVTYPE_SHOULDER"}, -- "Colossal Dragonplate Shoulderguards"
  [78735] = {4,410,"INVTYPE_SHOULDER"}, -- "Colossal Dragonplate Pauldrons"
  [78736] = {4,410,"INVTYPE_SHOULDER"}, -- "Necrotic Boneplate Pauldrons"
  [78737] = {4,410,"INVTYPE_SHOULDER"}, -- "Wyrmstalker's Spaulders"
  [78738] = {4,410,"INVTYPE_SHOULDER"}, -- "Blackfang Battleweave Spaulders"
  [78739] = {4,410,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Mantle"
  [78740] = {4,410,"INVTYPE_SHOULDER"}, -- "Deep Earth Mantle"
  [78741] = {4,410,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Shoulderwraps"
  [78742] = {4,410,"INVTYPE_SHOULDER"}, -- "Pauldrons of Radiant Glory"
  [78743] = {4,410,"INVTYPE_SHOULDER"}, -- "Deep Earth Spaulders"
  [78744] = {4,410,"INVTYPE_SHOULDER"}, -- "Deep Earth Shoulderwraps"
  [78745] = {4,410,"INVTYPE_SHOULDER"}, -- "Shoulderguards of Radiant Glory"
  [78746] = {4,410,"INVTYPE_SHOULDER"}, -- "Mantle of Radiant Glory"
  [78747] = {4,410,"INVTYPE_SHOULDER"}, -- "Mantle of Dying Light"
  [78748] = {4,410,"INVTYPE_SHOULDER"}, -- "Time Lord's Mantle"
  [78749] = {4,410,"INVTYPE_SHOULDER"}, -- "Mantle of the Faceless Shroud"
  [78750] = {4,410,"INVTYPE_SHOULDER"}, -- "Mantle of Dying Light"
  [78751] = {4,410,"INVTYPE_SHOULDER"}, -- "Necrotic Boneplate Shoulderguards"
  [78752] = {4,384,"INVTYPE_CHEST"}, -- "Colossal Dragonplate Battleplate"
  [78753] = {4,384,"INVTYPE_CHEST"}, -- "Colossal Dragonplate Chestguard"
  [78754] = {4,384,"INVTYPE_CHEST"}, -- "Necrotic Boneplate Breastplate"
  [78755] = {4,384,"INVTYPE_ROBE"}, -- "Deep Earth Robes"
  [78756] = {4,384,"INVTYPE_CHEST"}, -- "Wyrmstalker's Tunic"
  [78757] = {4,384,"INVTYPE_ROBE"}, -- "Deep Earth Vestment"
  [78758] = {4,384,"INVTYPE_CHEST"}, -- "Necrotic Boneplate Chestguard"
  [78759] = {4,384,"INVTYPE_CHEST"}, -- "Blackfang Battleweave Tunic"
  [78760] = {4,384,"INVTYPE_ROBE"}, -- "Deep Earth Raiment"
  [78761] = {4,384,"INVTYPE_HAND"}, -- "Spiritwalker's Gloves"
  [78762] = {4,384,"INVTYPE_HAND"}, -- "Spiritwalker's Grips"
  [78763] = {4,384,"INVTYPE_HAND"}, -- "Colossal Dragonplate Gauntlets"
  [78764] = {4,384,"INVTYPE_HAND"}, -- "Colossal Dragonplate Handguards"
  [78765] = {4,384,"INVTYPE_HAND"}, -- "Necrotic Boneplate Gauntlets"
  [78766] = {4,384,"INVTYPE_HAND"}, -- "Time Lord's Gloves"
  [78767] = {4,384,"INVTYPE_HAND"}, -- "Spiritwalker's Handwraps"
  [78768] = {4,384,"INVTYPE_HAND"}, -- "Gloves of Radiant Glory"
  [78769] = {4,384,"INVTYPE_HAND"}, -- "Wyrmstalker's Gloves"
  [78770] = {4,384,"INVTYPE_HAND"}, -- "Gauntlets of Radiant Glory"
  [78771] = {4,384,"INVTYPE_HAND"}, -- "Deep Earth Gloves"
  [78772] = {4,384,"INVTYPE_HAND"}, -- "Handguards of Radiant Glory"
  [78773] = {4,384,"INVTYPE_HAND"}, -- "Necrotic Boneplate Handguards"
  [78774] = {4,384,"INVTYPE_HAND"}, -- "Blackfang Battleweave Gloves"
  [78775] = {4,384,"INVTYPE_HAND"}, -- "Deep Earth Handwraps"
  [78776] = {4,384,"INVTYPE_HAND"}, -- "Gloves of the Faceless Shroud"
  [78777] = {4,384,"INVTYPE_HAND"}, -- "Gloves of Dying Light"
  [78778] = {4,384,"INVTYPE_HAND"}, -- "Handwraps of Dying Light"
  [78779] = {4,384,"INVTYPE_HAND"}, -- "Deep Earth Grips"
  [78780] = {4,384,"INVTYPE_HEAD"}, -- "Spiritwalker's Headpiece"
  [78781] = {4,384,"INVTYPE_HEAD"}, -- "Spiritwalker's Helmet"
  [78782] = {4,384,"INVTYPE_HEAD"}, -- "Necrotic Boneplate Helmet"
  [78783] = {4,384,"INVTYPE_HEAD"}, -- "Colossal Dragonplate Helmet"
  [78784] = {4,384,"INVTYPE_HEAD"}, -- "Colossal Dragonplate Faceguard"
  [78785] = {4,384,"INVTYPE_HEAD"}, -- "Deep Earth Helm"
  [78786] = {4,384,"INVTYPE_HEAD"}, -- "Spiritwalker's Faceguard"
  [78787] = {4,384,"INVTYPE_HEAD"}, -- "Headguard of Radiant Glory"
  [78788] = {4,384,"INVTYPE_HEAD"}, -- "Helmet of Radiant Glory"
  [78789] = {4,384,"INVTYPE_HEAD"}, -- "Deep Earth Headpiece"
  [78790] = {4,384,"INVTYPE_HEAD"}, -- "Faceguard of Radiant Glory"
  [78791] = {4,384,"INVTYPE_HEAD"}, -- "Deep Earth Cover"
  [78792] = {4,384,"INVTYPE_HEAD"}, -- "Necrotic Boneplate Faceguard"
  [78793] = {4,384,"INVTYPE_HEAD"}, -- "Wyrmstalker's Headguard"
  [78794] = {4,384,"INVTYPE_HEAD"}, -- "Blackfang Battleweave Helmet"
  [78795] = {4,384,"INVTYPE_HEAD"}, -- "Cowl of Dying Light"
  [78796] = {4,384,"INVTYPE_HEAD"}, -- "Time Lord's Hood"
  [78797] = {4,384,"INVTYPE_HEAD"}, -- "Hood of the Faceless Shroud"
  [78798] = {4,384,"INVTYPE_HEAD"}, -- "Hood of Dying Light"
  [78799] = {4,384,"INVTYPE_LEGS"}, -- "Spiritwalker's Legguards"
  [78800] = {4,384,"INVTYPE_LEGS"}, -- "Colossal Dragonplate Legguards"
  [78801] = {4,384,"INVTYPE_LEGS"}, -- "Colossal Dragonplate Legplates"
  [78802] = {4,384,"INVTYPE_LEGS"}, -- "Necrotic Boneplate Greaves"
  [78803] = {4,384,"INVTYPE_LEGS"}, -- "Blackfang Battleweave Legguards"
  [78804] = {4,384,"INVTYPE_LEGS"}, -- "Wyrmstalker's Legguards"
  [78805] = {4,384,"INVTYPE_LEGS"}, -- "Deep Earth Legwraps"
  [78806] = {4,384,"INVTYPE_LEGS"}, -- "Spiritwalker's Kilt"
  [78807] = {4,384,"INVTYPE_LEGS"}, -- "Legplates of Radiant Glory"
  [78808] = {4,384,"INVTYPE_LEGS"}, -- "Deep Earth Legguards"
  [78809] = {4,384,"INVTYPE_LEGS"}, -- "Deep Earth Leggings"
  [78810] = {4,384,"INVTYPE_LEGS"}, -- "Legguards of Radiant Glory"
  [78811] = {4,384,"INVTYPE_LEGS"}, -- "Necrotic Boneplate Legguards"
  [78812] = {4,384,"INVTYPE_LEGS"}, -- "Greaves of Radiant Glory"
  [78813] = {4,384,"INVTYPE_LEGS"}, -- "Spiritwalker's Legwraps"
  [78814] = {4,384,"INVTYPE_LEGS"}, -- "Legwraps of Dying Light"
  [78815] = {4,384,"INVTYPE_LEGS"}, -- "Time Lord's Leggings"
  [78816] = {4,384,"INVTYPE_LEGS"}, -- "Leggings of the Faceless Shroud"
  [78817] = {4,384,"INVTYPE_LEGS"}, -- "Leggings of Dying Light"
  [78818] = {4,384,"INVTYPE_ROBE"}, -- "Spiritwalker's Hauberk"
  [78819] = {4,384,"INVTYPE_ROBE"}, -- "Spiritwalker's Cuirass"
  [78820] = {4,384,"INVTYPE_ROBE"}, -- "Spiritwalker's Tunic"
  [78821] = {4,384,"INVTYPE_CHEST"}, -- "Breastplate of Radiant Glory"
  [78822] = {4,384,"INVTYPE_CHEST"}, -- "Battleplate of Radiant Glory"
  [78823] = {4,384,"INVTYPE_ROBE"}, -- "Robes of Dying Light"
  [78824] = {4,384,"INVTYPE_ROBE"}, -- "Time Lord's Robes"
  [78825] = {4,384,"INVTYPE_ROBE"}, -- "Robes of the Faceless Shroud"
  [78826] = {4,384,"INVTYPE_ROBE"}, -- "Robes of Dying Light"
  [78827] = {4,384,"INVTYPE_CHEST"}, -- "Chestguard of Radiant Glory"
  [78828] = {4,384,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Spaulders"
  [78829] = {4,384,"INVTYPE_SHOULDER"}, -- "Colossal Dragonplate Shoulderguards"
  [78830] = {4,384,"INVTYPE_SHOULDER"}, -- "Colossal Dragonplate Pauldrons"
  [78831] = {4,384,"INVTYPE_SHOULDER"}, -- "Necrotic Boneplate Pauldrons"
  [78832] = {4,384,"INVTYPE_SHOULDER"}, -- "Wyrmstalker's Spaulders"
  [78833] = {4,384,"INVTYPE_SHOULDER"}, -- "Blackfang Battleweave Spaulders"
  [78834] = {4,384,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Mantle"
  [78835] = {4,384,"INVTYPE_SHOULDER"}, -- "Deep Earth Mantle"
  [78836] = {4,384,"INVTYPE_SHOULDER"}, -- "Spiritwalker's Shoulderwraps"
  [78837] = {4,384,"INVTYPE_SHOULDER"}, -- "Pauldrons of Radiant Glory"
  [78838] = {4,384,"INVTYPE_SHOULDER"}, -- "Deep Earth Spaulders"
  [78839] = {4,384,"INVTYPE_SHOULDER"}, -- "Deep Earth Shoulderwraps"
  [78840] = {4,384,"INVTYPE_SHOULDER"}, -- "Shoulderguards of Radiant Glory"
  [78841] = {4,384,"INVTYPE_SHOULDER"}, -- "Mantle of Radiant Glory"
  [78842] = {4,384,"INVTYPE_SHOULDER"}, -- "Mantle of Dying Light"
  [78843] = {4,384,"INVTYPE_SHOULDER"}, -- "Time Lord's Mantle"
  [78844] = {4,384,"INVTYPE_SHOULDER"}, -- "Mantle of the Faceless Shroud"
  [78845] = {4,384,"INVTYPE_SHOULDER"}, -- "Mantle of Dying Light"
  [78846] = {4,384,"INVTYPE_SHOULDER"}, -- "Necrotic Boneplate Shoulderguards"
  [78878] = {4,397,"INVTYPE_WEAPONMAINHAND"}, -- "Spine of the Thousand Cuts"
  [78879] = {4,397,"INVTYPE_WAIST"}, -- "Sash of Relentless Truth"
  [78882] = {4,397,"INVTYPE_WAIST"}, -- "Nightblind Cinch"
  [78884] = {4,397,"INVTYPE_WAIST"}, -- "Girdle of Fungal Dreams"
  [78885] = {4,397,"INVTYPE_WAIST"}, -- "Dragoncarver Belt"
  [78886] = {4,397,"INVTYPE_WAIST"}, -- "Belt of Ghostly Graces"
  [78887] = {4,397,"INVTYPE_WAIST"}, -- "Girdle of Soulful Mending"
  [78888] = {4,397,"INVTYPE_WAIST"}, -- "Waistguard of Bleeding Bone"
  [78889] = {4,397,"INVTYPE_WAIST"}, -- "Waistplate of the Desecrated Future"
}

for k,v in pairs(CACHED_ITEM_DATA) do
  if not prices[k] then
    prices[k] = v
  end
end
for k,v in pairs(CUSTOM_ITEM_DATA) do
  if not prices[k] and v[2]>=359 then -- exclude pre-wrath
    prices[k] = v
  end
end

-- The default quality threshold:
-- 0 - Poor
-- 1 - Uncommon
-- 2 - Common
-- 3 - Rare
-- 4 - Epic
-- 5 - Legendary
-- 6 - Artifact
local quality_threshold = 4

local function getStaticValues(itemID, itemQuality, itemLevel, itemEquipLoc)
  -- Check our item database
  if CACHED_ITEM_DATA[itemID] then
    itemQuality, itemLevel, itemEquipLoc = unpack(CACHED_ITEM_DATA[itemID])
  end

  -- Check to see if there is custom data for this item ID
  if CUSTOM_ITEM_DATA[itemID] then
    itemQuality, itemLevel, itemEquipLoc = unpack(CUSTOM_ITEM_DATA[itemID])
  end

  -- Is the item above our minimum threshold?
  if not itemQuality or itemQuality < quality_threshold then
    return nil, nil, itemLevel, itemQuality, itemEquipLoc
  end

  local slot_multiplier1 = EQUIPSLOT_MULTIPLIER_1[itemEquipLoc]
  local slot_multiplier2 = EQUIPSLOT_MULTIPLIER_2[itemEquipLoc]

  if not slot_multiplier1 then
    return nil, nil, itemLevel, itemQuality, itemEquipLoc
  end
  local gp_base = 4.83 * 2 ^ (itemLevel/75 + (itemQuality - 4)) -- ~20% increase per tier (13ilvl)
  local high = math.floor(gp_base * slot_multiplier1)
  local low = slot_multiplier2 and math.floor(gp_base * slot_multiplier2) or nil
  return high, low
end
--/run for _,i in ipairs({359,372,378,379,384,390,391,397,403,410,416})do print(4.83 * 2 ^ (i/75))end
-- 359,372,378,379,384,390,391,397,403,410,416,
--[[
T11: 359 (+13) > 372 > 379 (Sinestra)
T12: 378 (+13) > 391
LFR: 384 390 (end boss)
T13: 397 > 403 (endboss) (+13) > 410 > 416 (endboss)
]]

local function calcTier(ilevel)
  if not ilevel then return end
  local tier = "T13.5"
  if ilevel <= 371 then
    tier = "T11"
  elseif ilevel <= 377 or ilevel == 379 then
    tier = "T11.5"
  elseif ilevel <= 390 then
    tier = "T12"
  elseif ilevel <= 396 then
    tier = "T12.5"
  elseif ilevel <= 402 or ilevel == 403 then
    tier = "T13"
  elseif ilevel >= 410 then
    tier = "T13.5"
  end
  return tier
end

local function GetDiscountDetail(invType, classID, subclassID)
  --[[Bit of documentation here
  Some discounts are baked-in for historical reasons of how the epgp price calculation worked off item equip location. Equip location lumps together some items (eg wands + some ranged weapon types) that have conditional discounts (based on class and role which is dynamic) so a human was needed to apply this manually. The formula just returned "this equiplocation has 2 possible valuations, you pick the correct one".

  We can only decide discount status deterministically for certain combinations.
  Two-Handed melee weapon to Hunter
  Main-hand or One-hand melee weapon to Hunter (Off-hand melee weapon has discount baked-in)
  Shield to Shaman (as the only non-tank shield bearer)
  Any ranged weapon to melee (ie Warrior or Rogue)
  All Wands (epgp formula is done based on inventory type and they share IndexRangedRight with some ranged weapons)

  Other cases still need a human deciding (One-hand melee weapon to Tank for tanking, One-hand melee weapon to tank or melee for Dual Wield Offhand use, Shield to Paladin, Two-hand melee weapon to Titan Grip warrior for Offhand use)
  ]]
  local wand_discount = subclassID == Enum.ItemWeaponSubclass.Wand
  local ranged_discount = ((invType == Enum.InventoryType.IndexRangedType) or (invType == Enum.InventoryType.IndexRangedrightType)) and "WARRIOR:ROGUE"
  local shield_discount = (subclassID == Enum.ItemArmorSubclass.Shield) and "SHAMAN"
  local onehand_discount = ((invType == Enum.InventoryType.IndexWeaponType) or (invType == Enum.InventoryType.IndexWeaponmainhandType)) and "HUNTER"
  local twohand_discount = (invType == Enum.InventoryType.Index2HweaponType) and "HUNTER"
  return wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount
end

function bepgp_prices_cata:GetPrice(item,progress)
  if not (type(item)=="number" or type(item)=="string") then return end
  if not progress then progress = "T13" end
  local price1,price2,itemID,data,tier,useful
  local itemType, itemSubType, itemEquipLoc, icon, classID, subclassID
  local wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount, item_level
  itemID, itemType, itemSubType, itemEquipLoc, icon, classID, subclassID = GetItemInfoInstant(item)
  if (itemID) then
    local invType = GetItemInventoryTypeByID(itemID)
    data = prices[itemID]
    if (data) then
      local quality, ilevel, equip = unpack(data)
      item_level = tonumber(ilevel)
      tier = calcTier(ilevel)
      price1, price2 = getStaticValues(itemID, quality, ilevel, equip)
      wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount = GetDiscountDetail(invType, classID, subclassID)
    else
      return
    end
  end
  return price1, tier, price2, wand_discount,ranged_discount,shield_discount,onehand_discount,twohand_discount, item_level
end

function bepgp_prices_cata:OnEnable()
  local system = {func=bepgp_prices_cata.GetPrice,flavor="_cata"}
  bepgp:RegisterPriceSystem(name_version,system)
  local mzt,_,_,_,reason = GetAddOnInfo("MizusRaidTracker")
  if not (reason == "ADDON_MISSING" or reason == "ADDON_DISABLED") then
    local loading, finished = IsAddOnLoaded("MizusRaidTracker")
    if loading and finished then
      self:ADDON_LOADED("ADDON_LOADED","MizusRaidTracker")
    else
      self:RegisterEvent("ADDON_LOADED")
    end
  end
end

function bepgp_prices_cata:ADDON_LOADED(event,...)
  if ... == "MizusRaidTracker" then
    self:UnregisterEvent("ADDON_LOADED")
    local MRT_ItemCost = function(mrt_data)
      local itemstring = mrt_data.ItemString
      local dkpValue = self:GetPrice(itemstring, bepgp.db.profile.progress)
      local itemNote
      if not dkpValue then
        dkpValue = 0
        itemNote = ""
      else
        local dkpValue2 = math.floor(dkpValue*bepgp.db.profile.discount)
        itemNote = string.format("%d or %d", dkpValue, dkpValue2)
      end
      return dkpValue, mrt_data.Looter, itemNote, "", true
    end
    if MRT_RegisterItemCostHandlerCore then
      MRT_RegisterItemCostHandlerCore(MRT_ItemCost, addonName)
    end
  end
end

local cacheTimer
function bepgp_prices_cata:Recalculate()
  BastionLootDB._CACHE_ITEM_DATA = BastionLootDB._CACHE_ITEM_DATA or {}
  local stats = {}
  local count = 0
  for i=50000,80000 do
    local itemID, itemType, itemSubType, itemEquipLoc, icon, classID, subclassID = GetItemInfoInstant(i)
    if itemID and EQUIPSLOT_MULTIPLIER_1[itemEquipLoc] then
      if not BastionLootDB._CACHE_ITEM_DATA[itemID] then
        BastionLootDB._CACHE_ITEM_DATA[itemID] = {-1,-1,itemEquipLoc}
      elseif BastionLootDB._CACHE_ITEM_DATA[itemID][1]==-1 then
        local itemAsync = Item:CreateFromItemID(itemID)
        itemAsync:ContinueOnItemLoad(function()
          count = count + 1
          local quality = itemAsync:GetItemQuality()
          local iLevel = itemAsync:GetCurrentItemLevel()
          if quality == 4 and iLevel >= 359 then
            local iLink = itemAsync:GetItemLink()
            stats.ITEM_MOD_RESILIENCE_RATING = nil
            GetItemStats(iLink,stats)
            if not stats.ITEM_MOD_RESILIENCE_RATING then
              local iID = itemAsync:GetItemID()
              local iName = itemAsync:GetItemName()
              BastionLootDB._CACHE_ITEM_DATA[iID][1] = quality
              BastionLootDB._CACHE_ITEM_DATA[iID][2] = iLevel
              BastionLootDB._CACHE_ITEM_DATA[iID][4] = iName
            end
          end
        end)
      end
    end
  end
  if cacheTimer then
    cacheTimer:Cancel()
  end
  cacheTimer = C_Timer.NewTicker(1,function(self)
    if self._lastCount == count and count > 0 then
      bepgp:debugPrint(string.format("Recalc Caching Loop Finished: %d items",count))
      self:Cancel()
    end
    self._lastCount = count
  end)
  cacheTimer._lastCount = count
  bepgp:debugPrint("Recalc Static Loop Finished")
end

function bepgp_prices_cata:Clean(wipe)
  if not BastionLootDB._CACHE_ITEM_DATA then return end
  if wipe then
    BastionLootDB._CACHE_ITEM_DATA = nil
    return
  end
  for itemID, data in pairs(BastionLootDB._CACHE_ITEM_DATA) do
    if data[1]==-1 then
      BastionLootDB._CACHE_ITEM_DATA[itemID] = nil
    end
  end
end

function bepgp_prices_cata:Distribution(ilvlMin,ilvlMax)
  local count = 0
  local atLevel = {}
  for k,v in pairs(prices) do
    atLevel[v[2]] = atLevel[v[2]] and atLevel[v[2]]+1 or 1
    if ilvlMax then
      if v[2]>=ilvlMin and v[2]<=ilvlMax then
        count = count + 1
      end
    else
      if ilvlMin then
        if v[2]==ilvlMin then
          count = count + 1
        end
      end
    end
  end
  if ilvlMax then
    bepgp:debugPrint(format("Items between %d-%d: %d",ilvlMin,ilvlMax,count))
  elseif ilvlMin then
    bepgp:debugPrint(format("Items at %d iLvl: %d",ilvlMin, count))
  end
  local keys = GetKeysArray(atLevel)
  table.sort(keys)
  for _,iLvl in ipairs(keys) do
    bepgp:debugPrint(format("Items at %d: %d",iLvl,atLevel[iLvl]))
  end
end

bepgp_prices_cata._prices = prices

--[[
Enum.ItemClass[Armor|Weapon|Miscellaneous]
Enum.ItemArmorSubclass[Cloth|Leather|Mail|Plate|Shield|Libram|Idol|Totem|Sigil|Relic]
Enum.ItemWeaponSubclass[Wand]
Enum.ItemMiscellaneousSubclass[Junk]
Enum.InventoryType[IndexNonEquipType|IndexHeadType|IndexNeckType|IndexShoulderType|IndexChestType|IndexWaistType|IndexLegsType|IndexFeetType|IndexWristType|IndexHandType|IndexFingerType|IndexTrinketType|IndexWeaponType|IndexShieldType|IndexRangedType|IndexCloakType|Index2HweaponType|IndexRobeType|IndexWeaponmainhandType|IndexWeaponoffhandType|IndexHoldableType|IndexRangedrightType|IndexRelicType]
]]
